shortform = {
    'parti islam semalaysia': ['parti islam semalaysia', 'pas'],
    'parti keadilan rakyat': ['parti keadilan rakyat', 'pkr'],
    'parti amanah': ['parti amanah', 'pan'],
    'democratic action party': ['dap', 'democratic action party'],
    'Pilihan Raya Umum Ke-14': ['ge', 'pru', 'pilihan raya umum ke-14'],
    'malaysian chinese association': ['malaysian chinese association', 'mca'],
    'pakatan harapan': ['ph', 'pakatan harapan'],
    'barisan nasional': ['bn', 'barisan nasional'],
    'universiti malaya': ['universiti malaya', 'um'],
    'universiti islam antarabangsa': [
        'universiti islam antarabangsa',
        'uia',
        'iium',
    ],
    'maktab rendah sains mara': ['mjsc', 'mrsm', 'maktab rendah sains mara'],
}
