location = {
    0: {'negeri': 'JOHOR', 'parlimen': 'SEGAMAT', 'dun': 'BULOH KASAP'},
    1: {'negeri': 'JOHOR', 'parlimen': 'SEGAMAT', 'dun': 'JEMENTAH'},
    2: {'negeri': 'JOHOR', 'parlimen': 'SEKIJANG', 'dun': 'PEMANIS'},
    3: {'negeri': 'JOHOR', 'parlimen': 'SEKIJANG', 'dun': 'KEMELAH'},
    4: {'negeri': 'JOHOR', 'parlimen': 'LABIS', 'dun': 'TENANG'},
    5: {'negeri': 'JOHOR', 'parlimen': 'LABIS', 'dun': 'BEKOK'},
    6: {'negeri': 'JOHOR', 'parlimen': 'PAGOH', 'dun': 'BUKIT SERAMPANG'},
    7: {'negeri': 'JOHOR', 'parlimen': 'PAGOH', 'dun': 'JORAK'},
    8: {'negeri': 'JOHOR', 'parlimen': 'LEDANG', 'dun': 'GAMBIR'},
    9: {'negeri': 'JOHOR', 'parlimen': 'LEDANG', 'dun': 'TANGKAK'},
    10: {'negeri': 'JOHOR', 'parlimen': 'LEDANG', 'dun': 'SEROM'},
    11: {'negeri': 'JOHOR', 'parlimen': 'BAKRI', 'dun': 'BENTAYAN'},
    12: {'negeri': 'JOHOR', 'parlimen': 'BAKRI', 'dun': 'SUNGAI ABONG'},
    13: {'negeri': 'JOHOR', 'parlimen': 'BAKRI', 'dun': 'BUKIT NANING'},
    14: {'negeri': 'JOHOR', 'parlimen': 'MUAR', 'dun': 'MAHARANI'},
    15: {'negeri': 'JOHOR', 'parlimen': 'MUAR', 'dun': 'SUNGAI BALANG'},
    16: {'negeri': 'JOHOR', 'parlimen': 'PARIT SULONG', 'dun': 'SEMERAH'},
    17: {'negeri': 'JOHOR', 'parlimen': 'PARIT SULONG', 'dun': 'SRI MEDAN'},
    18: {'negeri': 'JOHOR', 'parlimen': 'AYER HITAM', 'dun': 'YONG PENG'},
    19: {'negeri': 'JOHOR', 'parlimen': 'AYER HITAM', 'dun': 'SEMARANG'},
    20: {'negeri': 'JOHOR', 'parlimen': 'SRI GADING', 'dun': 'PARIT YAANI'},
    21: {'negeri': 'JOHOR', 'parlimen': 'SRI GADING', 'dun': 'PARIT RAJA'},
    22: {'negeri': 'JOHOR', 'parlimen': 'BATU PAHAT', 'dun': 'PENGGARAM'},
    23: {'negeri': 'JOHOR', 'parlimen': 'BATU PAHAT', 'dun': 'SENGGARANG'},
    24: {'negeri': 'JOHOR', 'parlimen': 'BATU PAHAT', 'dun': 'RENGIT'},
    25: {'negeri': 'JOHOR', 'parlimen': 'SIMPANG RENGGAM', 'dun': 'MACHAP'},
    26: {
        'negeri': 'JOHOR',
        'parlimen': 'SIMPANG RENGGAM',
        'dun': 'LAYANG-LAYANG',
    },
    27: {'negeri': 'JOHOR', 'parlimen': 'KLUANG', 'dun': 'MENGKIBOL'},
    28: {'negeri': 'JOHOR', 'parlimen': 'KLUANG', 'dun': 'MAHKOTA'},
    29: {'negeri': 'JOHOR', 'parlimen': 'SEMBRONG', 'dun': 'PALOH'},
    30: {'negeri': 'JOHOR', 'parlimen': 'SEMBRONG', 'dun': 'KAHANG'},
    31: {'negeri': 'JOHOR', 'parlimen': 'MERSING', 'dun': 'ENDAU'},
    32: {'negeri': 'JOHOR', 'parlimen': 'MERSING', 'dun': 'TENGGAROH'},
    33: {'negeri': 'JOHOR', 'parlimen': 'TENGGARA', 'dun': 'PANTI'},
    34: {'negeri': 'JOHOR', 'parlimen': 'TENGGARA', 'dun': 'PASIR RAJA'},
    35: {'negeri': 'JOHOR', 'parlimen': 'KOTA TINGGI', 'dun': 'SEDILI'},
    36: {'negeri': 'JOHOR', 'parlimen': 'KOTA TINGGI', 'dun': 'JOHOR LAMA'},
    37: {'negeri': 'JOHOR', 'parlimen': 'PENGERANG', 'dun': 'PENAWAR'},
    38: {'negeri': 'JOHOR', 'parlimen': 'PENGERANG', 'dun': 'TANJONG SURAT'},
    39: {'negeri': 'JOHOR', 'parlimen': 'TEBRAU', 'dun': 'TIRAM'},
    40: {'negeri': 'JOHOR', 'parlimen': 'TEBRAU', 'dun': 'PUTERI WANGSA'},
    41: {'negeri': 'JOHOR', 'parlimen': 'PASIR GUDANG', 'dun': 'JOHOR JAYA'},
    42: {'negeri': 'JOHOR', 'parlimen': 'PASIR GUDANG', 'dun': 'PERMAS'},
    43: {'negeri': 'JOHOR', 'parlimen': 'JOHOR BAHRU', 'dun': 'TANJONG PUTERI'},
    44: {'negeri': 'JOHOR', 'parlimen': 'JOHOR BAHRU', 'dun': 'STULANG'},
    45: {'negeri': 'JOHOR', 'parlimen': 'PULAI', 'dun': 'PENGKALAN RINTING'},
    46: {'negeri': 'JOHOR', 'parlimen': 'PULAI', 'dun': 'KEMPAS'},
    47: {'negeri': 'JOHOR', 'parlimen': 'GELANG PATAH', 'dun': 'SKUDAI'},
    48: {'negeri': 'JOHOR', 'parlimen': 'GELANG PATAH', 'dun': 'NUSA JAYA'},
    49: {'negeri': 'JOHOR', 'parlimen': 'KULAI', 'dun': 'BUKIT PERMAI'},
    50: {'negeri': 'JOHOR', 'parlimen': 'KULAI', 'dun': 'BUKIT BATU'},
    51: {'negeri': 'JOHOR', 'parlimen': 'KULAI', 'dun': 'SENAI'},
    52: {'negeri': 'JOHOR', 'parlimen': 'PONTIAN', 'dun': 'BENUT'},
    53: {'negeri': 'JOHOR', 'parlimen': 'PONTIAN', 'dun': 'PULAI SEBATANG'},
    54: {'negeri': 'JOHOR', 'parlimen': 'TANJONG PIAI', 'dun': 'PEKAN NENAS'},
    55: {'negeri': 'JOHOR', 'parlimen': 'TANJONG PIAI', 'dun': 'KUKUP'},
    56: {'negeri': 'KEDAH', 'parlimen': 'LANGKAWI', 'dun': 'AYER HANGAT'},
    57: {'negeri': 'KEDAH', 'parlimen': 'LANGKAWI', 'dun': 'KUAH'},
    58: {'negeri': 'KEDAH', 'parlimen': 'JERLUN', 'dun': 'KOTA SIPUTEH'},
    59: {'negeri': 'KEDAH', 'parlimen': 'JERLUN', 'dun': 'AYER HITAM'},
    60: {
        'negeri': 'KEDAH',
        'parlimen': 'KUBANG PASU',
        'dun': 'BUKIT KAYU HITAM',
    },
    61: {'negeri': 'KEDAH', 'parlimen': 'KUBANG PASU', 'dun': 'JITRA'},
    62: {'negeri': 'KEDAH', 'parlimen': 'PADANG TERAP', 'dun': 'KUALA NERANG'},
    63: {'negeri': 'KEDAH', 'parlimen': 'PADANG TERAP', 'dun': 'PEDU'},
    64: {'negeri': 'KEDAH', 'parlimen': 'POKOK SENA', 'dun': 'BUKIT LADA'},
    65: {'negeri': 'KEDAH', 'parlimen': 'POKOK SENA', 'dun': 'BUKIT PINANG'},
    66: {'negeri': 'KEDAH', 'parlimen': 'POKOK SENA', 'dun': 'DERGA'},
    67: {'negeri': 'KEDAH', 'parlimen': 'ALOR STAR', 'dun': 'BAKAR BATA'},
    68: {'negeri': 'KEDAH', 'parlimen': 'ALOR STAR', 'dun': 'KOTA DARUL AMAN'},
    69: {'negeri': 'KEDAH', 'parlimen': 'ALOR STAR', 'dun': 'ALOR MENGKUDU'},
    70: {'negeri': 'KEDAH', 'parlimen': 'KUALA KEDAH', 'dun': 'ANAK BUKIT'},
    71: {'negeri': 'KEDAH', 'parlimen': 'KUALA KEDAH', 'dun': 'KUBANG ROTAN'},
    72: {
        'negeri': 'KEDAH',
        'parlimen': 'KUALA KEDAH',
        'dun': 'PENGKALAN KUNDOR',
    },
    73: {'negeri': 'KEDAH', 'parlimen': 'PENDANG', 'dun': 'TOKAI'},
    74: {'negeri': 'KEDAH', 'parlimen': 'PENDANG', 'dun': 'SUNGAI TIANG'},
    75: {'negeri': 'KEDAH', 'parlimen': 'JERAI', 'dun': 'SUNGAI LIMAU'},
    76: {'negeri': 'KEDAH', 'parlimen': 'JERAI', 'dun': 'GUAR CHEMPEDAK'},
    77: {'negeri': 'KEDAH', 'parlimen': 'JERAI', 'dun': 'GURUN'},
    78: {'negeri': 'KEDAH', 'parlimen': 'SIK', 'dun': 'BELANTEK'},
    79: {'negeri': 'KEDAH', 'parlimen': 'SIK', 'dun': 'JENERI'},
    80: {'negeri': 'KEDAH', 'parlimen': 'MERBOK', 'dun': 'BUKIT SELAMBAU'},
    81: {'negeri': 'KEDAH', 'parlimen': 'MERBOK', 'dun': 'TANJONG DAWAI'},
    82: {
        'negeri': 'KEDAH',
        'parlimen': 'SUNGAI PETANI',
        'dun': 'PANTAI MERDEKA',
    },
    83: {'negeri': 'KEDAH', 'parlimen': 'SUNGAI PETANI', 'dun': 'BAKAR ARANG'},
    84: {'negeri': 'KEDAH', 'parlimen': 'SUNGAI PETANI', 'dun': 'SIDAM'},
    85: {'negeri': 'KEDAH', 'parlimen': 'BALING', 'dun': 'BAYU'},
    86: {'negeri': 'KEDAH', 'parlimen': 'BALING', 'dun': 'KUPANG'},
    87: {'negeri': 'KEDAH', 'parlimen': 'BALING', 'dun': 'KUALA KETIL'},
    88: {'negeri': 'KEDAH', 'parlimen': 'PADANG SERAI', 'dun': 'MERBAU PULAS'},
    89: {'negeri': 'KEDAH', 'parlimen': 'PADANG SERAI', 'dun': 'LUNAS'},
    90: {'negeri': 'KEDAH', 'parlimen': 'KULIM-BANDAR BAHARU', 'dun': 'KULIM'},
    91: {
        'negeri': 'KEDAH',
        'parlimen': 'KULIM-BANDAR BAHARU',
        'dun': 'BANDAR BAHARU',
    },
    92: {'negeri': 'KELANTAN', 'parlimen': 'TUMPAT', 'dun': 'PENGKALAN KUBOR'},
    93: {'negeri': 'KELANTAN', 'parlimen': 'TUMPAT', 'dun': 'KELABORAN'},
    94: {'negeri': 'KELANTAN', 'parlimen': 'TUMPAT', 'dun': 'PASIR PEKAN'},
    95: {'negeri': 'KELANTAN', 'parlimen': 'TUMPAT', 'dun': 'WAKAF BHARU'},
    96: {'negeri': 'KELANTAN', 'parlimen': 'PENGKALAN CHEPA', 'dun': 'KIJANG'},
    97: {
        'negeri': 'KELANTAN',
        'parlimen': 'PENGKALAN CHEPA',
        'dun': 'CHEMPAKA',
    },
    98: {'negeri': 'KELANTAN', 'parlimen': 'PENGKALAN CHEPA', 'dun': 'PANCHOR'},
    99: {'negeri': 'KELANTAN', 'parlimen': 'KOTA BHARU', 'dun': 'TANJONG MAS'},
    100: {'negeri': 'KELANTAN', 'parlimen': 'KOTA BHARU', 'dun': 'KOTA LAMA'},
    101: {
        'negeri': 'KELANTAN',
        'parlimen': 'KOTA BHARU',
        'dun': 'BUNUT PAYONG',
    },
    102: {'negeri': 'KELANTAN', 'parlimen': 'PASIR MAS', 'dun': 'TENDONG'},
    103: {
        'negeri': 'KELANTAN',
        'parlimen': 'PASIR MAS',
        'dun': 'PENGKALAN PASIR',
    },
    104: {'negeri': 'KELANTAN', 'parlimen': 'PASIR MAS', 'dun': 'CHETOK'},
    105: {'negeri': 'KELANTAN', 'parlimen': 'RANTAU PANJANG', 'dun': 'MERANTI'},
    106: {
        'negeri': 'KELANTAN',
        'parlimen': 'RANTAU PANJANG',
        'dun': 'GUAL PERIOK',
    },
    107: {
        'negeri': 'KELANTAN',
        'parlimen': 'RANTAU PANJANG',
        'dun': 'BUKIT TUKU',
    },
    108: {'negeri': 'KELANTAN', 'parlimen': 'KUBANG KERIAN', 'dun': 'SALOR'},
    109: {
        'negeri': 'KELANTAN',
        'parlimen': 'KUBANG KERIAN',
        'dun': 'PASIR TUMBOH',
    },
    110: {'negeri': 'KELANTAN', 'parlimen': 'KUBANG KERIAN', 'dun': 'DEMIT'},
    111: {'negeri': 'KELANTAN', 'parlimen': 'BACHOK', 'dun': 'TAWANG'},
    112: {'negeri': 'KELANTAN', 'parlimen': 'BACHOK', 'dun': 'PERUPOK'},
    113: {'negeri': 'KELANTAN', 'parlimen': 'BACHOK', 'dun': 'JELAWAT'},
    114: {'negeri': 'KELANTAN', 'parlimen': 'KETEREH', 'dun': 'MELOR'},
    115: {'negeri': 'KELANTAN', 'parlimen': 'KETEREH', 'dun': 'KADOK'},
    116: {'negeri': 'KELANTAN', 'parlimen': 'KETEREH', 'dun': 'KOK LANAS'},
    117: {
        'negeri': 'KELANTAN',
        'parlimen': 'TANAH MERAH',
        'dun': 'BUKIT PANAU',
    },
    118: {'negeri': 'KELANTAN', 'parlimen': 'TANAH MERAH', 'dun': 'GUAL IPOH'},
    119: {'negeri': 'KELANTAN', 'parlimen': 'TANAH MERAH', 'dun': 'KEMAHANG'},
    120: {'negeri': 'KELANTAN', 'parlimen': 'PASIR PUTEH', 'dun': 'SELISING'},
    121: {'negeri': 'KELANTAN', 'parlimen': 'PASIR PUTEH', 'dun': 'LIMBONGAN'},
    122: {'negeri': 'KELANTAN', 'parlimen': 'PASIR PUTEH', 'dun': 'SEMERAK'},
    123: {'negeri': 'KELANTAN', 'parlimen': 'PASIR PUTEH', 'dun': 'GAAL'},
    124: {'negeri': 'KELANTAN', 'parlimen': 'MACHANG', 'dun': 'PULAI CHONDONG'},
    125: {'negeri': 'KELANTAN', 'parlimen': 'MACHANG', 'dun': 'TEMANGAN'},
    126: {'negeri': 'KELANTAN', 'parlimen': 'MACHANG', 'dun': 'KEMUNING'},
    127: {'negeri': 'KELANTAN', 'parlimen': 'JELI', 'dun': 'BUKIT BUNGA'},
    128: {'negeri': 'KELANTAN', 'parlimen': 'JELI', 'dun': 'AIR LANAS'},
    129: {'negeri': 'KELANTAN', 'parlimen': 'JELI', 'dun': 'KUALA BALAH'},
    130: {'negeri': 'KELANTAN', 'parlimen': 'KUALA KRAI', 'dun': 'MENGKEBANG'},
    131: {'negeri': 'KELANTAN', 'parlimen': 'KUALA KRAI', 'dun': 'GUCHIL'},
    132: {'negeri': 'KELANTAN', 'parlimen': 'KUALA KRAI', 'dun': 'MANEK URAI'},
    133: {'negeri': 'KELANTAN', 'parlimen': 'KUALA KRAI', 'dun': 'DABONG'},
    134: {'negeri': 'KELANTAN', 'parlimen': 'GUA MUSANG', 'dun': 'NENGGIRI'},
    135: {'negeri': 'KELANTAN', 'parlimen': 'GUA MUSANG', 'dun': 'PALOH'},
    136: {'negeri': 'KELANTAN', 'parlimen': 'GUA MUSANG', 'dun': 'GALAS'},
    137: {
        'negeri': 'MELAKA',
        'parlimen': 'MASJID TANAH',
        'dun': 'KUALA LINGGI',
    },
    138: {
        'negeri': 'MELAKA',
        'parlimen': 'MASJID TANAH',
        'dun': 'TANJUNG BIDARA',
    },
    139: {'negeri': 'MELAKA', 'parlimen': 'MASJID TANAH', 'dun': 'AYER LIMAU'},
    140: {'negeri': 'MELAKA', 'parlimen': 'MASJID TANAH', 'dun': 'LENDU'},
    141: {
        'negeri': 'MELAKA',
        'parlimen': 'MASJID TANAH',
        'dun': 'TABOH NANING',
    },
    142: {'negeri': 'MELAKA', 'parlimen': 'ALOR GAJAH', 'dun': 'REMBIA'},
    143: {'negeri': 'MELAKA', 'parlimen': 'ALOR GAJAH', 'dun': 'GADEK'},
    144: {'negeri': 'MELAKA', 'parlimen': 'ALOR GAJAH', 'dun': 'MACHAP'},
    145: {
        'negeri': 'MELAKA',
        'parlimen': 'ALOR GAJAH',
        'dun': 'DURIAN TUNGGAL',
    },
    146: {'negeri': 'MELAKA', 'parlimen': 'ALOR GAJAH', 'dun': 'ASAHAN'},
    147: {'negeri': 'MELAKA', 'parlimen': 'TANGGA BATU', 'dun': 'SUNGAI UDANG'},
    148: {
        'negeri': 'MELAKA',
        'parlimen': 'TANGGA BATU',
        'dun': 'PANTAI KUNDOR',
    },
    149: {'negeri': 'MELAKA', 'parlimen': 'TANGGA BATU', 'dun': 'PAYA RUMPUT'},
    150: {'negeri': 'MELAKA', 'parlimen': 'TANGGA BATU', 'dun': 'KELEBANG'},
    151: {'negeri': 'MELAKA', 'parlimen': 'BUKIT KATIL', 'dun': 'BACHANG'},
    152: {'negeri': 'MELAKA', 'parlimen': 'BUKIT KATIL', 'dun': 'AYER KEROH'},
    153: {'negeri': 'MELAKA', 'parlimen': 'BUKIT KATIL', 'dun': 'BUKIT BARU'},
    154: {'negeri': 'MELAKA', 'parlimen': 'BUKIT KATIL', 'dun': 'AYER MOLEK'},
    155: {'negeri': 'MELAKA', 'parlimen': 'KOTA MELAKA', 'dun': 'KESIDANG'},
    156: {
        'negeri': 'MELAKA',
        'parlimen': 'KOTA MELAKA',
        'dun': 'KOTA LAKSAMANA',
    },
    157: {'negeri': 'MELAKA', 'parlimen': 'KOTA MELAKA', 'dun': 'DUYONG'},
    158: {'negeri': 'MELAKA', 'parlimen': 'KOTA MELAKA', 'dun': 'BANDAR HILIR'},
    159: {'negeri': 'MELAKA', 'parlimen': 'KOTA MELAKA', 'dun': 'TELOK MAS'},
    160: {'negeri': 'MELAKA', 'parlimen': 'JASIN', 'dun': 'BEMBAN'},
    161: {'negeri': 'MELAKA', 'parlimen': 'JASIN', 'dun': 'RIM'},
    162: {'negeri': 'MELAKA', 'parlimen': 'JASIN', 'dun': 'SERKAM'},
    163: {'negeri': 'MELAKA', 'parlimen': 'JASIN', 'dun': 'MERLIMAU'},
    164: {'negeri': 'MELAKA', 'parlimen': 'JASIN', 'dun': 'SUNGAI RAMBAI'},
    165: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JELEBU', 'dun': 'CHENNAH'},
    166: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JELEBU', 'dun': 'PERTANG'},
    167: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'JELEBU',
        'dun': 'SUNGAI LUI',
    },
    168: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JELEBU', 'dun': 'KLAWANG'},
    169: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JEMPOL', 'dun': 'SERTING'},
    170: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JEMPOL', 'dun': 'PALONG'},
    171: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'JEMPOL',
        'dun': 'JERAM PADANG',
    },
    172: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'JEMPOL', 'dun': 'BAHAU'},
    173: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'SEREMBAN',
        'dun': 'LENGGENG',
    },
    174: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'SEREMBAN', 'dun': 'NILAI'},
    175: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'SEREMBAN', 'dun': 'LOBAK'},
    176: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'SEREMBAN',
        'dun': 'TEMIANG',
    },
    177: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'SEREMBAN',
        'dun': 'SIKAMAT',
    },
    178: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'SEREMBAN',
        'dun': 'AMPANGAN',
    },
    179: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'KUALA PILAH',
        'dun': 'JUASSEH',
    },
    180: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'KUALA PILAH',
        'dun': 'SERI MENANTI',
    },
    181: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'KUALA PILAH',
        'dun': 'SENALING',
    },
    182: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'KUALA PILAH',
        'dun': 'PILAH',
    },
    183: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'KUALA PILAH',
        'dun': 'JOHOL',
    },
    184: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'RASAH', 'dun': 'LABU'},
    185: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'RASAH',
        'dun': 'BUKIT KEPAYANG',
    },
    186: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'RASAH', 'dun': 'RAHANG'},
    187: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'RASAH', 'dun': 'MAMBAU'},
    188: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'RASAH', 'dun': 'SENAWANG'},
    189: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'REMBAU', 'dun': 'PAROI'},
    190: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'REMBAU', 'dun': 'CHEMBONG'},
    191: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'REMBAU', 'dun': 'RANTAU'},
    192: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'REMBAU', 'dun': 'KOTA'},
    193: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TELOK KEMANG',
        'dun': 'CHUAH',
    },
    194: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TELOK KEMANG',
        'dun': 'LUKUT',
    },
    195: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TELOK KEMANG',
        'dun': 'BAGAN PINANG',
    },
    196: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TELOK KEMANG',
        'dun': 'LINGGI',
    },
    197: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TELOK KEMANG',
        'dun': 'PORT DICKSON',
    },
    198: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'TAMPIN', 'dun': 'GEMAS'},
    199: {
        'negeri': 'NEGERI SEMBILAN',
        'parlimen': 'TAMPIN',
        'dun': 'GEMENCHEH',
    },
    200: {'negeri': 'NEGERI SEMBILAN', 'parlimen': 'TAMPIN', 'dun': 'REPAH'},
    201: {
        'negeri': 'PAHANG',
        'parlimen': 'CAMERON HIGHLANDS',
        'dun': 'TANAH RATA',
    },
    202: {'negeri': 'PAHANG', 'parlimen': 'CAMERON HIGHLANDS', 'dun': 'JELAI'},
    203: {'negeri': 'PAHANG', 'parlimen': 'LIPIS', 'dun': 'PADANG TENGKU'},
    204: {'negeri': 'PAHANG', 'parlimen': 'LIPIS', 'dun': 'CHEKA'},
    205: {'negeri': 'PAHANG', 'parlimen': 'LIPIS', 'dun': 'BENTA'},
    206: {'negeri': 'PAHANG', 'parlimen': 'RAUB', 'dun': 'BATU TALAM'},
    207: {'negeri': 'PAHANG', 'parlimen': 'RAUB', 'dun': 'TRAS'},
    208: {'negeri': 'PAHANG', 'parlimen': 'RAUB', 'dun': 'DONG'},
    209: {'negeri': 'PAHANG', 'parlimen': 'JERANTUT', 'dun': 'TAHAN'},
    210: {'negeri': 'PAHANG', 'parlimen': 'JERANTUT', 'dun': 'DAMAK'},
    211: {'negeri': 'PAHANG', 'parlimen': 'JERANTUT', 'dun': 'PULAU TAWAR'},
    212: {'negeri': 'PAHANG', 'parlimen': 'INDERA MAHKOTA', 'dun': 'BESERAH'},
    213: {'negeri': 'PAHANG', 'parlimen': 'INDERA MAHKOTA', 'dun': 'SEMAMBU'},
    214: {'negeri': 'PAHANG', 'parlimen': 'KUANTAN', 'dun': 'TERUNTUM'},
    215: {'negeri': 'PAHANG', 'parlimen': 'KUANTAN', 'dun': 'TANJUNG LUMPUR'},
    216: {'negeri': 'PAHANG', 'parlimen': 'KUANTAN', 'dun': 'INDERAPURA'},
    217: {
        'negeri': 'PAHANG',
        'parlimen': 'PAYA BESAR',
        'dun': 'SUNGAI LEMBING',
    },
    218: {'negeri': 'PAHANG', 'parlimen': 'PAYA BESAR', 'dun': 'LEPAR'},
    219: {'negeri': 'PAHANG', 'parlimen': 'PAYA BESAR', 'dun': 'PANCHING'},
    220: {'negeri': 'PAHANG', 'parlimen': 'PEKAN', 'dun': 'PULAU MANIS'},
    221: {'negeri': 'PAHANG', 'parlimen': 'PEKAN', 'dun': 'PERAMU JAYA'},
    222: {'negeri': 'PAHANG', 'parlimen': 'PEKAN', 'dun': 'BEBAR'},
    223: {'negeri': 'PAHANG', 'parlimen': 'PEKAN', 'dun': 'CHINI'},
    224: {'negeri': 'PAHANG', 'parlimen': 'MARAN', 'dun': 'LUIT'},
    225: {'negeri': 'PAHANG', 'parlimen': 'MARAN', 'dun': 'KUALA SENTUL'},
    226: {'negeri': 'PAHANG', 'parlimen': 'MARAN', 'dun': 'CHENOR'},
    227: {'negeri': 'PAHANG', 'parlimen': 'KUALA KRAU', 'dun': 'JENDERAK'},
    228: {'negeri': 'PAHANG', 'parlimen': 'KUALA KRAU', 'dun': 'KERDAU'},
    229: {'negeri': 'PAHANG', 'parlimen': 'KUALA KRAU', 'dun': 'JENGKA'},
    230: {'negeri': 'PAHANG', 'parlimen': 'TEMERLOH', 'dun': 'MENTAKAB'},
    231: {'negeri': 'PAHANG', 'parlimen': 'TEMERLOH', 'dun': 'LANCHANG'},
    232: {'negeri': 'PAHANG', 'parlimen': 'TEMERLOH', 'dun': 'KUALA SEMANTAN'},
    233: {'negeri': 'PAHANG', 'parlimen': 'BENTONG', 'dun': 'BILUT'},
    234: {'negeri': 'PAHANG', 'parlimen': 'BENTONG', 'dun': 'KETARI'},
    235: {'negeri': 'PAHANG', 'parlimen': 'BENTONG', 'dun': 'SABAI'},
    236: {'negeri': 'PAHANG', 'parlimen': 'BENTONG', 'dun': 'PELANGAI'},
    237: {'negeri': 'PAHANG', 'parlimen': 'BERA', 'dun': 'GUAI'},
    238: {'negeri': 'PAHANG', 'parlimen': 'BERA', 'dun': 'TRIANG'},
    239: {'negeri': 'PAHANG', 'parlimen': 'BERA', 'dun': 'KEMAYAN'},
    240: {'negeri': 'PAHANG', 'parlimen': 'ROMPIN', 'dun': 'BUKIT IBAM'},
    241: {'negeri': 'PAHANG', 'parlimen': 'ROMPIN', 'dun': 'MUADZAM SHAH'},
    242: {'negeri': 'PAHANG', 'parlimen': 'ROMPIN', 'dun': 'TIOMAN'},
    243: {'negeri': 'PERAK', 'parlimen': 'GERIK', 'dun': 'PENGKALAN HULU'},
    244: {'negeri': 'PERAK', 'parlimen': 'GERIK', 'dun': 'TEMENGOR'},
    245: {'negeri': 'PERAK', 'parlimen': 'LENGGONG', 'dun': 'KENERING'},
    246: {'negeri': 'PERAK', 'parlimen': 'LENGGONG', 'dun': 'KOTA TAMPAN'},
    247: {'negeri': 'PERAK', 'parlimen': 'LARUT', 'dun': 'SELAMA'},
    248: {'negeri': 'PERAK', 'parlimen': 'LARUT', 'dun': 'KUBU GAJAH'},
    249: {'negeri': 'PERAK', 'parlimen': 'LARUT', 'dun': 'BATU KURAU'},
    250: {'negeri': 'PERAK', 'parlimen': 'PARIT BUNTAR', 'dun': 'TITI SERONG'},
    251: {'negeri': 'PERAK', 'parlimen': 'PARIT BUNTAR', 'dun': 'KUALA KURAU'},
    252: {'negeri': 'PERAK', 'parlimen': 'BAGAN SERAI', 'dun': 'ALOR PONGSU'},
    253: {
        'negeri': 'PERAK',
        'parlimen': 'BAGAN SERAI',
        'dun': 'GUNONG SEMANGGOL',
    },
    254: {'negeri': 'PERAK', 'parlimen': 'BAGAN SERAI', 'dun': 'SELINSING'},
    255: {
        'negeri': 'PERAK',
        'parlimen': 'BUKIT GANTANG',
        'dun': 'KUALA SAPETANG',
    },
    256: {
        'negeri': 'PERAK',
        'parlimen': 'BUKIT GANTANG',
        'dun': 'CHANGKAT JERING',
    },
    257: {'negeri': 'PERAK', 'parlimen': 'BUKIT GANTANG', 'dun': 'TRONG'},
    258: {'negeri': 'PERAK', 'parlimen': 'TAIPING', 'dun': 'KAMUNTING'},
    259: {'negeri': 'PERAK', 'parlimen': 'TAIPING', 'dun': 'POKOK ASSAM'},
    260: {'negeri': 'PERAK', 'parlimen': 'TAIPING', 'dun': 'AULONG'},
    261: {'negeri': 'PERAK', 'parlimen': 'PADANG RENGAS', 'dun': 'CHENDEROH'},
    262: {
        'negeri': 'PERAK',
        'parlimen': 'PADANG RENGAS',
        'dun': 'LUBOK MERBAU',
    },
    263: {'negeri': 'PERAK', 'parlimen': 'SUNGAI SIPUT', 'dun': 'LINTANG'},
    264: {'negeri': 'PERAK', 'parlimen': 'SUNGAI SIPUT', 'dun': 'JALONG'},
    265: {'negeri': 'PERAK', 'parlimen': 'TAMBUN', 'dun': 'MANJOI'},
    266: {'negeri': 'PERAK', 'parlimen': 'TAMBUN', 'dun': 'HULU KINTA'},
    267: {'negeri': 'PERAK', 'parlimen': 'IPOH TIMOR', 'dun': 'CANNING'},
    268: {'negeri': 'PERAK', 'parlimen': 'IPOH TIMOR', 'dun': 'TEBING TINGGI'},
    269: {'negeri': 'PERAK', 'parlimen': 'IPOH TIMOR', 'dun': 'PASIR PINJI'},
    270: {'negeri': 'PERAK', 'parlimen': 'IPOH BARAT', 'dun': 'BERCHAM'},
    271: {'negeri': 'PERAK', 'parlimen': 'IPOH BARAT', 'dun': 'KEPAYANG'},
    272: {'negeri': 'PERAK', 'parlimen': 'IPOH BARAT', 'dun': 'BUNTONG'},
    273: {'negeri': 'PERAK', 'parlimen': 'BATU GAJAH', 'dun': 'JELAPANG'},
    274: {'negeri': 'PERAK', 'parlimen': 'BATU GAJAH', 'dun': 'MENGLEMBU'},
    275: {'negeri': 'PERAK', 'parlimen': 'BATU GAJAH', 'dun': 'TRONOH'},
    276: {
        'negeri': 'PERAK',
        'parlimen': 'KUALA KANGSAR',
        'dun': 'BUKIT CHANDAN',
    },
    277: {'negeri': 'PERAK', 'parlimen': 'KUALA KANGSAR', 'dun': 'MANONG'},
    278: {'negeri': 'PERAK', 'parlimen': 'BERUAS', 'dun': 'PENGKALAN BAHARU'},
    279: {'negeri': 'PERAK', 'parlimen': 'BERUAS', 'dun': 'PANTAI REMIS'},
    280: {'negeri': 'PERAK', 'parlimen': 'PARIT', 'dun': 'BELANJA'},
    281: {'negeri': 'PERAK', 'parlimen': 'PARIT', 'dun': 'BOTA'},
    282: {'negeri': 'PERAK', 'parlimen': 'KAMPAR', 'dun': 'MALIM NAWAR'},
    283: {'negeri': 'PERAK', 'parlimen': 'KAMPAR', 'dun': 'KERANJI'},
    284: {'negeri': 'PERAK', 'parlimen': 'KAMPAR', 'dun': 'TUALANG SEKAH'},
    285: {'negeri': 'PERAK', 'parlimen': 'GOPENG', 'dun': 'SUNGAI RAPAT'},
    286: {'negeri': 'PERAK', 'parlimen': 'GOPENG', 'dun': 'SIMPANG PULAI'},
    287: {'negeri': 'PERAK', 'parlimen': 'GOPENG', 'dun': 'TEJA'},
    288: {'negeri': 'PERAK', 'parlimen': 'TAPAH', 'dun': 'CHENDERIANG'},
    289: {'negeri': 'PERAK', 'parlimen': 'TAPAH', 'dun': 'AYER KUNING'},
    290: {'negeri': 'PERAK', 'parlimen': 'PASIR SALAK', 'dun': 'SUNGAI MANIK'},
    291: {'negeri': 'PERAK', 'parlimen': 'PASIR SALAK', 'dun': 'KAMPONG GAJAH'},
    292: {'negeri': 'PERAK', 'parlimen': 'LUMUT', 'dun': 'SITIAWAN'},
    293: {'negeri': 'PERAK', 'parlimen': 'LUMUT', 'dun': 'PASIR PANJANG'},
    294: {'negeri': 'PERAK', 'parlimen': 'LUMUT', 'dun': 'PANGKOR'},
    295: {'negeri': 'PERAK', 'parlimen': 'BAGAN DATOK', 'dun': 'RUNGKUP'},
    296: {
        'negeri': 'PERAK',
        'parlimen': 'BAGAN DATOK',
        'dun': 'HUTAN MELINTANG',
    },
    297: {'negeri': 'PERAK', 'parlimen': 'TELOK INTAN', 'dun': 'PASIR BEDAMAR'},
    298: {'negeri': 'PERAK', 'parlimen': 'TELOK INTAN', 'dun': 'CHANGKAT JONG'},
    299: {'negeri': 'PERAK', 'parlimen': 'TANJONG MALIM', 'dun': 'SUNGKAI'},
    300: {'negeri': 'PERAK', 'parlimen': 'TANJONG MALIM', 'dun': 'SLIM'},
    301: {'negeri': 'PERAK', 'parlimen': 'TANJONG MALIM', 'dun': 'BEHRANG'},
    302: {'negeri': 'PERLIS', 'parlimen': 'PADANG BESAR', 'dun': 'TITI TINGGI'},
    303: {'negeri': 'PERLIS', 'parlimen': 'PADANG BESAR', 'dun': 'BESERI'},
    304: {'negeri': 'PERLIS', 'parlimen': 'PADANG BESAR', 'dun': 'CHUPING'},
    305: {'negeri': 'PERLIS', 'parlimen': 'PADANG BESAR', 'dun': 'MATA AYER'},
    306: {'negeri': 'PERLIS', 'parlimen': 'PADANG BESAR', 'dun': 'SANTAN'},
    307: {'negeri': 'PERLIS', 'parlimen': 'KANGAR', 'dun': 'BINTONG'},
    308: {'negeri': 'PERLIS', 'parlimen': 'KANGAR', 'dun': 'SENA'},
    309: {'negeri': 'PERLIS', 'parlimen': 'KANGAR', 'dun': 'INDERA KAYANGAN'},
    310: {'negeri': 'PERLIS', 'parlimen': 'KANGAR', 'dun': 'KUALA PERLIS'},
    311: {'negeri': 'PERLIS', 'parlimen': 'KANGAR', 'dun': 'KAYANG'},
    312: {'negeri': 'PERLIS', 'parlimen': 'ARAU', 'dun': 'PAUH'},
    313: {'negeri': 'PERLIS', 'parlimen': 'ARAU', 'dun': 'TAMBUN TULANG'},
    314: {'negeri': 'PERLIS', 'parlimen': 'ARAU', 'dun': 'GUAR SANJI'},
    315: {'negeri': 'PERLIS', 'parlimen': 'ARAU', 'dun': 'SIMPANG EMPAT'},
    316: {'negeri': 'PERLIS', 'parlimen': 'ARAU', 'dun': 'SANGLANG'},
    317: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'KEPALA BATAS',
        'dun': 'PENAGA',
    },
    318: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'KEPALA BATAS',
        'dun': 'BERTAM',
    },
    319: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'KEPALA BATAS',
        'dun': 'PINANG TUNGGAL',
    },
    320: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'TASEK GELUGOR',
        'dun': 'PERMATANG BERANGAN',
    },
    321: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'TASEK GELUGOR',
        'dun': 'SUNGAI DUA',
    },
    322: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'TASEK GELUGOR',
        'dun': 'TELOK AYER TAWAR',
    },
    323: {'negeri': 'PULAU PINANG', 'parlimen': 'BAGAN', 'dun': 'SUNGAI PUYU'},
    324: {'negeri': 'PULAU PINANG', 'parlimen': 'BAGAN', 'dun': 'BAGAN JERMAL'},
    325: {'negeri': 'PULAU PINANG', 'parlimen': 'BAGAN', 'dun': 'BAGAN DALAM'},
    326: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'PERMATANG PAUH',
        'dun': 'SEBERANG JAYA',
    },
    327: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'PERMATANG PAUH',
        'dun': 'PERMATANG PASIR',
    },
    328: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'PERMATANG PAUH',
        'dun': 'PENANTI',
    },
    329: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT MERTAJAM',
        'dun': 'BERAPIT',
    },
    330: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT MERTAJAM',
        'dun': 'MACHANG BUBUK',
    },
    331: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT MERTAJAM',
        'dun': 'PADANG LALANG',
    },
    332: {'negeri': 'PULAU PINANG', 'parlimen': 'BATU KAWAN', 'dun': 'PERAI'},
    333: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BATU KAWAN',
        'dun': 'BUKIT TENGAH',
    },
    334: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BATU KAWAN',
        'dun': 'BUKIT TAMBUN',
    },
    335: {'negeri': 'PULAU PINANG', 'parlimen': 'NIBONG TEBAL', 'dun': 'JAWI'},
    336: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'NIBONG TEBAL',
        'dun': 'SUNGAI BAKAP',
    },
    337: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'NIBONG TEBAL',
        'dun': 'SUNGAI ACHEH',
    },
    338: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT BENDERA',
        'dun': 'TANJONG BUNGA',
    },
    339: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT BENDERA',
        'dun': 'AIR PUTIH',
    },
    340: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT BENDERA',
        'dun': 'KEBUN BUNGA',
    },
    341: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT BENDERA',
        'dun': 'PULAU TIKUS',
    },
    342: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'TANJONG',
        'dun': 'PADANG KOTA',
    },
    343: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'TANJONG',
        'dun': 'PENGKALAN KOTA',
    },
    344: {'negeri': 'PULAU PINANG', 'parlimen': 'TANJONG', 'dun': 'KOMTAR'},
    345: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'JELUTONG',
        'dun': 'DATOK KERAMAT',
    },
    346: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'JELUTONG',
        'dun': 'SUNGAI PINANG',
    },
    347: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'JELUTONG',
        'dun': 'BATU LANCANG',
    },
    348: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT GELUGOR',
        'dun': 'SERI DELIMA',
    },
    349: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT GELUGOR',
        'dun': 'AIR ITAM',
    },
    350: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BUKIT GELUGOR',
        'dun': 'PAYA TERUBONG',
    },
    351: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BAYAN BARU',
        'dun': 'BATU UBAN',
    },
    352: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BAYAN BARU',
        'dun': 'PANTAI JEREJAK',
    },
    353: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BAYAN BARU',
        'dun': 'BATU MAUNG',
    },
    354: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BALIK PULAU',
        'dun': 'BAYAN LEPAS',
    },
    355: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BALIK PULAU',
        'dun': 'PULAU BETONG',
    },
    356: {
        'negeri': 'PULAU PINANG',
        'parlimen': 'BALIK PULAU',
        'dun': 'TELOK BAHANG',
    },
    357: {'negeri': 'SABAH', 'parlimen': 'KUDAT', 'dun': 'BANGGI'},
    358: {'negeri': 'SABAH', 'parlimen': 'KUDAT', 'dun': 'TANJONG KAPOR'},
    359: {'negeri': 'SABAH', 'parlimen': 'KUDAT', 'dun': 'PITAS'},
    360: {'negeri': 'SABAH', 'parlimen': 'KOTA MARUDU', 'dun': 'MATUNGGONG'},
    361: {'negeri': 'SABAH', 'parlimen': 'KOTA MARUDU', 'dun': 'TANDEK'},
    362: {'negeri': 'SABAH', 'parlimen': 'KOTA BELUD', 'dun': 'TEMPASUK'},
    363: {'negeri': 'SABAH', 'parlimen': 'KOTA BELUD', 'dun': 'KADAMAIAN'},
    364: {'negeri': 'SABAH', 'parlimen': 'KOTA BELUD', 'dun': 'USUKAN'},
    365: {'negeri': 'SABAH', 'parlimen': 'TUARAN', 'dun': 'TAMPARULI'},
    366: {'negeri': 'SABAH', 'parlimen': 'TUARAN', 'dun': 'SULAMAN'},
    367: {'negeri': 'SABAH', 'parlimen': 'TUARAN', 'dun': 'KIULU'},
    368: {'negeri': 'SABAH', 'parlimen': 'SEPANGGAR', 'dun': 'KARAMBUNAI'},
    369: {'negeri': 'SABAH', 'parlimen': 'SEPANGGAR', 'dun': 'INANAM'},
    370: {'negeri': 'SABAH', 'parlimen': 'KOTA KINABALU', 'dun': 'LIKAS'},
    371: {'negeri': 'SABAH', 'parlimen': 'KOTA KINABALU', 'dun': 'API-API'},
    372: {'negeri': 'SABAH', 'parlimen': 'KOTA KINABALU', 'dun': 'LUYANG'},
    373: {'negeri': 'SABAH', 'parlimen': 'PUTATAN', 'dun': 'TANJONG ARU'},
    374: {'negeri': 'SABAH', 'parlimen': 'PUTATAN', 'dun': 'PETAGAS'},
    375: {'negeri': 'SABAH', 'parlimen': 'PENAMPANG', 'dun': 'KAPAYAN'},
    376: {'negeri': 'SABAH', 'parlimen': 'PENAMPANG', 'dun': 'MOYOG'},
    377: {'negeri': 'SABAH', 'parlimen': 'PAPAR', 'dun': 'KAWANG'},
    378: {'negeri': 'SABAH', 'parlimen': 'PAPAR', 'dun': 'PANTAI MANIS'},
    379: {'negeri': 'SABAH', 'parlimen': 'KIMANIS', 'dun': 'BONGAWAN'},
    380: {'negeri': 'SABAH', 'parlimen': 'KIMANIS', 'dun': 'MEMBAKUT'},
    381: {'negeri': 'SABAH', 'parlimen': 'BEAUFORT', 'dun': 'KLIAS'},
    382: {'negeri': 'SABAH', 'parlimen': 'BEAUFORT', 'dun': 'KUALA PENYU'},
    383: {'negeri': 'SABAH', 'parlimen': 'SIPITANG', 'dun': 'LUMADAN'},
    384: {'negeri': 'SABAH', 'parlimen': 'SIPITANG', 'dun': 'SINDUMIN'},
    385: {'negeri': 'SABAH', 'parlimen': 'RANAU', 'dun': 'KUNDASANG'},
    386: {'negeri': 'SABAH', 'parlimen': 'RANAU', 'dun': 'KARANAAN'},
    387: {'negeri': 'SABAH', 'parlimen': 'RANAU', 'dun': 'PAGINATAN'},
    388: {'negeri': 'SABAH', 'parlimen': 'KENINGAU', 'dun': 'TAMBUNAN'},
    389: {'negeri': 'SABAH', 'parlimen': 'KENINGAU', 'dun': 'BINGKOR'},
    390: {'negeri': 'SABAH', 'parlimen': 'KENINGAU', 'dun': 'LIAWAN'},
    391: {'negeri': 'SABAH', 'parlimen': 'TENOM', 'dun': 'MELALAP'},
    392: {'negeri': 'SABAH', 'parlimen': 'TENOM', 'dun': 'KEMABONG'},
    393: {'negeri': 'SABAH', 'parlimen': 'PENSIANGAN', 'dun': 'SOOK'},
    394: {'negeri': 'SABAH', 'parlimen': 'PENSIANGAN', 'dun': 'NABAWAN'},
    395: {'negeri': 'SABAH', 'parlimen': 'BELURAN', 'dun': 'SUGUT'},
    396: {'negeri': 'SABAH', 'parlimen': 'BELURAN', 'dun': 'LABUK'},
    397: {'negeri': 'SABAH', 'parlimen': 'LIBARAN', 'dun': 'GUM-GUM'},
    398: {'negeri': 'SABAH', 'parlimen': 'LIBARAN', 'dun': 'SUNGAI SIBUGA'},
    399: {'negeri': 'SABAH', 'parlimen': 'BATU SAPI', 'dun': 'SEKONG'},
    400: {'negeri': 'SABAH', 'parlimen': 'BATU SAPI', 'dun': 'KARAMUNTING'},
    401: {'negeri': 'SABAH', 'parlimen': 'SANDAKAN', 'dun': 'ELOPURA'},
    402: {'negeri': 'SABAH', 'parlimen': 'SANDAKAN', 'dun': 'TANJONG PAPAT'},
    403: {'negeri': 'SABAH', 'parlimen': 'KINABATANGAN', 'dun': 'KUAMUT'},
    404: {'negeri': 'SABAH', 'parlimen': 'KINABATANGAN', 'dun': 'SUKAU'},
    405: {'negeri': 'SABAH', 'parlimen': 'SILAM', 'dun': 'TUNGKU'},
    406: {'negeri': 'SABAH', 'parlimen': 'SILAM', 'dun': 'LAHAD DATU'},
    407: {'negeri': 'SABAH', 'parlimen': 'SILAM', 'dun': 'KUNAK'},
    408: {'negeri': 'SABAH', 'parlimen': 'SEMPORNA', 'dun': 'SULABAYAN'},
    409: {'negeri': 'SABAH', 'parlimen': 'SEMPORNA', 'dun': 'SENALLANG'},
    410: {'negeri': 'SABAH', 'parlimen': 'SEMPORNA', 'dun': 'BUGAYA'},
    411: {'negeri': 'SABAH', 'parlimen': 'TAWAU', 'dun': 'BALUNG'},
    412: {'negeri': 'SABAH', 'parlimen': 'TAWAU', 'dun': 'APAS'},
    413: {'negeri': 'SABAH', 'parlimen': 'TAWAU', 'dun': 'SRI TANJONG'},
    414: {'negeri': 'SABAH', 'parlimen': 'KALABAKAN', 'dun': 'MEROTAI'},
    415: {'negeri': 'SABAH', 'parlimen': 'KALABAKAN', 'dun': 'TANJONG BATU'},
    416: {'negeri': 'SABAH', 'parlimen': 'KALABAKAN', 'dun': 'SEBATIK'},
    417: {'negeri': 'SARAWAK', 'parlimen': 'MAS GADING', 'dun': 'OPAR'},
    418: {'negeri': 'SARAWAK', 'parlimen': 'MAS GADING', 'dun': 'TASIK BIRU'},
    419: {'negeri': 'SARAWAK', 'parlimen': 'SANTUBONG', 'dun': 'TANJONG DATU'},
    420: {'negeri': 'SARAWAK', 'parlimen': 'SANTUBONG', 'dun': 'PANTAI DAMAI'},
    421: {'negeri': 'SARAWAK', 'parlimen': 'SANTUBONG', 'dun': 'DEMAK LAUT'},
    422: {'negeri': 'SARAWAK', 'parlimen': 'PETRA JAYA', 'dun': 'TUPONG'},
    423: {'negeri': 'SARAWAK', 'parlimen': 'PETRA JAYA', 'dun': 'SAMARIANG'},
    424: {'negeri': 'SARAWAK', 'parlimen': 'PETRA JAYA', 'dun': 'SATOK'},
    425: {'negeri': 'SARAWAK', 'parlimen': 'BANDAR KUCHING', 'dun': 'PADUNGAN'},
    426: {'negeri': 'SARAWAK', 'parlimen': 'BANDAR KUCHING', 'dun': 'PENDING'},
    427: {
        'negeri': 'SARAWAK',
        'parlimen': 'BANDAR KUCHING',
        'dun': 'BATU LINTANG',
    },
    428: {'negeri': 'SARAWAK', 'parlimen': 'STAMPIN', 'dun': 'KOTA SENTOSA'},
    429: {'negeri': 'SARAWAK', 'parlimen': 'STAMPIN', 'dun': 'BATU KITANG'},
    430: {'negeri': 'SARAWAK', 'parlimen': 'STAMPIN', 'dun': 'BATU KAWAH'},
    431: {'negeri': 'SARAWAK', 'parlimen': 'KOTA SAMARAHAN', 'dun': 'ASAJAYA'},
    432: {
        'negeri': 'SARAWAK',
        'parlimen': 'KOTA SAMARAHAN',
        'dun': 'MUARA TUANG',
    },
    433: {'negeri': 'SARAWAK', 'parlimen': 'KOTA SAMARAHAN', 'dun': 'STAKAN'},
    434: {'negeri': 'SARAWAK', 'parlimen': 'MAMBONG', 'dun': 'SEREMBU'},
    435: {'negeri': 'SARAWAK', 'parlimen': 'MAMBONG', 'dun': 'MAMBONG'},
    436: {'negeri': 'SARAWAK', 'parlimen': 'MAMBONG', 'dun': 'TARAT'},
    437: {'negeri': 'SARAWAK', 'parlimen': 'SERIAN', 'dun': 'TEBEDU'},
    438: {'negeri': 'SARAWAK', 'parlimen': 'SERIAN', 'dun': 'KEDUP'},
    439: {'negeri': 'SARAWAK', 'parlimen': 'SERIAN', 'dun': 'BUKIT SEMUJA'},
    440: {
        'negeri': 'SARAWAK',
        'parlimen': 'BATANG SADONG',
        'dun': 'SADONG JAYA',
    },
    441: {'negeri': 'SARAWAK', 'parlimen': 'BATANG SADONG', 'dun': 'SIMUNJAN'},
    442: {'negeri': 'SARAWAK', 'parlimen': 'BATANG SADONG', 'dun': 'GEDONG'},
    443: {'negeri': 'SARAWAK', 'parlimen': 'BATANG LUPAR', 'dun': 'SEBUYAU'},
    444: {'negeri': 'SARAWAK', 'parlimen': 'BATANG LUPAR', 'dun': 'LINGGA'},
    445: {
        'negeri': 'SARAWAK',
        'parlimen': 'BATANG LUPAR',
        'dun': 'BETING MARO',
    },
    446: {'negeri': 'SARAWAK', 'parlimen': 'SRI AMAN', 'dun': 'BALAI RINGIN'},
    447: {'negeri': 'SARAWAK', 'parlimen': 'SRI AMAN', 'dun': 'BUKIT BEGUNAN'},
    448: {'negeri': 'SARAWAK', 'parlimen': 'SRI AMAN', 'dun': 'SIMANGGANG'},
    449: {'negeri': 'SARAWAK', 'parlimen': 'LUBOK ANTU', 'dun': 'ENGKILILI'},
    450: {'negeri': 'SARAWAK', 'parlimen': 'LUBOK ANTU', 'dun': 'BATANG AI'},
    451: {'negeri': 'SARAWAK', 'parlimen': 'BETONG', 'dun': 'SARIBAS'},
    452: {'negeri': 'SARAWAK', 'parlimen': 'BETONG', 'dun': 'LAYAR'},
    453: {'negeri': 'SARAWAK', 'parlimen': 'BETONG', 'dun': 'BUKIT SABAN'},
    454: {'negeri': 'SARAWAK', 'parlimen': 'SARATOK', 'dun': 'KALAKA'},
    455: {'negeri': 'SARAWAK', 'parlimen': 'SARATOK', 'dun': 'KRIAN'},
    456: {'negeri': 'SARAWAK', 'parlimen': 'SARATOK', 'dun': 'KABONG'},
    457: {
        'negeri': 'SARAWAK',
        'parlimen': 'TANJONG MANIS',
        'dun': 'KUALA RAJANG',
    },
    458: {'negeri': 'SARAWAK', 'parlimen': 'TANJONG MANIS', 'dun': 'SEMOP'},
    459: {'negeri': 'SARAWAK', 'parlimen': 'IGAN', 'dun': 'DARO'},
    460: {'negeri': 'SARAWAK', 'parlimen': 'IGAN', 'dun': 'JEMORENG'},
    461: {'negeri': 'SARAWAK', 'parlimen': 'SARIKEI', 'dun': 'REPOK'},
    462: {'negeri': 'SARAWAK', 'parlimen': 'SARIKEI', 'dun': 'MERADONG'},
    463: {'negeri': 'SARAWAK', 'parlimen': 'JULAU', 'dun': 'PAKAN'},
    464: {'negeri': 'SARAWAK', 'parlimen': 'JULAU', 'dun': 'MELUAN'},
    465: {'negeri': 'SARAWAK', 'parlimen': 'KANOWIT', 'dun': 'NGEMAH'},
    466: {'negeri': 'SARAWAK', 'parlimen': 'KANOWIT', 'dun': 'MACHAN'},
    467: {'negeri': 'SARAWAK', 'parlimen': 'LANANG', 'dun': 'BUKIT ASSEK'},
    468: {'negeri': 'SARAWAK', 'parlimen': 'LANANG', 'dun': 'DUDONG'},
    469: {'negeri': 'SARAWAK', 'parlimen': 'SIBU', 'dun': 'BAWANG ASSAN'},
    470: {'negeri': 'SARAWAK', 'parlimen': 'SIBU', 'dun': 'PELAWAN'},
    471: {'negeri': 'SARAWAK', 'parlimen': 'SIBU', 'dun': 'NANGKA'},
    472: {'negeri': 'SARAWAK', 'parlimen': 'MUKAH', 'dun': 'DALAT'},
    473: {'negeri': 'SARAWAK', 'parlimen': 'MUKAH', 'dun': 'TELLIAN'},
    474: {'negeri': 'SARAWAK', 'parlimen': 'MUKAH', 'dun': 'BALINGIAN'},
    475: {'negeri': 'SARAWAK', 'parlimen': 'SELANGAU', 'dun': 'TAMIN'},
    476: {'negeri': 'SARAWAK', 'parlimen': 'SELANGAU', 'dun': 'KAKUS'},
    477: {'negeri': 'SARAWAK', 'parlimen': 'KAPIT', 'dun': 'PELAGUS'},
    478: {'negeri': 'SARAWAK', 'parlimen': 'KAPIT', 'dun': 'KATIBAS'},
    479: {'negeri': 'SARAWAK', 'parlimen': 'KAPIT', 'dun': 'BUKIT GORAM'},
    480: {'negeri': 'SARAWAK', 'parlimen': 'HULU RAJANG', 'dun': 'BALEH'},
    481: {'negeri': 'SARAWAK', 'parlimen': 'HULU RAJANG', 'dun': 'BELAGA'},
    482: {'negeri': 'SARAWAK', 'parlimen': 'HULU RAJANG', 'dun': 'MURUM'},
    483: {'negeri': 'SARAWAK', 'parlimen': 'BINTULU', 'dun': 'JEPAK'},
    484: {'negeri': 'SARAWAK', 'parlimen': 'BINTULU', 'dun': 'TANJONG BATU'},
    485: {'negeri': 'SARAWAK', 'parlimen': 'BINTULU', 'dun': 'KEMENA'},
    486: {'negeri': 'SARAWAK', 'parlimen': 'BINTULU', 'dun': 'SAMALAJU'},
    487: {'negeri': 'SARAWAK', 'parlimen': 'SIBUTI', 'dun': 'BEKENU'},
    488: {'negeri': 'SARAWAK', 'parlimen': 'SIBUTI', 'dun': 'LAMBIR'},
    489: {'negeri': 'SARAWAK', 'parlimen': 'MIRI', 'dun': 'PIASAU'},
    490: {'negeri': 'SARAWAK', 'parlimen': 'MIRI', 'dun': 'PUJUT'},
    491: {'negeri': 'SARAWAK', 'parlimen': 'MIRI', 'dun': 'SENADIN'},
    492: {'negeri': 'SARAWAK', 'parlimen': 'BARAM', 'dun': 'MARUDI'},
    493: {'negeri': 'SARAWAK', 'parlimen': 'BARAM', 'dun': 'TELANG USAN'},
    494: {'negeri': 'SARAWAK', 'parlimen': 'BARAM', 'dun': 'MULU'},
    495: {'negeri': 'SARAWAK', 'parlimen': 'LIMBANG', 'dun': 'BUKIT KOTA'},
    496: {'negeri': 'SARAWAK', 'parlimen': 'LIMBANG', 'dun': 'BATU DANAU'},
    497: {'negeri': 'SARAWAK', 'parlimen': 'LAWAS', 'dun': 'BA`KELALAN'},
    498: {'negeri': 'SARAWAK', 'parlimen': 'LAWAS', 'dun': 'BUKIT SARI'},
    499: {
        'negeri': 'SELANGOR',
        'parlimen': 'SABAK BERNAM',
        'dun': 'SUNGAI AIR TAWAR',
    },
    500: {'negeri': 'SELANGOR', 'parlimen': 'SABAK BERNAM', 'dun': 'SABAK'},
    501: {
        'negeri': 'SELANGOR',
        'parlimen': 'SUNGAI BESAR',
        'dun': 'SUNGAI PANJANG',
    },
    502: {'negeri': 'SELANGOR', 'parlimen': 'SUNGAI BESAR', 'dun': 'SEKINCHAN'},
    503: {
        'negeri': 'SELANGOR',
        'parlimen': 'HULU SELANGOR',
        'dun': 'HULU BERNAM',
    },
    504: {
        'negeri': 'SELANGOR',
        'parlimen': 'HULU SELANGOR',
        'dun': 'KUALA KUBU BAHARU',
    },
    505: {
        'negeri': 'SELANGOR',
        'parlimen': 'HULU SELANGOR',
        'dun': 'BATANG KALI',
    },
    506: {
        'negeri': 'SELANGOR',
        'parlimen': 'TANJONG KARANG',
        'dun': 'SUNGAI BURONG',
    },
    507: {
        'negeri': 'SELANGOR',
        'parlimen': 'TANJONG KARANG',
        'dun': 'PERMATANG',
    },
    508: {
        'negeri': 'SELANGOR',
        'parlimen': 'KUALA SELANGOR',
        'dun': 'BUKIT MELAWATI',
    },
    509: {'negeri': 'SELANGOR', 'parlimen': 'KUALA SELANGOR', 'dun': 'IJOK'},
    510: {'negeri': 'SELANGOR', 'parlimen': 'KUALA SELANGOR', 'dun': 'JERAM'},
    511: {'negeri': 'SELANGOR', 'parlimen': 'SELAYANG', 'dun': 'KUANG'},
    512: {'negeri': 'SELANGOR', 'parlimen': 'SELAYANG', 'dun': 'RAWANG'},
    513: {'negeri': 'SELANGOR', 'parlimen': 'SELAYANG', 'dun': 'TAMAN TEMPLER'},
    514: {'negeri': 'SELANGOR', 'parlimen': 'GOMBAK', 'dun': 'BATU CAVES'},
    515: {'negeri': 'SELANGOR', 'parlimen': 'GOMBAK', 'dun': 'GOMBAK SETIA'},
    516: {'negeri': 'SELANGOR', 'parlimen': 'GOMBAK', 'dun': 'HULU KELANG'},
    517: {
        'negeri': 'SELANGOR',
        'parlimen': 'AMPANG',
        'dun': 'BUKIT ANTARABANGSA',
    },
    518: {'negeri': 'SELANGOR', 'parlimen': 'AMPANG', 'dun': 'LEMBAH JAYA'},
    519: {'negeri': 'SELANGOR', 'parlimen': 'PANDAN', 'dun': 'CHEMPAKA'},
    520: {'negeri': 'SELANGOR', 'parlimen': 'PANDAN', 'dun': 'TERATAI'},
    521: {'negeri': 'SELANGOR', 'parlimen': 'HULU LANGAT', 'dun': 'DUSUN TUA'},
    522: {'negeri': 'SELANGOR', 'parlimen': 'HULU LANGAT', 'dun': 'SEMENYIH'},
    523: {'negeri': 'SELANGOR', 'parlimen': 'HULU LANGAT', 'dun': 'KAJANG'},
    524: {'negeri': 'SELANGOR', 'parlimen': 'SERDANG', 'dun': 'BANGI'},
    525: {'negeri': 'SELANGOR', 'parlimen': 'SERDANG', 'dun': 'BALAKONG'},
    526: {'negeri': 'SELANGOR', 'parlimen': 'SERDANG', 'dun': 'SERI KEMBANGAN'},
    527: {'negeri': 'SELANGOR', 'parlimen': 'PUCHONG', 'dun': 'SERI SERDANG'},
    528: {'negeri': 'SELANGOR', 'parlimen': 'PUCHONG', 'dun': 'KINRARA'},
    529: {
        'negeri': 'SELANGOR',
        'parlimen': 'KELANA JAYA',
        'dun': 'SUBANG JAYA',
    },
    530: {'negeri': 'SELANGOR', 'parlimen': 'KELANA JAYA', 'dun': 'SERI SETIA'},
    531: {
        'negeri': 'SELANGOR',
        'parlimen': 'PETALING JAYA SELATAN',
        'dun': 'TAMAN MEDAN',
    },
    532: {
        'negeri': 'SELANGOR',
        'parlimen': 'PETALING JAYA SELATAN',
        'dun': 'BUKIT GASING',
    },
    533: {
        'negeri': 'SELANGOR',
        'parlimen': 'PETALING JAYA UTARA',
        'dun': 'KAMPUNG TUNKU',
    },
    534: {
        'negeri': 'SELANGOR',
        'parlimen': 'PETALING JAYA UTARA',
        'dun': 'DAMANSARA UTAMA',
    },
    535: {'negeri': 'SELANGOR', 'parlimen': 'SUBANG', 'dun': 'BUKIT LANJAN'},
    536: {'negeri': 'SELANGOR', 'parlimen': 'SUBANG', 'dun': 'PAYA JARAS'},
    537: {'negeri': 'SELANGOR', 'parlimen': 'SUBANG', 'dun': 'KOTA DAMANSARA'},
    538: {
        'negeri': 'SELANGOR',
        'parlimen': 'SHAH ALAM',
        'dun': 'KOTA ANGGERIK',
    },
    539: {'negeri': 'SELANGOR', 'parlimen': 'SHAH ALAM', 'dun': 'BATU TIGA'},
    540: {'negeri': 'SELANGOR', 'parlimen': 'KAPAR', 'dun': 'MERU'},
    541: {'negeri': 'SELANGOR', 'parlimen': 'KAPAR', 'dun': 'SEMENTA'},
    542: {'negeri': 'SELANGOR', 'parlimen': 'KAPAR', 'dun': 'SUNGAI PINANG'},
    543: {'negeri': 'SELANGOR', 'parlimen': 'KAPAR', 'dun': 'SELAT KLANG'},
    544: {'negeri': 'SELANGOR', 'parlimen': 'KLANG', 'dun': 'PELABUHAN KLANG'},
    545: {'negeri': 'SELANGOR', 'parlimen': 'KLANG', 'dun': 'PANDAMARAN'},
    546: {'negeri': 'SELANGOR', 'parlimen': 'KLANG', 'dun': 'KOTA ALAM SHAH'},
    547: {'negeri': 'SELANGOR', 'parlimen': 'KOTA RAJA', 'dun': 'SERI ANDALAS'},
    548: {'negeri': 'SELANGOR', 'parlimen': 'KOTA RAJA', 'dun': 'SRI MUDA'},
    549: {
        'negeri': 'SELANGOR',
        'parlimen': 'KUALA LANGAT',
        'dun': 'SIJANGKANG',
    },
    550: {
        'negeri': 'SELANGOR',
        'parlimen': 'KUALA LANGAT',
        'dun': 'TELUK DATUK',
    },
    551: {'negeri': 'SELANGOR', 'parlimen': 'KUALA LANGAT', 'dun': 'MORIB'},
    552: {'negeri': 'SELANGOR', 'parlimen': 'SEPANG', 'dun': 'TANJONG SEPAT'},
    553: {'negeri': 'SELANGOR', 'parlimen': 'SEPANG', 'dun': 'DENGKIL'},
    554: {'negeri': 'SELANGOR', 'parlimen': 'SEPANG', 'dun': 'SUNGAI PELEK'},
    555: {'negeri': 'TERENGGANU', 'parlimen': 'BESUT', 'dun': 'KUALA BESUT'},
    556: {'negeri': 'TERENGGANU', 'parlimen': 'BESUT', 'dun': 'KOTA PUTERA'},
    557: {'negeri': 'TERENGGANU', 'parlimen': 'BESUT', 'dun': 'JERTIH'},
    558: {'negeri': 'TERENGGANU', 'parlimen': 'BESUT', 'dun': 'HULU BESUT'},
    559: {'negeri': 'TERENGGANU', 'parlimen': 'SETIU', 'dun': 'JABI'},
    560: {'negeri': 'TERENGGANU', 'parlimen': 'SETIU', 'dun': 'PERMAISURI'},
    561: {'negeri': 'TERENGGANU', 'parlimen': 'SETIU', 'dun': 'LANGKAP'},
    562: {'negeri': 'TERENGGANU', 'parlimen': 'SETIU', 'dun': 'BATU RAKIT'},
    563: {'negeri': 'TERENGGANU', 'parlimen': 'KUALA NERUS', 'dun': 'TEPUH'},
    564: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA NERUS',
        'dun': 'TELUK PASU',
    },
    565: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA NERUS',
        'dun': 'SEBERANG TAKIR',
    },
    566: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA NERUS',
        'dun': 'BUKIT TUNGGAL',
    },
    567: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA TERENGGANU',
        'dun': 'WAKAF MEMPELAM',
    },
    568: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA TERENGGANU',
        'dun': 'BANDAR',
    },
    569: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA TERENGGANU',
        'dun': 'LADANG',
    },
    570: {
        'negeri': 'TERENGGANU',
        'parlimen': 'KUALA TERENGGANU',
        'dun': 'BATU BURUK',
    },
    571: {'negeri': 'TERENGGANU', 'parlimen': 'MARANG', 'dun': 'ALUR LIMBAT'},
    572: {'negeri': 'TERENGGANU', 'parlimen': 'MARANG', 'dun': 'BUKIT PAYUNG'},
    573: {'negeri': 'TERENGGANU', 'parlimen': 'MARANG', 'dun': 'RU RENDANG'},
    574: {
        'negeri': 'TERENGGANU',
        'parlimen': 'MARANG',
        'dun': 'PENGKALAN BERANGAN',
    },
    575: {
        'negeri': 'TERENGGANU',
        'parlimen': 'HULU TERENGGANU',
        'dun': 'TELEMUNG',
    },
    576: {
        'negeri': 'TERENGGANU',
        'parlimen': 'HULU TERENGGANU',
        'dun': 'MANIR',
    },
    577: {
        'negeri': 'TERENGGANU',
        'parlimen': 'HULU TERENGGANU',
        'dun': 'KUALA BERANG',
    },
    578: {'negeri': 'TERENGGANU', 'parlimen': 'HULU TERENGGANU', 'dun': 'AJIL'},
    579: {'negeri': 'TERENGGANU', 'parlimen': 'DUNGUN', 'dun': 'BUKIT BESI'},
    580: {'negeri': 'TERENGGANU', 'parlimen': 'DUNGUN', 'dun': 'RANTAU ABANG'},
    581: {'negeri': 'TERENGGANU', 'parlimen': 'DUNGUN', 'dun': 'SURA'},
    582: {'negeri': 'TERENGGANU', 'parlimen': 'DUNGUN', 'dun': 'PAKA'},
    583: {'negeri': 'TERENGGANU', 'parlimen': 'KEMAMAN', 'dun': 'KEMASIK'},
    584: {'negeri': 'TERENGGANU', 'parlimen': 'KEMAMAN', 'dun': 'KIJAL'},
    585: {'negeri': 'TERENGGANU', 'parlimen': 'KEMAMAN', 'dun': 'CUKAI'},
    586: {'negeri': 'TERENGGANU', 'parlimen': 'KEMAMAN', 'dun': 'AIR PUTIH'},
    587: {'negeri': 'WILAYAH PERSEKUTUAN', 'parlimen': 'KEPONG', 'dun': 'NAN'},
    588: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'WANGSA MAJU',
        'dun': 'NAN',
    },
    589: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'SEGAMBUT',
        'dun': 'NAN',
    },
    590: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'SETIAWANGSA',
        'dun': 'NAN',
    },
    591: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'TITIWANGSA',
        'dun': 'NAN',
    },
    592: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'BUKIT BINTANG',
        'dun': 'NAN',
    },
    593: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'LEMBAH PANTAI',
        'dun': 'NAN',
    },
    594: {'negeri': 'WILAYAH PERSEKUTUAN', 'parlimen': 'SEPUTEH', 'dun': 'NAN'},
    595: {'negeri': 'WILAYAH PERSEKUTUAN', 'parlimen': 'CHERAS', 'dun': 'NAN'},
    596: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'BANDAR TUN RAZAK',
        'dun': 'NAN',
    },
    597: {
        'negeri': 'WILAYAH PERSEKUTUAN',
        'parlimen': 'PUTRAJAYA',
        'dun': 'NAN',
    },
    598: {'negeri': 'WILAYAH PERSEKUTUAN', 'parlimen': 'LABUAN', 'dun': 'NAN'},
}
