topic = {
    'mahathir': [
        'tun mahathir',
        'madey',
        'dr mahathir',
        'tun m',
        'mahathir',
        'madir',
        'dr m',
        'mahathir muhamad',
    ],
    'anwar ibrahim': ['anwar ibrahim', 'anwar'],
    'najib razak': [
        'najib razak',
        'ajib',
        'pakjib',
        'pok jib',
        'pak jib',
        'najib',
        'tan sri najib',
    ],
    'pakatan harapan': ['pakatan harapan'],
    'syed saddiq': ['syed saddiq', 'syedsaddiq', 'saddiq'],
    'parti keadilan rakyat': ['parti keadilan rakyat', 'people justice party'],
    'umno': ['united malays', 'umno', 'united malays national organization'],
    'barisan nasional': ['barisan nasional'],
    'parti islam semalaysia': [
        'parti islam',
        'malaysian islamic party',
        'parti islam semalaysia',
        'parti islam malaysia',
    ],
    'nurul izzah': ['nurul izzah', 'izzah'],
    'Tunku Ismail Idris': ['tunku ismail', 'tunku ismail idris', 'tmj'],
    'pdrm': [
        'royal police malaysia',
        'polis diraja malaysia',
        'pdrm',
        'polis',
        'polis diraja',
    ],
    '1mdb': [
        '1mdb',
        '1malaysia development berhad',
        '1malaysia development',
        '1malaysia development bhd',
        'mdb',
    ],
    'makanan': [
        'kfc',
        'murtabak',
        'sate',
        'nasi',
        'nandos',
        'mcdonald',
        'mcd',
        'makanan',
        'martabak',
        'roti',
        'canai',
        'sushi king',
    ],
    'ganja': ['cannabis', 'heroin', 'weed', 'ganja'],
    'gst': ['gst', 'good service tax'],
    'malaysian chinese association': ['malaysian chinese association'],
    'democratic action party': ['democratic action party'],
    'amanah': ['national trust party', 'amanah', 'parti amanah negara'],
    'ppbm': [
        'parti pribumi bersatu malaysia',
        'ppbm',
        'malaysian united',
        'parti pribumi',
        'malaysian united indigenous party',
    ],
    'mic': [
        'malaysian indian',
        'malaysian indian congress',
        'indian congress',
        'mic',
    ],
    'kerajaan': ['gemen', 'kerajaan', 'kemen', 'gomen', 'government'],
    'pembangkang': ['opposition', 'pembangkang'],
    'tiga penjuru': ['tiga penjuru'],
    'Pilihan Raya Umum Ke-14': [
        'election',
        'ge14',
        'pilihan raya',
        'pilihan raya umum ke-14',
        'pru14',
    ],
    'Pusat Daerah Mangundi': ['pdm', 'pusat daerah mangundi', 'pusat mengundi'],
    'Tun Daim Zainuddin': [
        'daim zainuddin',
        'daim',
        'tun daim',
        'tun daim zainuddin',
    ],
    'Datuk Seri Abdul Hadi Awang': [
        'hadi',
        'datuk seri abdul hadi awang',
        'hadi awang',
    ],
    'Majlis Pakatan Harapan': ['majlis pakatan harapan'],
    'Wan Azizah': ['kak wan', 'azizah', 'wan azizah'],
    'Parti Pribumi Bersatu Malaysia': [
        'parti pribumi bersatu malaysia',
        'ppbm',
        'parti bersatu',
        'parti pribumi',
    ],
    'Datuk Seri Azmin Ali': ['azmin ali', 'datuk seri azmin ali', 'azmin'],
    'masalah air': ['air', 'masalah air', 'isu air'],
    'orang asli': [
        'perkampungan asli',
        'perkampungan orang asli',
        'orang asli',
        'tenau',
    ],
    'Datuk Johari Abdul': ['johari', 'johari abdul', 'datuk johari abdul'],
    'Tengku Razaleigh Hamzah': ['tengku razaleigh hamzah', 'razaleigh'],
    'Tan Sri Dr Rais Yatim': ['rais yatim', 'tan sri dr rais yatim'],
    'kaum cina': ['cina', 'chinese', 'kaum cina'],
    'k-pop': ['korea', 'k-pop'],
    'kaum india': ['kaum india', 'india', 'indian'],
    'rafidah aziz': ['rafidah', 'rafidah aziz'],
    'rumah mampu milik': ['rmm', 'mampu milik', 'rmmj', 'rumah mampu milik'],
    'universiti teknologi mara': [
        'universiti teknologi mara',
        'teknologi mara',
        'uitm',
    ],
    'universiti teknologi malaysia': ['utm', 'universiti teknologi malaysia'],
    'universiti malaya': ['universiti malaya'],
    'pendidikan': [
        'peruntukan',
        'pendidikan',
        'sekolah',
        'tvet',
        'untuk semua',
        'universiti',
        'asean',
        'prasekolah',
        'vokasional',
        'ilmu',
    ],
    'sekolah': ['sekolah'],
    'universiti': ['universiti'],
    'maktab rendah sains mara': ['maktab rendah sains mara'],
    'pos laju': ['pos laju', 'poslaju'],
    'hari raya': ['aidiladha', 'aidilfitri', 'hari raya'],
    'kesihatan': [
        'denggi',
        'klinik',
        'fiber',
        'kencing manis',
        'diet',
        'kanser',
        'vitamin',
        'pusat jantung',
        'kesihatan',
        'hospital',
    ],
    'kewangan': ['hutang negara', 'kewangan', 'ekonomi negara', 'bank'],
    'hutang negara': [
        'national debt',
        'malaysian debt',
        'hutang negara',
        'malaysia debt',
    ],
    'ekonomi': [
        'asia tenggara',
        'dftz',
        'pelabur',
        'ekonomi',
        'dagang',
        'modal teroka',
        'swasta',
        'magic',
        'cradle',
        'stvp',
        'map',
        'keusahawan',
        'bebas digital',
        'global',
        'ekonomi digital',
        'mycreative',
    ],
    'sosial': [
        'sosial',
        'kehidupan',
        'taraf hidup',
        'sosiologi',
        'keusahawan',
        'masyarakat',
    ],
    'politik': [
        'pru',
        'transformasi',
        'exco',
        'menteri besar',
        'kabinet',
        'jawatan',
        'debat',
        'menteri',
        'politik',
        'senator',
        'parti',
        'pemimpin',
        'undi luar',
        'calon speaker',
    ],
    'startup companies': [
        'pelabur',
        'cradle',
        'magic',
        'startup companies',
        'keusahawan sosial',
        'startup',
        'ekonomi digital',
        'mycreative',
    ],
    'felda': [
        'lembaga kemajuan tanah persekutuan',
        'federal land development authority',
        'felda global ventures',
        'felda',
    ],
    'kwsp': ['epf', 'employees provident fund', 'kwsp', 'kumpulan wang'],
    'bank malaysia': [
        'ocbc',
        'cimb',
        'citibank',
        'hsbc',
        'affin bank',
        'alliance bank',
        'bangkok bank',
        'hong leong bank',
        'ambank',
        'bank malaysia',
        'rhb',
    ],
    'bank negara': ['bank negara'],
    'perdana menteri': ['perdana menteri', 'prime minister'],
    'timbalan perdana menteri': [
        'deputy prime minister',
        'timbalan perdana menteri',
    ],
    'menteri dalam negeri': [
        'ministry of home affairs',
        'menteri dalam negeri',
    ],
    'menteri kewangan': ['menteri kewangan', 'ministry of finance', 'mof'],
    'menteri pertahanan': ['menteri pertahanan', 'minister of defence'],
    'majlis penasihat': [
        'tun daim',
        'zeti aziz',
        'council of elders',
        'ks jomo',
        'robert kuok',
        'majlis penasihat',
        'hassan merican',
    ],
    'skim peduli sihat': ['skim peduli sihat'],
    'ptptn': [
        'ptptn',
        'perbadanan tabung pendidikan tinggi nasional',
        'tabung pendidikan',
    ],
    'projek mega': ['projek mega'],
    'gaji minimum': ['gaji minimum'],
    'menyiasat skandal': [
        'korupsi kerajaan',
        'skandal bn',
        'skandal kerajaan',
        'government scandal',
        'menyiasat skandal',
    ],
    'highway tol': [
        'highway tol',
        'tol',
        'hapuskan tol',
        'harga tol',
        'kutipan tol',
    ],
    'tabung haji': ['tabung haji'],
    'tentera malaysia': [
        'tentera',
        'malaysian armed forces',
        'tentera udara',
        'tentera malaysia',
        'tentera darat',
        'tentera laut',
    ],
    'infrastruktur': [
        'luar bandar',
        'pan borneo',
        'infrastruktur',
        'lebuhraya pan borneo',
        'transformasi luar bandar',
        'belb',
        'bekalan elektrik',
        'bekalan air',
    ],
    'kos sara hidup': [
        'bantuan rakyat',
        'k1m',
        'brim',
        'kos sara hidup',
        'br1m',
        'bantuan pelajar',
    ],
    'pengangkutan awam': ['lrt', 'terminal', 'pengangkutan awam', 'bas', 'mrt'],
    'perkhidmatan awam': [
        'dasar pengambilan',
        'perkhidmatan awam',
        'oku',
        'peluang pekerjaan',
        'utc',
        'rtc',
    ],
    'wanita': ['wanita', 'talentcorp', 'dewi', 'kembali bekerja'],
    'rafizi ramli': ['rafizi', 'rafizi ramli'],
    'bersatu': ['bersatu'],
    'bernama': ['bernama'],
    'rela': ['rela', 'anggota jabatan sukarelawan malaysia'],
    'kementerian dalam negeri': ['kementerian dalam negeri', 'kdn'],
    'donald trump': ['trump', 'donald', 'donald trump'],
    'kaum melayu': ['malay', 'melayu', 'kaum melayu'],
    'Survei Institut Darul Ehsan': [
        'survei institut',
        'survei institut darul ehsan',
    ],
    'Inisiatif Peduli Rakyat': [
        'peduli rakyat',
        'ipr',
        'inisiatif peduli rakyat',
    ],
    'astro awani': ['astro', 'astro awani', 'awani'],
    'Datuk Seri Ti Lian Ker': ['ti lian', 'datuk seri ti lian ker', 'lian ker'],
    'Nga Kor Ming': ['kor ming', 'nga kor ming'],
    'Lee Kuan Yew': ['kuan yew', 'lee kuan yew'],
    'rosmah mansur': ['rosmah', 'rosmah mansur'],
    'facebook': ['fb', 'facebook'],
    '1malaysia': ['1malaysia'],
    'petronas': ['petronas'],
    'keluar parti': [
        'pemecatan ahli',
        'khianati parti',
        'khianat parti',
        'keluar parti',
    ],
    'sabotaj parti': ['sabotaj calon', 'sabotaj parti'],
    'kotak undi': ['spr', 'kotak undi', 'salah kotak'],
    'perkasa': ['pertubuhan pribumi perkasa', 'pertubuhan pribumi', 'perkasa'],
    'Tan Sri Mokhzani Mahathir': [
        'tan sri mokhzani mahathir',
        'mokhzani',
        'mokhzani mahathir',
    ],
    'teknologi': [
        'smartphone',
        'machine learning',
        'fiber optic',
        'telefon pintar',
        'big data',
        'kecerdasan buatan',
        'teknologi',
        'internet',
        'artificial intelligence',
        'iot',
        'drone',
    ],
    'internet': ['broadband', 'fiber optic', '4g', '3g', 'internet'],
    'artificial intelligence': [
        'artificial intelligence',
        'bayes',
        'machine learning',
    ],
    'humanoid': ['humanoid', 'robot', 'sofia humanoid'],
    'Rais Yatim': ['rais yatim', 'rais'],
    'Anthony Loke Siew Fook': ['anthony loke siew fook', 'loke siew'],
    'Ahli Dewan Undangan Negeri': [
        'ahli dewan undangan negeri',
        'ahli dewan undangan',
        'adun',
    ],
    '#fakenews': ['#fakenews', 'fake news', 'berita palsu'],
    'suruhanjaya pilihan raya malaysia': [
        'suruhanjaya pilihan raya',
        'spr',
        'suruhanjaya pilihan raya malaysia',
        'sprm',
    ],
    'kertas undi': ['kertas undi'],
    'KKMM': [
        'kementerian komunikasi multimedia',
        'kkmm',
        'kementerian komunikasi',
        'kementerian komunikasi dan multimedia',
    ],
    'akta pilihan raya': ['akta pilihan raya'],
    'undi pos': ['undian pos', 'pengundi pos', 'undi pos'],
    'undi rosak': ['undi rosak', '#undirosak'],
    'harga minyak': [
        'ron95',
        'harga minyak',
        'oil',
        'petrol',
        'diesel',
        'minyak',
        'ron97',
    ],
    'petrol': ['ron95', 'ron', 'petrol', 'ron97'],
    'government subsidies': ['government subsidies', 'subsidies'],
    'akademik': [
        'akademik',
        'phd',
        'ijazah',
        'sarjana',
        'degree',
        'diploma',
        'master',
    ],
    'mh370': ['mh370'],
    'kemelangan penumpang cedera': [
        'penumpang cedera',
        'kemelangan penumpang cedera',
    ],
    'kemelangan maut': ['kemelangan maut', 'maut'],
    'Recep Tayyip Erdogan': ['recep tayyip', 'recep tayyip erdogan', 'erdogan'],
    'individu penjara': ['penjara', 'individu penjara'],
    'kes rogol': ['kes rogol', 'rogol'],
    'isytihar darurat': ['isytihar darurat', 'darurat'],
    'cambridge analytica': [
        'analytica',
        'strategic communication laboratories',
        'cambridge analytica',
    ],
    'kokain': ['kokain', 'cocaine'],
    'bebas tahanan': ['tahanan', 'tahanan bebas', 'bebas tahanan'],
    'sosial media': ['fb', 'instragram', 'twitter', 'sosial media', 'facebook'],
    'twitter': ['twitter'],
    'instagram': ['instagram'],
    'mati dipukul': ['mati dipukul'],
    'pengedar dadah': ['dadah', 'pengedar dadah', 'pengedar'],
    'kematian wabak': ['ebola', 'penyakit', 'wabak', 'h1n1', 'kematian wabak'],
    'letupan bom': ['letupan bom', 'pengebom', 'bom'],
    'isu dadah': ['dadah', 'isu dadah'],
    'diesel': ['diesel'],
    'china': ['china'],
    'saudi arabia': ['arab', 'saudi arabia', 'saudi'],
    'gaji menteri': ['gaji menteri'],
    'jabatan bubar': ['jabatan bubar', 'dibubarkan', 'bubar'],
    'harakah': ['harakah'],
    'apple product': [
        'apple product',
        'macintosh',
        'airpod',
        'iphone',
        'ipad',
        'imac',
        'macbook',
        'apple',
    ],
    'iphone': ['iphone'],
    'samsung smartphone': [
        'samsung smartphone',
        'samsung galaxy',
        'samsung note',
    ],
    'huawei smartphone': [
        'huawei mate',
        'huawei nova',
        'huawei smartphone',
        'huawei honor',
        'huawei p',
    ],
    'xiaomi smartphone': ['xiaomi mi', 'xiaomi redmi', 'xiaomi smartphone'],
    'asus smartphone': ['asus smartphone', 'zenfone'],
    'oppo smartphone': ['oppo smartphone', 'oppo r', 'oppo f', 'oppo a'],
    'lenovo smartphone': [
        'lenovo phab',
        'lenovo smartphone',
        'lenovo vibe',
        'lenovo a',
    ],
    'vivo smartphone': ['vivo y', 'vivo smartphone', 'vivo v'],
    'telekom malaysia': [
        'telekom malaysia',
        'unifi',
        'streamyx',
        'telekom',
        'tm net',
        'axiata',
    ],
    'unifi': ['unifi'],
    'robert kuok': ['robert kuok', 'kuok'],
    'macc': ['macc'],
    'piala thomas': ['piala thomas'],
    'fifa': ['world cup', 'piala dunia', 'fifa'],
    'programming language': [
        'ruby',
        'programming language',
        'c++',
        'java',
        'python',
    ],
    'agama': [
        'lesbian',
        'muslim',
        'lgbt',
        'free thinker',
        'kafir',
        'agama',
        'kristian',
        'islam',
        'gay',
        'buddha',
    ],
    'lgbt': [
        'lesbian',
        'asexual',
        'lgbt',
        'gay',
        'transgender',
        'bisexual',
        'biseksual',
    ],
    'islam': ['muslim', 'kafir', 'hadis', 'syiah', 'islam', 'wahabi'],
    'masyarakat': [
        'free thinker',
        'konservatif',
        'komunis',
        'liberalisme',
        'sosialis',
        'masyarakat',
    ],
    'idealogi': [
        'idealogi',
        'konservatif',
        'liberal',
        'komunis',
        'kapitalis',
        'sosialis',
    ],
    'parlimen': ['parlimen'],
    'Pusat Transformasi Bandar': [
        'pusat transformasi bandar',
        'utc',
        'pusat transformasi',
    ],
    'gerakan': ['gerakan', 'gerakan rakyat malaysia', 'parti gerakan'],
    'institut diraja': [
        'sultan',
        'institut diraja',
        'diraja',
        'institusi diraja',
        'kerabat',
    ],
    'tsunami fitnah': [
        'bohong',
        'tsunami politik',
        'janji palsu',
        'tiada modal',
        'tsunami',
        'tsunami fitnah',
        'fitnah',
        'jual cerita',
    ],
    'makro-ekonomi': [
        'macroeconomies',
        'makroekonomi',
        'macroeconomy',
        'makro-ekonomi',
    ],
    'mikro-ekonomi': [
        'microeconomy',
        'mikroekonomi',
        'mikro-ekonomi',
        'microeconomies',
    ],
    'stock market malaysia': [
        'macroeconomic impact',
        'usdmyr',
        'stock market malaysia',
        'economic policies',
        'stock votality',
        'subsidiaries',
        'national stock',
        'bloomberg',
        'foreign investor',
        'malaysia stock market',
        'malaysia revenue',
    ],
    'government revenue': [
        'stock market',
        'government revenue',
        'credit negative',
        'subsidies',
        'fuel subsidies',
        'foreign investor',
        'tax',
        'fiscal position',
        'moody',
    ],
    'ringgit fall': [
        'power transition',
        'ringgit',
        'ekonomi',
        'malaysian economy',
        'oil related',
        'subsidies',
        'ringgit fall',
        'foreign investor',
        'shock vote',
        'tax',
        'revenue',
        'moody',
    ],
    'bloomberg': ['bloomberg'],
    'new straits times': [
        'pro-government',
        'new straits times',
        'english newspaper',
        'straits times',
        'right wing',
        'media prima',
    ],
    'the star': ['the star'],
    'malay mail': ['malay mail'],
    'median salary': [
        'monthly salary',
        'median salary',
        'department of statistics',
        'per anum',
        'overtime',
        'employee',
        'wage',
        'allowance',
    ],
    'bursa malaysia': ['bursa malaysia', 'bursa'],
    'bumiputra': ['bumi putra', 'bumiputra', 'melayu'],
    'universiti islam antarabangsa': ['universiti islam antarabangsa'],
    'baling botol': ['baling botol'],
    'child marriage': ['child marriage', 'kahwin bawah umur', 'kahwin budak'],
    'bridge city park': ['bridge city park', 'citi park'],
    'malaysia baru': ['malaysia baharu', 'malaysia baru'],
    'produk berbahaya': ['produk berbahaya'],
    'keluar parlimen': ['keluar parlimen'],
    'musim durian': ['durian', 'musim durian'],
    'world cup': ['world cup', 'fifa'],
    'rtm': ['radio televisyen malaysia', 'rtm'],
    'motogp': ['motogp'],
    'euro 2020': ['euro 2020'],
    'ask me a question': ['ask me a question'],
    'thai cave': ['thai cave'],
    'dewan rakyat': ['dewan rakyat', 'dato ariff', 'parliament house'],
    'tabung harapan': ['tabung harapan'],
    'racist': ['racist', 'perkauman'],
    'singapura': ['singapura', 'singapore'],
    'sst': ['sales and service tax', 'sales service tax', 'sst'],
    'malaysia-indonesia': ['malaysia-indonesia'],
    'gaza': ['gaza'],
    'bola sepak': ['bola sepak'],
    'sepak takraw': ['sepak takraw'],
    'isu sosma': ['isu sosma', 'sosma'],
    'isu ecrl': ['isu ecrl', 'ecrl'],
    'royalti minyak': ['royalti minyak'],
    'Jabatan Agama Islam Wilayah Persekutuan': [
        'jawi',
        'jabatan agama islam wilayah persekutuan',
    ],
    'sinar harian': ['sinar harian'],
    'reformasi': ['reformasi'],
    'kes rasuah': ['kes rasuah', 'rasuah'],
    'kewangan dan perniagaan': [
        'kewangan',
        'niaga',
        'perniagaan',
        'duit',
        'kewangan dan perniagaan',
        'wang',
    ],
    'saham dan komoditi': ['wang', 'saham', 'saham dan komoditi', 'komoditi'],
    'isu kerugian': [
        'mata wang jatuh',
        'isu kerugian',
        'saham jatuh',
        'kerugian',
    ],
    'isu bumiputera': [
        'melayu',
        'isu bumiputera',
        'bumiputera',
        'cina',
        'india',
    ],
    'alam sekitar': ['alam sekitar', 'hidupan liar', 'biodiversiti', 'hutan'],
    'isu kemiskinan': [
        'duit takde',
        'kemiskinan',
        'takda duit',
        'takde duit',
        'isu kemiskinan',
        'miskin',
        'duit takda',
    ],
    'sumber asli': [
        'emas',
        'sumber asli',
        'getah',
        'sawit',
        'timah',
        'perak',
        'besi',
        'kuprum',
    ],
}
