influencer = {
    'mahathir': [
        'tun mahathir',
        'madey',
        'dr mahathir',
        'tun m',
        'mahathir',
        'madir',
        'dr m',
        'mahathir muhamad',
    ],
    'anwar ibrahim': ['anwar ibrahim', 'anwar'],
    'najib razak': [
        'najib razak',
        'ajib',
        'pakjib',
        'pok jib',
        'pak jib',
        'najib',
        'tan sri najib',
    ],
    'pakatan harapan': ['harapan', 'pakatan harapan', 'pakatan'],
    'syed saddiq': ['syed saddiq', 'syedsaddiq', 'syed', 'saddiq'],
    'parti keadilan rakyat': [
        'parti keadilan rakyat',
        'people justice party',
        'pkr',
    ],
    'umno': ['united malays', 'umno', 'united malays national organization'],
    'barisan nasional': ['bn', 'barisan nasional'],
    'parti islam semalaysia': [
        'parti islam',
        'malaysian islamic party',
        'parti islam semalaysia',
        'parti islam malaysia',
    ],
    'nurul izzah': ['nurul izzah', 'izzah'],
    'Tunku Ismail Idris': ['tunku ismail', 'tunku ismail idris', 'tmj'],
    'mca': ['malaysian chinese association', 'mca'],
    'democratic action party': ['democratic action party'],
    'parti amanah': [
        'national trust party',
        'amanah',
        'parti amanah',
        'parti amanah negara',
    ],
    'ppbm': [
        'parti pribumi bersatu malaysia',
        'ppbm',
        'malaysian united',
        'parti pribumi',
        'malaysian united indigenous party',
    ],
    'mic': [
        'malaysian indian',
        'malaysian indian congress',
        'indian congress',
        'mic',
    ],
    'Tun Daim Zainuddin': [
        'daim zainuddin',
        'daim',
        'tun daim',
        'tun daim zainuddin',
    ],
    'datuk seri abdul hadi awang': [
        'hadi',
        'datuk seri abdul hadi awang',
        'hadi awang',
    ],
    'majlis pakatan harapan': ['majlis pakatan harapan'],
    'wan azizah': ['kak wan', 'azizah', 'wan azizah'],
    'Parti Pribumi Bersatu Malaysia': [
        'parti pribumi bersatu malaysia',
        'ppbm',
        'parti bersatu',
        'parti pribumi',
    ],
    'Datuk Seri Azmin Ali': ['azmin ali', 'datuk seri azmin ali', 'azmin'],
    'Datuk Johari Abdul': ['johari', 'johari abdul', 'datuk johari abdul'],
    'Tengku Razaleigh Hamzah': ['tengku razaleigh hamzah', 'razaleigh'],
    'Tan Sri Dr Rais Yatim': ['rais yatim', 'tan sri dr rais yatim'],
    'rafizi ramli': ['rafizi', 'rafizi ramli'],
    'bersatu': ['bersatu'],
    'bernama': ['bernama'],
    'donald trump': ['trump', 'donald', 'donald trump'],
    'perkasa': ['pertubuhan pribumi perkasa', 'pertubuhan pribumi', 'perkasa'],
    'Tan Sri Mokhzani Mahathir': [
        'tan sri mokhzani mahathir',
        'mokhzani',
        'mokhzani mahathir',
    ],
    'Rais Yatim': ['rais yatim', 'rais'],
    'Anthony Loke Siew Fook': ['anthony loke siew fook', 'loke siew'],
    'rosmah mansur': ['rosmah', 'rosmah mansur'],
    'arul kanda': ['arul kanda', 'kanda'],
    'manchester united': ['manchester', 'manchester united'],
    'arsenal fc': ['arsenal fc', 'arsenal'],
    'liverpool fc': ['liverpool fc', 'liverpool'],
    'chelsea fc': ['chelsea', 'chelsea fc'],
    'manchester city': ['manchester city'],
    'fc barcelona': ['barcelona', 'fc barcelona'],
    'real madrid cf': ['madrid', 'real madrid', 'real madrid cf'],
    'fc bayern munich': ['bayern munich', 'fc bayern munich'],
    'juventus fc': ['juventus fc', 'juventus'],
    'zeti aziz': ['zeti aziz'],
    'robert kuok': ['robert kuok'],
    'hassan merican': ['hassan merican'],
    'ks jomo': ['ks jomo'],
    'jho low': ['jho low'],
    'kadir jasin': ['kadir jasin'],
    'zakir naik': ['zakir naik'],
    'bung mokhtar': ['bung mokhtar'],
    'shafie apdal': ['shafie apdal'],
    'ariff md yusof': ['ariff yusof', 'datuk ariff md yusof', 'ariff md yusof'],
    'felda': ['felda'],
    'dato vida': ['vida', 'dato vida'],
    'Jabatan Perancangan Bandar dan Desa': [
        'jabatan perancangan bandar dan desa'
    ],
}
