calon = {
    0: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 1,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK ZAHIDI BIN ZAINUL ABIDIN',
        'parti': 'BN',
    },
    1: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 1,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOKHTAR BIN SENIK',
        'parti': 'PAS',
    },
    2: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 1,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'IZIZAM BIN IBRAHIM',
        'parti': 'PKR',
    },
    3: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 101,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEH CHAI ANN',
        'parti': 'BN',
    },
    4: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 101,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TEH SENG CHUAN',
        'parti': 'PKR',
    },
    5: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 101,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KAMIS BIN HJ YUB',
        'parti': 'PAS',
    },
    6: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 101,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YAACOB BIN MAN',
        'parti': 'BEBAS',
    },
    7: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 102,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RUZAINI BIN RAIS',
        'parti': 'BN',
    },
    8: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 102,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZAMHARI BIN MOHAMOOD',
        'parti': 'PAS',
    },
    9: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 102,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN KHARIZAL BIN WAN KHAZIM',
        'parti': 'PKR',
    },
    10: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 103,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ASMAIZA BINTI AHMAD',
        'parti': 'BN',
    },
    11: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 103,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'POZIYAH BINTI HAMZAH',
        'parti': 'PKR',
    },
    12: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 103,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ALI BIN PUTEH',
        'parti': 'PAS',
    },
    13: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 104,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SITI BERENEE BT YAHAYA',
        'parti': 'BN',
    },
    14: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 104,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZHAR BIN OMAR',
        'parti': 'PKR',
    },
    15: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 104,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMMAD BIN YAHYA',
        'parti': 'PAS',
    },
    16: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 105,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZIZAN BIN SULAIMAN',
        'parti': 'BN',
    },
    17: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 105,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHE MAZLINA BT CHE YOB',
        'parti': 'PKR',
    },
    18: {
        'KodN': 1,
        'KodParlimen': 1,
        'KodKawasan': 105,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BAHARUDDIN BIN AHMAD',
        'parti': 'PAS',
    },
    19: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 2,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AMIN BIN AHMAD',
        'parti': 'PKR',
    },
    20: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 2,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZAHID BIN IBRAHIM',
        'parti': 'PAS',
    },
    21: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 2,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RAMLI BIN SHARIF',
        'parti': 'BN',
    },
    22: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 206,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' SERI AZLAN BIN MAN",
        'parti': 'BN',
    },
    23: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 206,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOKHTAR BIN CHE KASSIM',
        'parti': 'PKR',
    },
    24: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 206,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL JAMIL BIN KAMIS',
        'parti': 'PAS',
    },
    25: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 207,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FAKHRUL ANWAR BIN ISMAIL',
        'parti': 'PAS',
    },
    26: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 207,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "AZIHANI BINTI DATO' ALI",
        'parti': 'BN',
    },
    27: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 207,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ASRUL NIZAN BIN ABDUL JALIL',
        'parti': 'PKR',
    },
    28: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 208,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GAN AY LING',
        'parti': 'PKR',
    },
    29: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 208,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHUAH TIAN HEE',
        'parti': 'BN',
    },
    30: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 208,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN HASAN BIN ISMAIL',
        'parti': 'PAS',
    },
    31: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 209,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD FUAT BIN HJ ABU',
        'parti': 'PAS',
    },
    32: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 209,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZAM BIN KARAP',
        'parti': 'PKR',
    },
    33: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 209,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK AZAM BIN RASHID',
        'parti': 'BN',
    },
    34: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 210,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAMIZAN BIN HASSAN',
        'parti': 'BN',
    },
    35: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 210,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD HANNAAN BIN KHAIRY',
        'parti': 'PKR',
    },
    36: {
        'KodN': 1,
        'KodParlimen': 2,
        'KodKawasan': 210,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MD RADZI BIN HASSAN',
        'parti': 'PAS',
    },
    37: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 3,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SERI DR. SHAHIDAN BIN KASSIM",
        'parti': 'BN',
    },
    38: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 3,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'PROF. DATO DR. ABDUL RAHMAN BIN DAUD',
        'parti': 'PKR',
    },
    39: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 3,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HAJI HASHIM BIN  JASIN',
        'parti': 'PAS',
    },
    40: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 311,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROZIEANA BINTI AHMAD',
        'parti': 'BN',
    },
    41: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 311,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAJI AMIER BIN HASSAN ',
        'parti': 'PKR',
    },
    42: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 311,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJI IDRIS BIN YAAKOB',
        'parti': 'PAS',
    },
    43: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 312,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ISMAIL BIN KASSIM',
        'parti': 'BN',
    },
    44: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 312,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MATON BIN DIN ',
        'parti': 'PKR',
    },
    45: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 312,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. A BAKAR BIN ALI',
        'parti': 'PAS',
    },
    46: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 313,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AFIFI BIN OSMAN',
        'parti': 'BN',
    },
    47: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 313,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'BARIDAH BINTI NAYAN',
        'parti': 'PKR',
    },
    48: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 313,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD RIDZUAN BIN HASHIM',
        'parti': 'PAS',
    },
    49: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 314,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "RUS'SELE BIN EIZAN",
        'parti': 'PAS',
    },
    50: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 314,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NURULHISHAM BIN YAAKOB',
        'parti': 'BN',
    },
    51: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 314,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. WAN NORALHAKIM SHAGHIR BIN SAAD',
        'parti': 'PKR',
    },
    52: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 315,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZOLKARNAIN BIN ABIDIN',
        'parti': 'PKR',
    },
    53: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 315,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SHUKRI BIN RAMLI',
        'parti': 'PAS',
    },
    54: {
        'KodN': 1,
        'KodParlimen': 3,
        'KodKawasan': 315,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHE ZAIDI BIN SAIDIN',
        'parti': 'BN',
    },
    55: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 4,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'mahathir',
        'parti': 'PKR',
    },
    56: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 4,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ZUBIR BIN AHMAD',
        'parti': 'PAS',
    },
    57: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 4,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' IR. HJ NAWAWI BIN HJ AHMAD",
        'parti': 'BN',
    },
    58: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 401,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZLINA BINTI AZINAN',
        'parti': 'PAS',
    },
    59: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 401,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' HJ. RAWI BIN HJ. ABD HAMID",
        'parti': 'BN',
    },
    60: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 401,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JUHARI BIN BULAT',
        'parti': 'PKR',
    },
    61: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 402,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NORSAIDI BIN HJ. NANYAN',
        'parti': 'BN',
    },
    62: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 402,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MAZLAN BIN AHMAD',
        'parti': 'PAS',
    },
    63: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 402,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD RATU BIN MANSOR',
        'parti': 'BEBAS',
    },
    64: {
        'KodN': 2,
        'KodParlimen': 4,
        'KodKawasan': 402,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD FIRDAUS BIN AHMAD',
        'parti': 'PKR',
    },
    65: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 5,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO’ WIRA OTHMAN BIN HJ AZIZ',
        'parti': 'BN',
    },
    66: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 5,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SERI MUKHRIZ BIN MAHATHIR",
        'parti': 'PKR',
    },
    67: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 5,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ABDUL GHANI BIN AHMAD',
        'parti': 'PAS',
    },
    68: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 503,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD AZHAR BIN ABDULLAH',
        'parti': 'BN',
    },
    69: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 503,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD REJAB BIN MD AKHIR',
        'parti': 'PAS',
    },
    70: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 503,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR SALMEE T SAID',
        'parti': 'PKR',
    },
    71: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 504,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO’ HJ ABU HASAN BIN SARIF',
        'parti': 'BN',
    },
    72: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 504,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' A. AZIZ BIN MOHAMOD",
        'parti': 'PKR',
    },
    73: {
        'KodN': 2,
        'KodParlimen': 5,
        'KodKawasan': 504,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZHAR BIN IBRAHIM',
        'parti': 'PAS',
    },
    74: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 6,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' SRI MOHD JOHARI BIN BAHARUM",
        'parti': 'BN',
    },
    75: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 6,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' AMIRUDDIN HAMZAH",
        'parti': 'PKR',
    },
    76: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 6,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NORHAFIZA BINTI FADZIL',
        'parti': 'PAS',
    },
    77: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 605,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HABSHAH BINTI BAKAR',
        'parti': 'PAS',
    },
    78: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 605,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJAH HALIMATON SHAADIAH BINTI SAAD',
        'parti': 'PKR',
    },
    79: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 605,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HAJI AHMAD ZAINI JAPAR",
        'parti': 'BN',
    },
    80: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 606,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZULHAZMI BIN OSMAN',
        'parti': 'PAS',
    },
    81: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 606,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' SERI HJ MUKHRIZ TUN MAHATHIR",
        'parti': 'PKR',
    },
    82: {
        'KodN': 2,
        'KodParlimen': 6,
        'KodKawasan': 606,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' AMINUDDIN BIN OMAR ",
        'parti': 'BN',
    },
    83: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 7,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MAHDZIR BIN KHALID',
        'parti': 'BN',
    },
    84: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 7,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD AZAM BIN ABD MAJID',
        'parti': 'PAS',
    },
    85: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 7,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD KHAIRIZAL BIN KHAZALI',
        'parti': 'PKR',
    },
    86: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 707,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BADROL HISHAM BIN HASHIM',
        'parti': 'BN',
    },
    87: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 707,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD YUSSOF BIN ZAKARIA',
        'parti': 'PAS',
    },
    88: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 707,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SYED FADZIL BIN SYED EMBUN',
        'parti': 'PKR',
    },
    89: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 708,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KAMA NORIAH BINTI IBRAHIM',
        'parti': 'BN',
    },
    90: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 708,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD RADZI BIN AMIN',
        'parti': 'PAS',
    },
    91: {
        'KodN': 2,
        'KodParlimen': 7,
        'KodKawasan': 708,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HASHIM BIN IDRIS',
        'parti': 'PKR',
    },
    92: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 8,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO SAID ALI BIN SYED ROSTAN',
        'parti': 'BN',
    },
    93: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 8,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HJ RADHI BIN MAT DIN',
        'parti': 'PAS',
    },
    94: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 8,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO MAHFUZ BIN OMAR',
        'parti': 'PKR',
    },
    95: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 809,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO ARIFFIN BIN MAN',
        'parti': 'BN',
    },
    96: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 809,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SALIM BIN MAHMOOD AL HAFIZ',
        'parti': 'PAS',
    },
    97: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 809,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD AIZAD BIN ROSLAN',
        'parti': 'PKR',
    },
    98: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 809,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DATO MOHD ISMAIL BIN HJ OTHMAN',
        'parti': 'BEBAS',
    },
    99: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 810,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR MOHAMMAD NAWAR BIN ARIFFIN',
        'parti': 'BN',
    },
    100: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 810,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHE MAT DZAHED BIN AHMAD',
        'parti': 'PKR',
    },
    101: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 810,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN ROMANI BIN WAN SALIM',
        'parti': 'PAS',
    },
    102: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 811,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO DR CHEAH SOON HAI',
        'parti': 'BN',
    },
    103: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 811,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YAHYA BIN SAAD',
        'parti': 'PAS',
    },
    104: {
        'KodN': 2,
        'KodParlimen': 8,
        'KodKawasan': 811,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN KOK YEW',
        'parti': 'PKR',
    },
    105: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 9,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD AMINUL SHAFIQ BIN MOHD ABDUH',
        'parti': 'PAS',
    },
    106: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 9,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CHAN MING KAI',
        'parti': 'PKR',
    },
    107: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 9,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO YOO WEI HOW',
        'parti': 'BN',
    },
    108: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 912,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SABRI OMAR',
        'parti': 'PAS',
    },
    109: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 912,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO SERI DIRAJA AHMAD BASHAH BIN HANIPAH',
        'parti': 'BN',
    },
    110: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 912,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'IR ZAMBRI YUSUF ',
        'parti': 'PKR',
    },
    111: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 913,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZULKIFLI CHE HARON',
        'parti': 'PAS',
    },
    112: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 913,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN ENG HWA',
        'parti': 'BN',
    },
    113: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 913,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEH SWEE LEUNG',
        'parti': 'PKR',
    },
    114: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 913,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TAN KANG YAP',
        'parti': 'PRM',
    },
    115: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 914,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD BIN SAAD@YAHYA',
        'parti': 'PAS',
    },
    116: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 914,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL MALIK SAAD',
        'parti': 'BN',
    },
    117: {
        'KodN': 2,
        'KodParlimen': 9,
        'KodKawasan': 914,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PHAHROLRAZI BIN MOHD ZAWAWI',
        'parti': 'PKR',
    },
    118: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 10,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUHAMAD RIDUAN BIN OTHMAN',
        'parti': 'PAS',
    },
    119: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 10,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABDULLAH HASNAN BIN KAMARUDDIN',
        'parti': 'BN',
    },
    120: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 10,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR.AZMAN BIN ISMAIL',
        'parti': 'PKR',
    },
    121: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1015,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAMDI BIN ISHAK',
        'parti': 'PAS',
    },
    122: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1015,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JOHARI BIN AZIZ',
        'parti': 'BN',
    },
    123: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1015,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'IR AMIRUDDIN BIN HAMZAH',
        'parti': 'PKR',
    },
    124: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1016,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'OMAR BIN SAAD',
        'parti': 'PAS',
    },
    125: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1016,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL MUTALIB BIN HARUN',
        'parti': 'BN',
    },
    126: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1016,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ASMIRUL ANUAR BIN ARIS',
        'parti': 'PKR',
    },
    127: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1017,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR.ISMAIL BIN SALLEH',
        'parti': 'PKR',
    },
    128: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1017,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR.AHMAD FAKHRUDDIN BIN FAKHRURAZI',
        'parti': 'PAS',
    },
    129: {
        'KodN': 2,
        'KodParlimen': 10,
        'KodKawasan': 1017,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL HALIM BIN SAID',
        'parti': 'BN',
    },
    130: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 11,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' WIRA OTHMAN BIN ABDUL",
        'parti': 'BN',
    },
    131: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 11,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AWANG BIN HASHIM',
        'parti': 'PAS',
    },
    132: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 11,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WAN SAIFULRUDDIN BIN WAN JAN',
        'parti': 'PKR',
    },
    133: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 11,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'ABDUL MALEK BIN ABDUL MANAF',
        'parti': 'BEBAS',
    },
    134: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1118,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ AHMAD FATAHI BIN OMAR',
        'parti': 'BN',
    },
    135: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1118,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO'DR MOHD HAYATI BIN OTHMAN",
        'parti': 'PAS',
    },
    136: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1118,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD FIRDAUS BIN JAAFAR',
        'parti': 'PKR',
    },
    137: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1119,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATO HJH SURAYA BINTI YAACOB',
        'parti': 'BN',
    },
    138: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1119,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAIFUL SYAZWAN BIN SHAFIE',
        'parti': 'PAS',
    },
    139: {
        'KodN': 2,
        'KodParlimen': 11,
        'KodKawasan': 1119,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL RAZAK BIN KHAMIS',
        'parti': 'PKR',
    },
    140: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 12,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'USTAZ SABRI BIN AZIT',
        'parti': 'PAS',
    },
    141: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 12,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' SERI JAMIL KHIR BIN BAHAROM",
        'parti': 'BN',
    },
    142: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 12,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AKHRAMSYAH MUAMAR UBAIDIAH BIN TANSRI SANUSI',
        'parti': 'PKR',
    },
    143: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1220,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NOHD AZAM BIN ABD SAMAT',
        'parti': 'PAS',
    },
    144: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1220,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "ZAHRAN BIN DATO' HJ ABDULLAH",
        'parti': 'PKR',
    },
    145: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1220,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HJH NORMA BINTI AWANG",
        'parti': 'BN',
    },
    146: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1221,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUSODDAK BIN HAJI AHMAD',
        'parti': 'PAS',
    },
    147: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1221,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SAFFUAN BIN SABARI',
        'parti': 'PKR',
    },
    148: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1221,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' WIRA DR KU ABD RAHMAN BIN KU ISMAIL",
        'parti': 'BN',
    },
    149: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1222,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUZANI BIN AZIZAN',
        'parti': 'PAS',
    },
    150: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1222,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' JOHARI BIN ABDUL",
        'parti': 'PKR',
    },
    151: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1222,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' BOEY CHIN GAN",
        'parti': 'BN',
    },
    152: {
        'KodN': 2,
        'KodParlimen': 12,
        'KodKawasan': 1222,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'PALANIAPPAN A/L MARIMUTHU',
        'parti': 'BEBAS',
    },
    153: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 13,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MANSOR BIN ABD RAHMAN',
        'parti': 'BN',
    },
    154: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 13,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AHMAD TARMIZI BIN SULAIMAN',
        'parti': 'PAS',
    },
    155: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 13,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AZLI BIN UDA',
        'parti': 'PKR',
    },
    156: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1323,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD TAJUDIN BIN ABDULLAH',
        'parti': 'BN',
    },
    157: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1323,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ISA BIN SHAFIE',
        'parti': 'PAS',
    },
    158: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1323,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL RASHID BIN ABDULLAH',
        'parti': 'PKR',
    },
    159: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1324,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD NAZRI BIN ABU HASSAN',
        'parti': 'PKR',
    },
    160: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1324,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MAHADZIR BIN ABDUL HAMID',
        'parti': 'BN',
    },
    161: {
        'KodN': 2,
        'KodParlimen': 13,
        'KodKawasan': 1324,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD SANUSI BIN MD NOR',
        'parti': 'PAS',
    },
    162: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 14,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NOR AZRINA BINTI SURIP',
        'parti': 'PKR',
    },
    163: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 14,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO HAJI TAJUL URUS BIN HAJI MAT ZAIN',
        'parti': 'BN',
    },
    164: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 14,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AHMAD FAUZI BIN RAMLI',
        'parti': 'PAS',
    },
    165: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1425,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'R SUMMUGAM A/L RENGASAMY',
        'parti': 'PKR',
    },
    166: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1425,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JASPAL SINGH A/L GURBAKHES SINGH',
        'parti': 'BN',
    },
    167: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1425,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAJI MOHD ALI BIN SULAIMAN',
        'parti': 'PAS',
    },
    168: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1426,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ANNUAR BIN AHMAD',
        'parti': 'BN',
    },
    169: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1426,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HANIF BIN GHAZALI',
        'parti': 'PAS',
    },
    170: {
        'KodN': 2,
        'KodParlimen': 14,
        'KodKawasan': 1426,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MEJAR (B) ANUAR BIN ABDUL HAMID',
        'parti': 'PKR',
    },
    171: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 15,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO JOHARI BIN ABDUL',
        'parti': 'PKR',
    },
    172: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 15,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SHARIR BIN LONG',
        'parti': 'PAS',
    },
    173: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 15,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO SHAHANIM BINTI MOHAMAD YUSOFF',
        'parti': 'BN',
    },
    174: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 15,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'SRITHARAN A/L PICHATU',
        'parti': 'PRM',
    },
    175: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1527,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROSLI BIN YUSUF',
        'parti': 'PKR',
    },
    176: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1527,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD FADZLI BIN HASHIM',
        'parti': 'PAS',
    },
    177: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1527,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATO ALI BIN YAHAYA',
        'parti': 'BN',
    },
    178: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1528,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN HOCK HUAT',
        'parti': 'BEBAS',
    },
    179: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1528,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'OTHMAN BIN CHE MEE',
        'parti': 'PAS',
    },
    180: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1528,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SIMON OOI TZE MIN',
        'parti': 'PKR',
    },
    181: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1528,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'KO HUNG WENG',
        'parti': 'BN',
    },
    182: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1528,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'TAN KEE CHYE',
        'parti': 'PRM',
    },
    183: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1529,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR ROBERT LING KUI EE',
        'parti': 'PKR',
    },
    184: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1529,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NURHIDAYAH FOO BINTI ABDULLAH',
        'parti': 'PAS',
    },
    185: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1529,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN KOK SEONG',
        'parti': 'BN',
    },
    186: {
        'KodN': 2,
        'KodParlimen': 15,
        'KodKawasan': 1529,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD HASHIM BIN SAALUDIN',
        'parti': 'PRM',
    },
    187: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 16,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ABDUL AZEEZ BIN ABDUL RAHIM',
        'parti': 'BN',
    },
    188: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 16,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HASSAN BIN SAAD',
        'parti': 'PAS',
    },
    189: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 16,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHD TAUFIK BIN YAACOB',
        'parti': 'PKR',
    },
    190: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1630,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED NOOR BIN MOHAMED AMIN',
        'parti': 'BN',
    },
    191: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1630,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD NASIR BIN IDRIS',
        'parti': 'PAS',
    },
    192: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1630,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABD RAHIM BIN KECHIK@WAN CHIK',
        'parti': 'PKR',
    },
    193: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1631,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HARUN BIN ABUL AZIZ',
        'parti': 'BN',
    },
    194: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1631,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JOHARI BIN ABDULLAH',
        'parti': 'PKR',
    },
    195: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1631,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NAJMI BIN AHMAD',
        'parti': 'PAS',
    },
    196: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1632,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHAIRUL AZHAR BIN ABDULLAH',
        'parti': 'BN',
    },
    197: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1632,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MANSOR BIN ZAKARIA',
        'parti': 'PAS',
    },
    198: {
        'KodN': 2,
        'KodParlimen': 16,
        'KodKawasan': 1632,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD SOFEE BIN RAZAK',
        'parti': 'PKR',
    },
    199: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 17,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUHAMAD SOBRI BIN OSMAN',
        'parti': 'PAS',
    },
    200: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 17,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'LEONG YONG KONG ',
        'parti': 'BN',
    },
    201: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 17,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KARUPAIYA A/L MUTUSAMI',
        'parti': 'PKR',
    },
    202: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1733,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ASMADI BIN ABU TALIB',
        'parti': 'BN',
    },
    203: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1733,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO SITI ASHAH BINTI GHAZALI',
        'parti': 'PAS',
    },
    204: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1733,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABD RAZAK BIN SALLEH',
        'parti': 'PKR',
    },
    205: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1734,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZMAN BIN NASRUDIN',
        'parti': 'PKR',
    },
    206: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1734,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD TAUFIQ BIN BAHARUM',
        'parti': 'PAS',
    },
    207: {
        'KodN': 2,
        'KodParlimen': 17,
        'KodKawasan': 1734,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'THURAISINGAM A/L K.S MUTHU',
        'parti': 'BN',
    },
    208: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 18,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' ABD AZIZ BIN HJ SHEIKH FADZIR",
        'parti': 'BN',
    },
    209: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 18,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SAIFUDDIN NASUTION ISMAIL",
        'parti': 'PKR',
    },
    210: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 18,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'USTAZ HASSAN RAZAK',
        'parti': 'PAS',
    },
    211: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 1835,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHUA THIONG GEE',
        'parti': 'BN',
    },
    212: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 1835,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHAIRI SALLEH',
        'parti': 'PAS',
    },
    213: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 1836,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' NORSABRINA BINTI MOHD NOOR",
        'parti': 'BN',
    },
    214: {
        'KodN': 2,
        'KodParlimen': 18,
        'KodKawasan': 1836,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' AZIMI BIN DAIM",
        'parti': 'PKR',
    },
    215: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 19,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK WAN JOHANI BIN WAN HUSSIN',
        'parti': 'BN',
    },
    216: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 19,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO HJ CHE ABDULLAH B MAT NAWI',
        'parti': 'PAS',
    },
    217: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 19,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK HJ NORDIN BIN SALLEH',
        'parti': 'PKR',
    },
    218: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1901,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ MAT RAZI BIN MAT AIL',
        'parti': 'BN',
    },
    219: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1901,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ WAN ROSLAN BIN WAN HAMAT',
        'parti': 'PAS',
    },
    220: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1901,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATO WAN ROSDI BIN RASIK',
        'parti': 'PKR',
    },
    221: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1902,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NIK FAIZAH BT NIK OTHMAN',
        'parti': 'PKR',
    },
    222: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1902,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HASHIM BIN MOHAMAD',
        'parti': 'BN',
    },
    223: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1902,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ ADNAN BIN HASSAN',
        'parti': 'PAS',
    },
    224: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1903,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO BENTARA KANAN HJ AHMAD BIN YAKOB',
        'parti': 'PAS',
    },
    225: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1903,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN JOHARI BIN WAN OMAR',
        'parti': 'PKR',
    },
    226: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1903,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN MOHD SANUSI BIN WAN YUNUS',
        'parti': 'BN',
    },
    227: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1904,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHIR ZAHRI BIN ABDUL GHANI',
        'parti': 'PKR',
    },
    228: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1904,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ ROSLI BIN ABDULLAH',
        'parti': 'PAS',
    },
    229: {
        'KodN': 3,
        'KodParlimen': 19,
        'KodKawasan': 1904,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HJ MOHD ROSDI B AB AZIZ',
        'parti': 'BN',
    },
    230: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 20,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD BIN IBRAHIM',
        'parti': 'PKR',
    },
    231: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 20,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AHMAD MARZUK BIN SHAARY',
        'parti': 'PAS',
    },
    232: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 20,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ZALUZI BIN SULAIMAN',
        'parti': 'BN',
    },
    233: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2005,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NIK AZMI BIN NIK MAN@NIK OSMAN',
        'parti': 'PKR',
    },
    234: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2005,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN SHAHRUL AZUAN BIN WAN AB AZIZ',
        'parti': 'BN',
    },
    235: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2005,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'IZANI BIN HUSIN',
        'parti': 'PAS',
    },
    236: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2006,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED FAREEZ BIN NOOR AMRAN ',
        'parti': 'BN',
    },
    237: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2006,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD FATHAN BIN MAHMOOD @ MAHAMAD',
        'parti': 'PAS',
    },
    238: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2006,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NIK OMAR BIN NIK AB. AZIZ',
        'parti': 'PKR',
    },
    239: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2007,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD AMAR BIN ABDULLAH',
        'parti': 'PAS',
    },
    240: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2007,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZARINA BINTI EUSOPE',
        'parti': 'BN',
    },
    241: {
        'KodN': 3,
        'KodParlimen': 20,
        'KodKawasan': 2007,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZULHAZMI BIN HASSAN',
        'parti': 'PKR',
    },
    242: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 21,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'FIKHRAN HAMSHI BIN MOHAMAD FATMI',
        'parti': 'BN',
    },
    243: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 21,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HUSAM BIN MUSA',
        'parti': 'PKR',
    },
    244: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 21,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TAKIYUDDIN BIN HASSAN',
        'parti': 'PAS',
    },
    245: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2108,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MADIHAH BINTI ABDUL AZIZ',
        'parti': 'BN',
    },
    246: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2108,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAFIDZAH BIN MUSTAKIM',
        'parti': 'PKR',
    },
    247: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2108,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROHANI BINTI IBRAHIM',
        'parti': 'PAS',
    },
    248: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2109,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHUA HOCK KUAN',
        'parti': 'BN',
    },
    249: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2109,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ANUAR TAN BIN ABDULLAH',
        'parti': 'PAS',
    },
    250: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2109,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL RASHID BIN RAHMAN',
        'parti': 'PKR',
    },
    251: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2110,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SANUSI BIN OTHMAN',
        'parti': 'PKR',
    },
    252: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2110,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED HASNAN BIN CHE HUSSIN',
        'parti': 'BN',
    },
    253: {
        'KodN': 3,
        'KodParlimen': 21,
        'KodKawasan': 2110,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR RAMLI BIN MAMAT',
        'parti': 'PAS',
    },
    254: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 22,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NOR AZMAWI BIN AB RAHMAN',
        'parti': 'BN',
    },
    255: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 22,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AHMAD FADHLI BIN SHAARI',
        'parti': 'PAS',
    },
    256: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 22,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' PADUKA HJ DR IBRAHIM BIN ALI",
        'parti': 'BEBAS',
    },
    257: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 22,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'CHE UJANG BIN CHE DAUD',
        'parti': 'PKR',
    },
    258: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2211,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "DATO' YAHAYA BIN MAMAT",
        'parti': 'BN',
    },
    259: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2211,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROZI BIN MOHAMAD',
        'parti': 'PAS',
    },
    260: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2211,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR WAN ZUKHAIRY BIN WAN ZAIN',
        'parti': 'PKR',
    },
    261: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2211,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' PADUKA HJ DR IBRAHIM BIN ALI",
        'parti': 'BEBAS',
    },
    262: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2212,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DR SYA'RANI BIN MOHD NAIM",
        'parti': 'PKR',
    },
    263: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2212,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHE JOHAN BIN CHE PA',
        'parti': 'BN',
    },
    264: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2212,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "DATO' HJ HANIFA BIN AHMAD",
        'parti': 'PAS',
    },
    265: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2212,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'IR SUHARTO BIN MAT NASIR',
        'parti': 'BEBAS',
    },
    266: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2213,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'AHMAD ANUAR BIN HUSIN',
        'parti': 'BN',
    },
    267: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2213,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' HJ MOHD NASSURRUDIN",
        'parti': 'PAS',
    },
    268: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2213,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ROMIZU BIN ALI',
        'parti': 'PKR',
    },
    269: {
        'KodN': 3,
        'KodParlimen': 22,
        'KodKawasan': 2213,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHE DAUD BIN CHE MAN',
        'parti': 'BEBAS',
    },
    270: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 23,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABDULLAH BIN MAT YASIM',
        'parti': 'BN',
    },
    271: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 23,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ZAILAH BINTI MOHD YUSOFF',
        'parti': 'PAS',
    },
    272: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 23,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WAN SHAH JIHAN BIN WAN DIN',
        'parti': 'PKR',
    },
    273: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2314,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD AFIFI BIN MUHAMMAD NOOR',
        'parti': 'BN',
    },
    274: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2314,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ZURAIDIN BIN ABDULLAH',
        'parti': 'PAS',
    },
    275: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2314,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ALI ABDU RAHMAN BIN HASAN',
        'parti': 'PKR',
    },
    276: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2314,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAKARIA BIN HASSAN',
        'parti': 'BEBAS',
    },
    277: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2315,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GHAZALI BIN ISMAIL',
        'parti': 'BN',
    },
    278: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2315,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD RIDZUAN BIN MUHAMAD',
        'parti': 'PKR',
    },
    279: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2315,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD BIN AWANG',
        'parti': 'PAS',
    },
    280: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2316,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AKBAR BIN SALIM',
        'parti': 'BN',
    },
    281: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2316,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL RASUL BIN MOHAMED',
        'parti': 'PAS',
    },
    282: {
        'KodN': 3,
        'KodParlimen': 23,
        'KodKawasan': 2316,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD HISYAMUDDIN BIN GHAZALI',
        'parti': 'PKR',
    },
    283: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 24,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO SRI MUHAMMAD BIN ABDUL GHANI',
        'parti': 'BN',
    },
    284: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 24,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TUAN IBRAHIM B. TUAN MAN',
        'parti': 'PAS',
    },
    285: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 24,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR ABDUL HALIM B YUSOF',
        'parti': 'PKR',
    },
    286: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2417,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD NOORDIN BIN HAJI AWANG',
        'parti': 'BN',
    },
    287: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2417,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAIFUL ADLI B ABU BAKAR',
        'parti': 'PAS',
    },
    288: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2417,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HUSAM B MUSA',
        'parti': 'PKR',
    },
    289: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2418,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BAKRI BIN YUSOFF',
        'parti': 'BN',
    },
    290: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2418,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL RAHMAN B YUNUS',
        'parti': 'PAS',
    },
    291: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2418,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD NOR YAZID',
        'parti': 'PKR',
    },
    292: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2419,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NURUL AMAL BIN MOHD FAUZI',
        'parti': 'BN',
    },
    293: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2419,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN AHMAD KAMIL ABDULLAH',
        'parti': 'PKR',
    },
    294: {
        'KodN': 3,
        'KodParlimen': 24,
        'KodKawasan': 2419,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUMTAZ BT MD NAWI',
        'parti': 'PAS',
    },
    295: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 25,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD ZULKIFLI BIN HJ ZAKARIA',
        'parti': 'PKR',
    },
    296: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 25,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NIK MOHAMAD ABDUH BIN NIK ABDUL AZIZ',
        'parti': 'PAS',
    },
    297: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 25,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AWANG ADEK BIN HUSSIN',
        'parti': 'BN',
    },
    298: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2520,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD RADZUAN BIN ABDULLAH',
        'parti': 'BN',
    },
    299: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2520,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HASSAN BIN MOHAMOOD',
        'parti': 'PAS',
    },
    300: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2521,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ILIAS BIN HUSAIN',
        'parti': 'BN',
    },
    301: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2521,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD HUZAIMI BIN CHE HUSSIN',
        'parti': 'PKR',
    },
    302: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2521,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ISMAIL BIN GHANI',
        'parti': 'PKR',
    },
    303: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2522,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD RADZUAN BIN HAMAT',
        'parti': 'BN',
    },
    304: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2522,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL AZZIZ BIN KADIR',
        'parti': 'PAS',
    },
    305: {
        'KodN': 3,
        'KodParlimen': 25,
        'KodKawasan': 2522,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD FAMI BIN ZAKARIA',
        'parti': 'PKR',
    },
    306: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 26,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ANNUAR BIN MUSA',
        'parti': 'BN',
    },
    307: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 26,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'WAN ISMAIL BIN WAN JUSOH',
        'parti': 'PAS',
    },
    308: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 26,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RADZI BIN JIDIN',
        'parti': 'PKR',
    },
    309: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2623,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMI BIN ISHAK',
        'parti': 'BN',
    },
    310: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2623,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MD YUSNAN BIN YUSOF',
        'parti': 'PAS',
    },
    311: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2623,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZIZ BIN KADIR',
        'parti': 'PKR',
    },
    312: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2624,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD AZAM BIN ISMAIL',
        'parti': 'BN',
    },
    313: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2624,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZAMI BIN MOHD NOR',
        'parti': 'PAS',
    },
    314: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2624,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHE IBRAHIM BIN MOHAMMAD',
        'parti': 'PKR',
    },
    315: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2625,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MD ALWI BIN CHE AHMAD',
        'parti': 'BN',
    },
    316: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2625,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NIK MAHADI BIN NIK MAHMOOD',
        'parti': 'PAS',
    },
    317: {
        'KodN': 3,
        'KodParlimen': 26,
        'KodKawasan': 2625,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD HANAFI BIN ISMAIL',
        'parti': 'PKR',
    },
    318: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 27,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'IKMAL HISHAM BIN ABDUL AZIZ',
        'parti': 'BN',
    },
    319: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 27,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JOHARI BIN MAT',
        'parti': 'PAS',
    },
    320: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 27,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'FAUZI BIN ZAKARIA',
        'parti': 'PKR',
    },
    321: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2726,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DYG SANIAH BINTI AWG HAMID',
        'parti': 'BN',
    },
    322: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2726,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HISHAM BIN FAUZI',
        'parti': 'PKR',
    },
    323: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2726,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL FATTAH BIN HAJI MAHMOOD',
        'parti': 'PAS',
    },
    324: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2727,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BAKRI @MOHD BAKRI BIN MUSTAPHA',
        'parti': 'BN',
    },
    325: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2727,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD SOBA BIN HUSSIN',
        'parti': 'PKR',
    },
    326: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2727,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN YUSOF BIN WAN MUSTAFFA',
        'parti': 'PAS',
    },
    327: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2728,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MD ANIZAM BIN AB RAHMAN',
        'parti': 'PAS',
    },
    328: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2728,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN RAKEMI BIN WAN ZAHARI',
        'parti': 'BN',
    },
    329: {
        'KodN': 3,
        'KodParlimen': 27,
        'KodKawasan': 2728,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BAHARI BIN MOHAMAD NOOR',
        'parti': 'PKR',
    },
    330: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 28,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO DR. ASYRAF WAJDI BIN DUSUKI',
        'parti': 'BN',
    },
    331: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 28,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO DR. NIK ZAWAWI BIN SALLEH',
        'parti': 'PAS',
    },
    332: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 28,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK KAMARUDDIN BIN MOHD NOOR',
        'parti': 'PKR',
    },
    333: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2829,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TUAN SARIPUDDIN BIN TUAN ISMAIL',
        'parti': 'PAS',
    },
    334: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2829,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZULKIFLE BIN ALI',
        'parti': 'BN',
    },
    335: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2829,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ISMAIL BIN MOHAMAD',
        'parti': 'PKR',
    },
    336: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2830,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD HANAFIAH BIN MOHD AZIZ',
        'parti': 'BN',
    },
    337: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2830,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHAMED NAZLAN BIN MOHD HASBULLAH',
        'parti': 'PAS',
    },
    338: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2830,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZARIR BIN YAACOB',
        'parti': 'PKR',
    },
    339: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2831,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAWAWI BIN OTHMAN',
        'parti': 'BN',
    },
    340: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2831,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN HASSAN BIN WAN IBRAHIM',
        'parti': 'PAS',
    },
    341: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2831,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN MARZUDI BIN WAN OMAR',
        'parti': 'PKR',
    },
    342: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2832,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO DR. MOHD KAISAN BIN AB RAHMAN',
        'parti': 'BN',
    },
    343: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2832,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "MOHD RODZI BIN JA'AFAR",
        'parti': 'PAS',
    },
    344: {
        'KodN': 3,
        'KodParlimen': 28,
        'KodKawasan': 2832,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL RAHMAN ',
        'parti': 'PKR',
    },
    345: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 29,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ZULKIFLI BIN MAMAT',
        'parti': 'PAS',
    },
    346: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 29,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SAZMI BIN MIAH',
        'parti': 'PKR',
    },
    347: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 29,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD JAZLAN BIN YAAKUB',
        'parti': 'BN',
    },
    348: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2933,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AHMAD TARMIZI BIN ISMAIL',
        'parti': 'BN',
    },
    349: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2933,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'USTAZ AZHAR BIN SALLEH',
        'parti': 'PAS',
    },
    350: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2933,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AB HALIM @ KAMARUDDIN BIN HAJI AB KADI',
        'parti': 'PKR',
    },
    351: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2934,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN MOHD ADNAN BIN WAN AZIZ',
        'parti': 'BN',
    },
    352: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2934,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD REDZUAN BIN ALIAS',
        'parti': 'PKR',
    },
    353: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2934,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED FADZLI BIN HASSAN',
        'parti': 'PAS',
    },
    354: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2935,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ERIANDI BIN ISMAIL',
        'parti': 'BN',
    },
    355: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2935,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ROSELI BIN ISMAIL',
        'parti': 'PAS',
    },
    356: {
        'KodN': 3,
        'KodParlimen': 29,
        'KodKawasan': 2935,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL KADIR BIN OTHMAN',
        'parti': 'PKR',
    },
    357: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 30,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'YB. DATO’ HAJI MUSTAPA BIN MOHAMED',
        'parti': 'BN',
    },
    358: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 30,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD HAMID',
        'parti': 'PAS',
    },
    359: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 30,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AZRAN ARIFFIN',
        'parti': 'PKR',
    },
    360: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3036,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YB. DATUK HAJI MOHD ADHAN KECHIK',
        'parti': 'BN',
    },
    361: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3036,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROMZI',
        'parti': 'PAS',
    },
    362: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3036,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ASLAN',
        'parti': 'PKR',
    },
    363: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3037,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YB. DATO’ HAJI MUSTAPA BIN MOHAMED',
        'parti': 'BN',
    },
    364: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3037,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "ABDULLAH YA'KUB",
        'parti': 'PAS',
    },
    365: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3037,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMINUDDIN B YAACUB',
        'parti': 'PKR',
    },
    366: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3038,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YB. DATUK HAJI ABDUL AZIZ DERASHID',
        'parti': 'BN',
    },
    367: {
        'KodN': 3,
        'KodParlimen': 30,
        'KodKawasan': 3038,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AFENDI MOHAMAD',
        'parti': 'PAS',
    },
    368: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 31,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHD YAZID BIN ABDULLAH',
        'parti': 'PKR',
    },
    369: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 31,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABD LATIFF BIN ABD RAHMAN',
        'parti': 'PAS',
    },
    370: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 31,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' RAMZI BIN AB RAHMAN",
        'parti': 'BN',
    },
    371: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3139,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN MOHAMAD AZLAN BIN AHMAD',
        'parti': 'PKR',
    },
    372: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3139,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAKI BIN MUHAMMAD',
        'parti': 'BN',
    },
    373: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3139,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD BIN MAT SULAIMAN',
        'parti': 'PAS',
    },
    374: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3140,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR ZUBER BIN HASSAN',
        'parti': 'BN',
    },
    375: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3140,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ROSLAN BIN PUTEH',
        'parti': 'PKR',
    },
    376: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3140,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HILIMI BIN ABDULLAH',
        'parti': 'PAS',
    },
    377: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3140,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL AZIZ BIN AHAMD',
        'parti': 'BEBAS',
    },
    378: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3141,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SUZAINI ADLINA BINTI SUKRI',
        'parti': 'BN',
    },
    379: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3141,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHAMED DAHAN BIN MAT JALI',
        'parti': 'PKR',
    },
    380: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3141,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD FAUZI BIN ABDULLAH',
        'parti': 'PAS',
    },
    381: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3141,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DERAMAN BIN MAMAT',
        'parti': 'BEBAS',
    },
    382: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3142,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD BIN AWANG',
        'parti': 'BN',
    },
    383: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3142,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN AHAMAD FADZIL BIN WAN OMAR',
        'parti': 'PKR',
    },
    384: {
        'KodN': 3,
        'KodParlimen': 31,
        'KodKawasan': 3142,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KU MOHD ZAKI  BIN KU HUSSIN',
        'parti': 'PAS',
    },
    385: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 32,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TENGKU RAZALEIGH BIN MOHD HAMZAH',
        'parti': 'BN',
    },
    386: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 32,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABDULLAH BIN HUSSEIN',
        'parti': 'PAS',
    },
    387: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 32,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD NOOR BIN HUSSIN',
        'parti': 'PKR',
    },
    388: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3243,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ ABD AZIZ BIN YUSOFF',
        'parti': 'BN',
    },
    389: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3243,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SIDEK@SAUPI BIN ABD RAZAK',
        'parti': 'PAS',
    },
    390: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3243,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ OTHMAN BIN YUSOFF',
        'parti': 'PKR',
    },
    391: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3244,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMRAN BIN ARIFIN',
        'parti': 'BN',
    },
    392: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3244,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZMAN BIN AHMAD',
        'parti': 'PAS',
    },
    393: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3244,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORAINI BINTI HUSIN',
        'parti': 'PKR',
    },
    394: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3245,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SYAHBUDDIN BIN HASHIM',
        'parti': 'BN',
    },
    395: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3245,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SUHAIMI BIN MAT DERIS',
        'parti': 'PAS',
    },
    396: {
        'KodN': 3,
        'KodParlimen': 32,
        'KodKawasan': 3245,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NASIR BIN DOLLAH',
        'parti': 'PKR',
    },
    397: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 33,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'RIDUAN BIN MOHAMMAD NOR ',
        'parti': 'PAS',
    },
    398: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 33,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'IDRIS BIN JUSOH ',
        'parti': 'BN',
    },
    399: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 33,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WAN NAZARI BIN WAN JUSOH ',
        'parti': 'PKR',
    },
    400: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3301,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HASBI BIN SALLEH ',
        'parti': 'PAS',
    },
    401: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3301,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TENGKU ZAIHAN BIN CHE KU ABD RAHMAN ',
        'parti': 'BN',
    },
    402: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3301,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHE KU HASHIM BIN CHE KU MAT ',
        'parti': 'PKR',
    },
    403: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3302,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD NUR HUZAINI BIN AB RAHMAN ',
        'parti': 'PAS',
    },
    404: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3302,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NOHD MAHDI BIN MUSA ',
        'parti': 'BN',
    },
    405: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3302,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TENGKU ROSLAN BIN TENGKU OTHMAN @ TENGKU RAMLI ',
        'parti': 'PKR',
    },
    406: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3303,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUHAMMAD PEHIMI BIN YUSOF ',
        'parti': 'BN',
    },
    407: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3303,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KAMARUZAMAN BIN WAN SU ',
        'parti': 'PKR',
    },
    408: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3303,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN AZHAR BIN WAN AHMAD ',
        'parti': 'PAS',
    },
    409: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3304,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ISMAIL BIN ABD KADIR ',
        'parti': 'PKR',
    },
    410: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3304,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MAT DAIK BIN MOHAMAD ',
        'parti': 'PAS',
    },
    411: {
        'KodN': 4,
        'KodParlimen': 33,
        'KodKawasan': 3304,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NAWI BIN MOHAMAD',
        'parti': 'BN',
    },
    412: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 34,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO HJ MOHD JIDIN BIN SHAFEE',
        'parti': 'BN',
    },
    413: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 34,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SHAHARIZZUKIRNAIN BIN ABD KADIR',
        'parti': 'PAS',
    },
    414: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 34,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO DR MOHD FAUZI BIN MUSA',
        'parti': 'PKR',
    },
    415: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3405,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ISKANDAR BIN JAAFAR',
        'parti': 'BN',
    },
    416: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3405,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD AZIZ BIN ABAS',
        'parti': 'PKR',
    },
    417: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3405,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZMAN BIN IBRAHIM',
        'parti': 'PAS',
    },
    418: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3406,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ABD HALIM BIN JUSOH',
        'parti': 'BN',
    },
    419: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3406,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZUL BAHRI BIN A RAHMAN',
        'parti': 'PAS',
    },
    420: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3406,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN MOKHTAR BIN WAN IBRAHIM',
        'parti': 'PKR',
    },
    421: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3407,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' SABRI BIN MOHD NOOR",
        'parti': 'BN',
    },
    422: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3407,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUSTAFFA BIN ABDULLAH',
        'parti': 'PKR',
    },
    423: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3407,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZMI BIN MAAROF',
        'parti': 'PAS',
    },
    424: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3408,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BAZLAN BIN ABD RAHMAN',
        'parti': 'BN',
    },
    425: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3408,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AMIR BIN LONG',
        'parti': 'PKR',
    },
    426: {
        'KodN': 4,
        'KodParlimen': 34,
        'KodKawasan': 3408,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD SHAFIZI BIN ISMAIL',
        'parti': 'PAS',
    },
    427: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 35,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'Tengku Asmadi bin Tengku Mohamad',
        'parti': 'BN',
    },
    428: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 35,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'Mohd Khairuddin bin Aman Razali',
        'parti': 'PAS',
    },
    429: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 35,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'Abdullah bin Mohamad',
        'parti': 'PKR',
    },
    430: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3509,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Basir bin Ismail',
        'parti': 'BN',
    },
    431: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3509,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Hishamuddin bin Abdul Karim ',
        'parti': 'PAS',
    },
    432: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3509,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Wan Hafizie Suzli bin Wan Hassan',
        'parti': 'PKR',
    },
    433: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3510,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Che Mansor bin Salleh',
        'parti': 'BN',
    },
    434: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3510,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Ridzuan bin Hashim',
        'parti': 'PAS',
    },
    435: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3510,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Azik bin Chik',
        'parti': 'PKR',
    },
    436: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3511,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Ahmad Razif bin Abd Rahman',
        'parti': 'BN',
    },
    437: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3511,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Abu Bakar bin Abdullah',
        'parti': 'PKR',
    },
    438: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3511,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Mohd Fazil bin Wahab',
        'parti': 'PAS',
    },
    439: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3512,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Tuan Arif Sahibu Fadilah bin Tuan Ahmad',
        'parti': 'BN',
    },
    440: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3512,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Alias bin Razak',
        'parti': 'PAS',
    },
    441: {
        'KodN': 4,
        'KodParlimen': 35,
        'KodKawasan': 3512,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Fatimah Laili binti Omar',
        'parti': 'PKR',
    },
    442: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 36,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' RAJA BAHARIN",
        'parti': 'PKR',
    },
    443: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 36,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AHMAD AMZAD BIN MOHAMED @HASHIM',
        'parti': 'PAS',
    },
    444: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 36,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WAN NAWAWI BIN HAJI WAN ISMAIL',
        'parti': 'BN',
    },
    445: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3613,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN SUKAIRI BIN WAN ABDULLAH',
        'parti': 'PAS',
    },
    446: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3613,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SALLEH BIN OTHMAN',
        'parti': 'BN',
    },
    447: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3613,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZUBIR BIN MOHAMED',
        'parti': 'PKR',
    },
    448: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3614,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZAN BIN ISMAIL',
        'parti': 'PKR',
    },
    449: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3614,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD SHAH BIN MOHAMED',
        'parti': 'PAS',
    },
    450: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3614,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TOH SENG CHENG',
        'parti': 'BN',
    },
    451: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3615,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK MOHD SABRI BIN ALWI',
        'parti': 'BN',
    },
    452: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3615,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' TENGKU HASSAN BIN T. OMAR",
        'parti': 'PAS',
    },
    453: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3615,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HAJI ZULKIFLI ",
        'parti': 'PKR',
    },
    454: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3616,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUHAMMAD KHALIL BIN ABDUL HADI',
        'parti': 'PAS',
    },
    455: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3616,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' RAJA BAHARIN",
        'parti': 'PKR',
    },
    456: {
        'KodN': 4,
        'KodParlimen': 36,
        'KodKawasan': 3616,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAMRI BIN AWANG HITAM',
        'parti': 'BN',
    },
    457: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 37,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TUAN HAJI MOHAMAD NOR BIN ENDOT',
        'parti': 'BN',
    },
    458: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 37,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SERI HAJI ABDUL HADI BIN AWANG",
        'parti': 'PAS',
    },
    459: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 37,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ZARAWI BIN SULONG',
        'parti': 'PKR',
    },
    460: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3717,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HAJI SAIFUL BAHRI BIN DATO' BAHARUDDIN",
        'parti': 'BN',
    },
    461: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3717,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ARIFFIN BIN DERAMAN',
        'parti': 'PAS',
    },
    462: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3717,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD SABRI BIN ALI @ MAMAT',
        'parti': 'PKR',
    },
    463: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3718,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TOH PUAN HAJAH ZAITUN BINTI MAT AMIN',
        'parti': 'BN',
    },
    464: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3718,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USTAZ MOHD NOR BIN HAMZAH',
        'parti': 'PAS',
    },
    465: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3718,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD DALIZAN BIN ABD AZIZ',
        'parti': 'PKR',
    },
    466: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3719,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' HAJI NIK DIR BIN NIK WAN KU",
        'parti': 'BN',
    },
    467: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3719,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZARAWI BIN SULONG',
        'parti': 'PKR',
    },
    468: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3719,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR AHMAD SAMSURI BIN MOKHTAR',
        'parti': 'PAS',
    },
    469: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3720,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'A.LATIFF BIN AWANG',
        'parti': 'BN',
    },
    470: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3720,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AIDI BIN AHMAD',
        'parti': 'PKR',
    },
    471: {
        'KodN': 4,
        'KodParlimen': 37,
        'KodKawasan': 3720,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SULAIMAN BIN SULONG',
        'parti': 'PAS',
    },
    472: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 38,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO'HAJI ROSOL BIN WAHID",
        'parti': 'BN',
    },
    473: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 38,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK RAZALI BIN IDRISS',
        'parti': 'PKR',
    },
    474: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 38,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HAJI MUHYIDIN BIN ABDUL RASHID',
        'parti': 'PAS',
    },
    475: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3821,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' ROZI BIN MAMAT",
        'parti': 'BN',
    },
    476: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3821,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USTAZ KAMARUZAMAN BIN ABDULLAH',
        'parti': 'PAS',
    },
    477: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3821,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SYARIFAH NORHAYATI BINTI SYED OMAR',
        'parti': 'PKR',
    },
    478: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3822,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'EN YUSOF BIN AWANG HITAM ',
        'parti': 'BN',
    },
    479: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3822,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD HAFIZUDDIN BIN HUSSAIN',
        'parti': 'PKR',
    },
    480: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3822,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HILMI BIN HARUN',
        'parti': 'PAS',
    },
    481: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3823,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO'HJ TENGKU PUTERA BIN TG AWANG",
        'parti': 'BN',
    },
    482: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3823,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD NOR BIN OTHMAN',
        'parti': 'PKR',
    },
    483: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3823,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR HJ MAMAD BIN PUTEH',
        'parti': 'PAS',
    },
    484: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3824,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAMANI BIN MAMAT',
        'parti': 'PKR',
    },
    485: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3824,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR GHAZALI BIN TAIB',
        'parti': 'BN',
    },
    486: {
        'KodN': 4,
        'KodParlimen': 38,
        'KodKawasan': 3824,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MALIAMAN BIN KASSIM',
        'parti': 'PAS',
    },
    487: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 39,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO DIN ADAM ',
        'parti': 'BN',
    },
    488: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 39,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'USTAZ WAN HASSAN MOHD RAMLI',
        'parti': 'PAS',
    },
    489: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 39,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HJ ABD RAHMAN YUSOF ',
        'parti': 'PKR',
    },
    490: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3925,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAJI GHAZALI SULAIMAN ',
        'parti': 'PAS',
    },
    491: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3925,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD ARIF ARIFIN ',
        'parti': 'PKR',
    },
    492: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3925,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROSLEE DAUD ',
        'parti': 'BN',
    },
    493: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3926,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAJI WAN ZAULKFLI WAN GATI',
        'parti': 'BN',
    },
    494: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3926,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CIKGU ALIAS ',
        'parti': 'PAS',
    },
    495: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3926,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ FADLY ART ',
        'parti': 'PKR',
    },
    496: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3927,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CIKGU WAN HAPANDI ',
        'parti': 'PAS',
    },
    497: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3927,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAINUN A.BAKAR ',
        'parti': 'BN',
    },
    498: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3927,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZULKIFLI ALI ',
        'parti': 'PKR',
    },
    499: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3928,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HASBIE MUDA ',
        'parti': 'PKR',
    },
    500: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3928,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'T HAMZAH T DRAMAN ',
        'parti': 'BN',
    },
    501: {
        'KodN': 4,
        'KodParlimen': 39,
        'KodKawasan': 3928,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'USTAZ SAIFUL BAHRI MAMAT ',
        'parti': 'PAS',
    },
    502: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 40,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD HUZAIFAH BIN MD SUHAIMI',
        'parti': 'PKR',
    },
    503: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 40,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD SHABERY BIN CHEEK',
        'parti': 'BN',
    },
    504: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 40,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHE ALIAS BIN AB HAMID',
        'parti': 'PAS',
    },
    505: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4029,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROSLI BIN OTHMAN',
        'parti': 'BN',
    },
    506: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4029,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAIFUL AZMI BIN SUHAILI',
        'parti': 'PAS',
    },
    507: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4029,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RIZAN BIN ALI',
        'parti': 'PKR',
    },
    508: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4030,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAZRI BIN JUSOH',
        'parti': 'PAS',
    },
    509: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4030,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AHMAD BIN SAID',
        'parti': 'BN',
    },
    510: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4030,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN MARZUKI BIN WAN SEMBOK',
        'parti': 'PKR',
    },
    511: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4031,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMED BIN AWANG TERA',
        'parti': 'BN',
    },
    512: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4031,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HANAFIAH BIN MAT',
        'parti': 'PAS',
    },
    513: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4031,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WAN MOHD ANIES BIN WAN MOHD ADNAN',
        'parti': 'PKR',
    },
    514: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4032,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN ABDUL HAKIM BIN WAN MOKHTAR',
        'parti': 'BN',
    },
    515: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4032,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AB RAZAK BIN IBRAHIM',
        'parti': 'PAS',
    },
    516: {
        'KodN': 4,
        'KodParlimen': 40,
        'KodKawasan': 4032,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZUKRI BIN AKSAH',
        'parti': 'PKR',
    },
    517: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 41,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' SRI REEZAL MERICAN BIN NAINA MERICAN",
        'parti': 'BN',
    },
    518: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 41,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DR. ZAIDI BIN ZAKARIA',
        'parti': 'PKR',
    },
    519: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 41,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SITI MASTURA BINTI MUHAMMAD',
        'parti': 'PAS',
    },
    520: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4101,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD YUSNI BIN MAT PIAH',
        'parti': 'PAS',
    },
    521: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4101,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK HJ MOHD ZAIN BIN AHMAD',
        'parti': 'BN',
    },
    522: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4102,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHALIQ MEHTAB BIN MOHD ISHAQ',
        'parti': 'PKR',
    },
    523: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4102,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOKHTAR BIN RAMLY',
        'parti': 'PAS',
    },
    524: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4102,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ SHARIFUL AZHAR BIN IBRAHIM',
        'parti': 'BN',
    },
    525: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4103,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' IR AHMAD ZAKIYUDDIN BIN ABD RAHMAN",
        'parti': 'PKR',
    },
    526: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4103,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ BUKHORI BIN GHAZALI',
        'parti': 'PAS',
    },
    527: {
        'KodN': 5,
        'KodParlimen': 41,
        'KodKawasan': 4103,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HJ ROSLAN BIN SAIDIN",
        'parti': 'BN',
    },
    528: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 42,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'SHABUDIN BIN YAHAYA',
        'parti': 'BN',
    },
    529: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 42,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MARZUKI BIN YAHYA',
        'parti': 'PKR',
    },
    530: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 42,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'RIZAL HAFIZ BIN RUSLAN',
        'parti': 'PAS',
    },
    531: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4204,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NOR HAFIZAH BINTI OTHMAN',
        'parti': 'BN',
    },
    532: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4204,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMAN SHAH BIN OTHMAN',
        'parti': 'PRM',
    },
    533: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4204,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD SOBRI BIN SALEH',
        'parti': 'PAS',
    },
    534: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4204,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD. SHARIFF BIN OMAR',
        'parti': 'PKR',
    },
    535: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4205,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAHADI BIN HJ. MOHD',
        'parti': 'PAS',
    },
    536: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4205,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMAD YUSOFF BIN MOHD',
        'parti': 'BN',
    },
    537: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4205,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YUSRI BIN ISAHAK',
        'parti': 'PKR',
    },
    538: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4206,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD HANIF BIN HARON',
        'parti': 'PAS',
    },
    539: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4206,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUSTAFA KAMAL BIN AHMAD',
        'parti': 'PKR',
    },
    540: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4206,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LEE THIAN HONG',
        'parti': 'PRM',
    },
    541: {
        'KodN': 5,
        'KodParlimen': 42,
        'KodKawasan': 4206,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ZAMRI BIN CHE ROS',
        'parti': 'BN',
    },
    542: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 43,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LEE BENG SENG',
        'parti': 'BN',
    },
    543: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 43,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KOAY XING BOON',
        'parti': 'MU',
    },
    544: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 43,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'LIM GUAN ENG',
        'parti': 'PKR',
    },
    545: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 43,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'HUANG CHENG GUAN',
        'parti': 'PCM',
    },
    546: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4307,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LIM HAI SONG ',
        'parti': 'BN',
    },
    547: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4307,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NEOH BOK KENG',
        'parti': 'MU',
    },
    548: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4307,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ONG YIN YIN',
        'parti': 'PFP',
    },
    549: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4307,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'PHEE BOON POH',
        'parti': 'PKR',
    },
    550: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4307,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TAN LAY HOCK',
        'parti': 'PRM',
    },
    551: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4308,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'FABIAN GEORGE ALBART',
        'parti': 'PFP',
    },
    552: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4308,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SOON LIP CHEE ',
        'parti': 'PKR',
    },
    553: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4308,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HARI DEVYNDRAN A/P MUNISWARAN',
        'parti': 'MU',
    },
    554: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4308,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ANG CHOR KEONG',
        'parti': 'BN',
    },
    555: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4308,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TEOH CHAI DENG',
        'parti': 'PRM',
    },
    556: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4309,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEOH UAT LYE',
        'parti': 'MU',
    },
    557: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4309,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DHINAGARAN A/L JAYABALAN',
        'parti': 'BN',
    },
    558: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4309,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JASPER OOI ZANG HAN',
        'parti': 'PFP',
    },
    559: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4309,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TEOH HUCK PING',
        'parti': 'PRM',
    },
    560: {
        'KodN': 5,
        'KodParlimen': 43,
        'KodKawasan': 4309,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'SATEES a/l MUNIANDY',
        'parti': 'PKR',
    },
    561: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 44,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "NURUL IZZAH BT DATO' SERI ANWAR",
        'parti': 'PKR',
    },
    562: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 44,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AFNAN HAMIMI BIN DATO TAIB AZAMUDIN',
        'parti': 'PAS',
    },
    563: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 44,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK HJ MOHD ZAIDI BIN HJ MOHD SAID',
        'parti': 'BN',
    },
    564: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4410,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABU BAKAR SIDEKH BIN ZAINUL ABIDIN',
        'parti': 'BN',
    },
    565: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4410,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. AFIF BIN BAHARDIN',
        'parti': 'PKR',
    },
    566: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4410,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'IR WAN AHMAD RAFAIE BIN DATO" ABDUL RASHID',
        'parti': 'PAS',
    },
    567: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4411,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ANUAR FAISAL BIN YAHAYA',
        'parti': 'BN',
    },
    568: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4411,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD FAUZI BIN YUSOF',
        'parti': 'PAS',
    },
    569: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4411,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "MUHAMMAD FAIZ BIN DATO' FADZIL",
        'parti': 'PKR',
    },
    570: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4412,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SUHAIMI BIN SABUDIN',
        'parti': 'BN',
    },
    571: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4412,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR. NORLELA BT ARIFFIN',
        'parti': 'PKR',
    },
    572: {
        'KodN': 5,
        'KodParlimen': 44,
        'KodKawasan': 4412,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD FAWWAZ BIN MAT JAN',
        'parti': 'PAS',
    },
    573: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 45,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'GUI GUAT LYE',
        'parti': 'BN',
    },
    574: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 45,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SIM CHEE KEONG',
        'parti': 'PKR',
    },
    575: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4513,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HENG LEE LEE',
        'parti': 'PKR',
    },
    576: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4513,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEE POH KONG',
        'parti': 'PFP',
    },
    577: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4513,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'GOH SWEE GIM',
        'parti': 'BN',
    },
    578: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4513,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SONG CHEE MENG',
        'parti': 'PRM',
    },
    579: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4514,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LIM JHUN HOU',
        'parti': 'MU',
    },
    580: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4514,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TANG AH BA',
        'parti': 'PRM',
    },
    581: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4514,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DATUK TAN TEIK CHENG',
        'parti': 'BN',
    },
    582: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4514,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'MD JAMIL BIN ABD RAHMAN',
        'parti': 'PAS',
    },
    583: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4514,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE KHAI LOON',
        'parti': 'PKR',
    },
    584: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4515,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIEW EE JIN',
        'parti': 'PFP',
    },
    585: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4515,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KUAN HIN YEEP',
        'parti': 'BN',
    },
    586: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4515,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHONG ENG',
        'parti': 'PKR',
    },
    587: {
        'KodN': 5,
        'KodParlimen': 45,
        'KodKawasan': 4515,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'LAI YEAN NEE',
        'parti': 'PRM',
    },
    588: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 46,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'OOI KHAR GIAP',
        'parti': 'PFP',
    },
    589: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 46,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JAYANTHI DEVI BALAGURU',
        'parti': 'BN',
    },
    590: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 46,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'JAY KUMAR',
        'parti': 'PAS',
    },
    591: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 46,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'KASTHURIRAANI PATTO',
        'parti': 'PKR',
    },
    592: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'PROF. P. RAMASAMY',
        'parti': 'PKR',
    },
    593: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'OOI KHAR GIAP',
        'parti': 'PFP',
    },
    594: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'M.SURESH ',
        'parti': 'BN',
    },
    595: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'R.KUMARY',
        'parti': 'BEBAS',
    },
    596: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ASOGHAN A/L GOVINDARAJU',
        'parti': 'PAP',
    },
    597: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4616,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'SAMUGANATHAN A/L MUNIANDY',
        'parti': 'PRM',
    },
    598: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4617,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GOOI HSIAO-LEUNG',
        'parti': 'PKR',
    },
    599: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4617,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EDWARD JOSEPH',
        'parti': 'PFP',
    },
    600: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4617,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR THOR TEONG GEE',
        'parti': 'BN',
    },
    601: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4617,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'NORAZMAN BIN ISHAK',
        'parti': 'PAS',
    },
    602: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4618,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GOH B KOON',
        'parti': 'PRM',
    },
    603: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4618,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ONG SEONG LU',
        'parti': 'PFP',
    },
    604: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4618,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HARTINI TAN BINTI ABDULLAH',
        'parti': 'BN',
    },
    605: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4618,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'GOH CHOON AIK',
        'parti': 'PKR',
    },
    606: {
        'KodN': 5,
        'KodParlimen': 46,
        'KodKawasan': 4618,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'KUMARAVELU A/L ARUMUGAM',
        'parti': 'PAS',
    },
    607: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 47,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' MANSOR BIN  OTHMAN",
        'parti': 'PKR',
    },
    608: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 47,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' IR DR SHAIK HUSSEIN BIN MYDIN",
        'parti': 'BN',
    },
    609: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 47,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHD HELMI BIN HARUN',
        'parti': 'PAS',
    },
    610: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 47,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'TAN TEE BENG',
        'parti': 'BEBAS',
    },
    611: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN BENG HUAT',
        'parti': 'PAP',
    },
    612: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR. KIEW HENG CHONG',
        'parti': 'BN',
    },
    613: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DAPHNE A/P EDWARD ',
        'parti': 'PFP',
    },
    614: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "H'NG MOOI LYE",
        'parti': 'PKR',
    },
    615: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'TAN CHEW SUAN',
        'parti': 'PRM',
    },
    616: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4719,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'KOAY XING BOON',
        'parti': 'MU',
    },
    617: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4720,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN CHOW KANG',
        'parti': 'PRM',
    },
    618: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4720,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'OSMAN BIN JAAFAR',
        'parti': 'PAS',
    },
    619: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4720,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. AMAR PRITPAL BIN ABDULLAH',
        'parti': 'PKR',
    },
    620: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4720,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "DATO' MOHAMED SANI BIN BAKAR",
        'parti': 'BN',
    },
    621: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4721,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZULKIFLI BIN IBRAHIM',
        'parti': 'PKR',
    },
    622: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4721,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' MAHMUD BIN ZAKARIA",
        'parti': 'BN',
    },
    623: {
        'KodN': 5,
        'KodParlimen': 47,
        'KodKawasan': 4721,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NOR ZAMRI BIN LATIF',
        'parti': 'PAS',
    },
    624: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 48,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'WONG HON WAI',
        'parti': 'PKR',
    },
    625: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 48,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ANDY YONG KIM SENG',
        'parti': 'BN',
    },
    626: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 48,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TAN GIN THEAM',
        'parti': 'MU',
    },
    627: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4822,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE ZHENG YONG',
        'parti': 'MU',
    },
    628: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4822,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHUA CHEONG WEE',
        'parti': 'PRM',
    },
    629: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4822,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAIRIL KHIR JOHARI',
        'parti': 'PKR',
    },
    630: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4822,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TENG CHANG YEOW',
        'parti': 'BN',
    },
    631: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4823,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LIM GUAN ENG',
        'parti': 'PKR',
    },
    632: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4823,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN HEAP SENG',
        'parti': 'BN',
    },
    633: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4823,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN GIN THEAM',
        'parti': 'MU',
    },
    634: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4823,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MANIKANDAN A/L RAMAYAH',
        'parti': 'PCM',
    },
    635: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4824,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'OOI ZHI YI',
        'parti': 'BN',
    },
    636: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4824,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WU KAI MIN',
        'parti': 'MU',
    },
    637: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4824,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JASON ONG KHAN LEE',
        'parti': 'PKR',
    },
    638: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4825,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LOO JIEH SHENG',
        'parti': 'BN',
    },
    639: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4825,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WEE KEAN WAI',
        'parti': 'MU',
    },
    640: {
        'KodN': 5,
        'KodParlimen': 48,
        'KodKawasan': 4825,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LEE CHUN KIT',
        'parti': 'PKR',
    },
    641: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 49,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NG SIEW LAI',
        'parti': 'BN',
    },
    642: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 49,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHOW KON YEOW',
        'parti': 'PKR',
    },
    643: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4926,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "H'NG KHOON LENG",
        'parti': 'BN',
    },
    644: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4926,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHOW KON YEOW',
        'parti': 'PKR',
    },
    645: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4927,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIM SWEE BOK',
        'parti': 'BN',
    },
    646: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4927,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'KOAY TENG LYE',
        'parti': 'BEBAS',
    },
    647: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4927,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DANIEL GOOI ZI SEN',
        'parti': 'PKR',
    },
    648: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4927,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHEW SENG TUNG',
        'parti': 'PRM',
    },
    649: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4927,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'RAGINDRAN SIVASAMY',
        'parti': 'BEBAS',
    },
    650: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4928,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TEH LAI HENG',
        'parti': 'PKR',
    },
    651: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4928,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN HING TEIK',
        'parti': 'BN',
    },
    652: {
        'KodN': 5,
        'KodParlimen': 49,
        'KodKawasan': 4928,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ONG CHUN JIET',
        'parti': 'MU',
    },
    653: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 50,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK BALJIT SINGH A/L JIGIRI SINGH',
        'parti': 'BN',
    },
    654: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 50,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RSN SANISVARA NETHAJI RAYER',
        'parti': 'PKR',
    },
    655: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 50,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TAN SIM BEE',
        'parti': 'MU',
    },
    656: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5029,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE BOON TEN',
        'parti': 'BN',
    },
    657: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5029,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAGDEEP SINGH DEO A/L KARPAL SINGH ',
        'parti': 'PKR',
    },
    658: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5029,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LIM BOO CHANG ',
        'parti': 'MU',
    },
    659: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5029,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'NICHOLAS DIANE A/L MORGAN ',
        'parti': 'PFP',
    },
    660: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5029,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'MUHAMMAD MAJNUN BIN ABDUL WAHAB',
        'parti': 'PAP',
    },
    661: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG FOOK ON',
        'parti': 'BN',
    },
    662: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIM SIEW KHIM',
        'parti': 'PKR',
    },
    663: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YACOOP BIN OMAR',
        'parti': 'PAS',
    },
    664: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'TAN SIM-BEE',
        'parti': 'MU',
    },
    665: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TEH YEE CHEU',
        'parti': 'PSM',
    },
    666: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5030,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'MOHAMED YACOOB BIN MOHAMED NOOR',
        'parti': 'BEBAS',
    },
    667: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5031,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KOO PEI-CHEE',
        'parti': 'BN',
    },
    668: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5031,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ONG AH-TEONG',
        'parti': 'PKR',
    },
    669: {
        'KodN': 5,
        'KodParlimen': 50,
        'KodKawasan': 5031,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KEE LEAN-EE',
        'parti': 'MU',
    },
    670: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 51,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LOW JOO- HIAP',
        'parti': 'BN',
    },
    671: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 51,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RAMKARPAL SINGH A/L KARPAL SINGH',
        'parti': 'PKR',
    },
    672: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 51,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'LAI XUE-CHING',
        'parti': 'MU',
    },
    673: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5132,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHOO KAY TEONG',
        'parti': 'BN',
    },
    674: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5132,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SYERLEENA BINTI ABDUL RASHID',
        'parti': 'PKR',
    },
    675: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5132,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN YANG-YUNG',
        'parti': 'MU',
    },
    676: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5133,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN KAH LEONG',
        'parti': 'BN',
    },
    677: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5133,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JOSEPH NG SOON SIANG',
        'parti': 'PKR',
    },
    678: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5133,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KANG TEIK WOI',
        'parti': 'MU',
    },
    679: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5134,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WONG CHING CHONG',
        'parti': 'BN',
    },
    680: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5134,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YEOH SOON HIN',
        'parti': 'PKR',
    },
    681: {
        'KodN': 5,
        'KodParlimen': 51,
        'KodKawasan': 5134,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KUAN AUN WAN ',
        'parti': 'MU',
    },
    682: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 52,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DAVID YIM BOON LEONG',
        'parti': 'MU',
    },
    683: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 52,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SIM TZE TZIN',
        'parti': 'PKR',
    },
    684: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 52,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CHUAH SENG GUAN',
        'parti': 'BN',
    },
    685: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 52,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'ISZUREE BIN IBRAHIM',
        'parti': 'PAS',
    },
    686: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5235,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HNG CHEE WEY',
        'parti': 'BN',
    },
    687: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5235,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'VIKNESWARAN A/L MUNIANDY',
        'parti': 'PAS',
    },
    688: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5235,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KUMARESAN A/L ARAMUSAM',
        'parti': 'PKR',
    },
    689: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5235,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TEOH KEAN LEANG',
        'parti': 'PFP',
    },
    690: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5235,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'TEOH KOK SIANG',
        'parti': 'MU',
    },
    691: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5236,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DAVID YIM BOON-LEONG',
        'parti': 'MU',
    },
    692: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5236,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD FARHAN BIN YUSRI',
        'parti': 'PAS',
    },
    693: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5236,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'OH TONG-KEONG',
        'parti': 'BN',
    },
    694: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5236,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SAIFUDDIN NASUITION BIN ISMAIL',
        'parti': 'PKR',
    },
    695: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5237,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' ABDUL HALIM BIN HUSSAIN",
        'parti': 'PKR',
    },
    696: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5237,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAIFUL LIZAN BIN MD YUSOFF',
        'parti': 'PAS',
    },
    697: {
        'KodN': 5,
        'KodParlimen': 52,
        'KodKawasan': 5237,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HAJI LAIKAT ALI BIN MOHAMED ALI',
        'parti': 'BN',
    },
    698: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 53,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SERI DR. HJ. HILMI BIN HJ. YAHAYA",
        'parti': 'BN',
    },
    699: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 53,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD BAKHTIAR BIN WAN CHIK',
        'parti': 'PKR',
    },
    700: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 53,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "MUHAMMAD IMRAN BIN MUHAMMAD SA'AD",
        'parti': 'PAS',
    },
    701: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5338,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ RUSLI BIN HASHIM',
        'parti': 'BN',
    },
    702: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5338,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZRUL MAHATHIR BIN AZIZ',
        'parti': 'PKR',
    },
    703: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5338,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZARINA BINTI SHINTA MADAR',
        'parti': 'PAS',
    },
    704: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5339,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DATUK DR. HJ. MUHAMAD FARID BIN HJ. SAAD',
        'parti': 'BN',
    },
    705: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5339,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ MOHD TUAH BIN ISMAIL',
        'parti': 'PKR',
    },
    706: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5339,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ TAUFIK BIN HASHIM',
        'parti': 'PAS',
    },
    707: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5339,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YEOH CHENG HUAT ',
        'parti': 'PRM',
    },
    708: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5340,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ ZOLKIFLY BIN MD LAZIM',
        'parti': 'PKR',
    },
    709: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5340,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK SHAH HEADAN HEADAN BIN AYOOB HUSSAIN SHAH',
        'parti': 'BN',
    },
    710: {
        'KodN': 5,
        'KodParlimen': 53,
        'KodKawasan': 5340,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ ALI BIN OTHMAN',
        'parti': 'PAS',
    },
    711: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 54,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'Ustaz Dahalan',
        'parti': 'PAS',
    },
    712: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 54,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'Dato Hasbullah Bin Osman',
        'parti': 'BN',
    },
    713: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 54,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'Ibrahim Hanafiah',
        'parti': 'PKR',
    },
    714: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5401,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Dato Hj. Aznel Hj. Ibrahim',
        'parti': 'BN',
    },
    715: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5401,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Hamidi Ismail',
        'parti': 'PAS',
    },
    716: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5401,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': ' DR AHMAD SAFWAN (DR IWAN)',
        'parti': 'PKR',
    },
    717: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5402,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Fadzil Aziz',
        'parti': 'PKR',
    },
    718: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5402,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Md Pozi bin Md Sani',
        'parti': 'PAS',
    },
    719: {
        'KodN': 6,
        'KodParlimen': 54,
        'KodKawasan': 5402,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Salbiah binti Mohamed',
        'parti': 'BN',
    },
    720: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 55,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AMIRUL FAIRUZZEEN',
        'parti': 'PKR',
    },
    721: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 55,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'USTAZ MUJAHID IR FADZIL',
        'parti': 'PAS',
    },
    722: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 55,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR. SHAMSUL ANUAR NASARAH',
        'parti': 'BN',
    },
    723: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5503,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZHAR HJ. RASDI',
        'parti': 'PAS',
    },
    724: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5503,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NOOR SHAM BINTI ABU SAMAH',
        'parti': 'PKR',
    },
    725: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5503,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TARMIZI BIN IDRIS',
        'parti': 'BN',
    },
    726: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5504,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'USTAZ RIFAAT BIN HJ RAZMAN',
        'parti': 'PAS',
    },
    727: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5504,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAARANI BIN MOHAMAD',
        'parti': 'BN',
    },
    728: {
        'KodN': 6,
        'KodParlimen': 55,
        'KodKawasan': 5504,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NOOR HASNIDA BINTI MOHD. HASHIM',
        'parti': 'PKR',
    },
    729: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 56,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ABU HUSIN BIN MOHMMAD',
        'parti': 'PAS',
    },
    730: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 56,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HAMZAH BIN ZAINUDIN',
        'parti': 'BN',
    },
    731: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 56,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'KHAIRIL ANUAR BIN AKHIRUDDIN',
        'parti': 'PKR',
    },
    732: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5605,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'FAIZUL ARBY BIN MOHD SHOHOR',
        'parti': 'BN',
    },
    733: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5605,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAZALI BIN ISMAIL',
        'parti': 'PKR',
    },
    734: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5605,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD AKMAL BIN KAMARUDIN',
        'parti': 'PAS',
    },
    735: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5606,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MAT SUPRI BIN MUSA',
        'parti': 'PKR',
    },
    736: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5606,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KHALIL BIN YAHAYA',
        'parti': 'PAS',
    },
    737: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5606,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SALIZA BINTI AHMAD',
        'parti': 'BN',
    },
    738: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5607,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SHAHIR BIN MOHD HASSAN',
        'parti': 'PAS',
    },
    739: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5607,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAINAL ABIDIN BIN ABD RAHMAN',
        'parti': 'BERJASA',
    },
    740: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5607,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMAD AIMAN AIZUDDIN BIN MD HUSIN',
        'parti': 'PKR',
    },
    741: {
        'KodN': 6,
        'KodParlimen': 56,
        'KodKawasan': 5607,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MUHAMMAD AMIN BIN ZAKARIA',
        'parti': 'BN',
    },
    742: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 57,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'Dato Puhat B. Mat Nayan',
        'parti': 'BN',
    },
    743: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 57,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'Dato Mujahid B. Yusuf Rawa',
        'parti': 'PKR',
    },
    744: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 57,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'Ahmad Azhar B. Shahrin',
        'parti': 'PAS',
    },
    745: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5708,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Hasnul Zulkarnain B Abd Munaim',
        'parti': 'PKR',
    },
    746: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5708,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Abu Bakar b Hussin',
        'parti': 'PAS',
    },
    747: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5708,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Norsalewati  bt Mat Norwani',
        'parti': 'BN',
    },
    748: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5709,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'Shahrul Nizam b Razali ',
        'parti': 'BN',
    },
    749: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5709,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Abdul Yunus b Jamhari',
        'parti': 'PKR',
    },
    750: {
        'KodN': 6,
        'KodParlimen': 57,
        'KodKawasan': 5709,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Abdul Baharin ',
        'parti': 'PAS',
    },
    751: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 58,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO DR HJ AZMI BIN GHAZALI',
        'parti': 'BN',
    },
    752: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 58,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ADAM BIN ASMUNI',
        'parti': 'PKR',
    },
    753: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 58,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ROHAYA BINTI BAKAR',
        'parti': 'PAS',
    },
    754: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5810,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ AHMAD ZAKI BIN HUSSIN',
        'parti': 'PKR',
    },
    755: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5810,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO HJ SHAM BIN MAT SAHAT',
        'parti': 'BN',
    },
    756: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5810,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN TARMIZI BIN WAN AZIZ',
        'parti': 'PAS',
    },
    757: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5811,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAZMAN BIN ZAKARIA',
        'parti': 'PAS',
    },
    758: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5811,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ ZAINI BIN CHA',
        'parti': 'BN',
    },
    759: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5811,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ISMAIL BIN ALI',
        'parti': 'PKR',
    },
    760: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5812,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAQIF BIN ANSORULLAH',
        'parti': 'PKR',
    },
    761: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5812,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ HUSIN BIN DIN',
        'parti': 'PAS',
    },
    762: {
        'KodN': 6,
        'KodParlimen': 58,
        'KodKawasan': 5812,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMAD NOOR BIN DAWOO',
        'parti': 'BN',
    },
    763: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 59,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'USTAZ IDRIS AHMAD',
        'parti': 'PAS',
    },
    764: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 59,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SYED ABU HUSSIN BIN HAFIZ SYED ABDUL FASAL',
        'parti': 'BN',
    },
    765: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 59,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATO HJ KHADRI KHALID',
        'parti': 'PKR',
    },
    766: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5913,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD KAMARUDDIN BIN ABU BAKAR',
        'parti': 'BN',
    },
    767: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5913,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHUA YEE LING',
        'parti': 'PKR',
    },
    768: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5913,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAJI RAHIM ISMAIL',
        'parti': 'PAS',
    },
    769: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5914,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'USTAZ NORDIN JAAFAR',
        'parti': 'PAS',
    },
    770: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5914,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'IR. MEGAT SHARIFFUDIN IBRAHIM',
        'parti': 'PKR',
    },
    771: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5914,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHGANAN A/L P MANIKAM',
        'parti': 'BEBAS',
    },
    772: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5914,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'AHMAD SAIDI BIN MOHAMAD DAUD',
        'parti': 'BN',
    },
    773: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5915,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAMILAH BINTI ZAKARIA',
        'parti': 'BN',
    },
    774: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5915,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK SHAHARUDDIN ABDUL RASHID',
        'parti': 'PKR',
    },
    775: {
        'KodN': 6,
        'KodParlimen': 59,
        'KodKawasan': 5915,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'USTAZ FAISAL BIN ABDUL RAHMAN',
        'parti': 'PAS',
    },
    776: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 60,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'TAN KENG LIANG',
        'parti': 'BN',
    },
    777: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 60,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'IBRAHIM BIN ISMAIL',
        'parti': 'PAS',
    },
    778: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 60,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TEH KOK LIM',
        'parti': 'PKR',
    },
    779: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6016,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD FAKHRUDIN BIN ABDUL AZIZ',
        'parti': 'PAS',
    },
    780: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6016,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHD FADHIL BIN NURUDDIN',
        'parti': 'PKR',
    },
    781: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6016,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD ZAHIR BIN ABDUL KHALID',
        'parti': 'BN',
    },
    782: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6017,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE LI KUAN',
        'parti': 'BN',
    },
    783: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6017,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEOW THYE YIH',
        'parti': 'PKR',
    },
    784: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6018,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SOO KAY PING',
        'parti': 'BN',
    },
    785: {
        'KodN': 6,
        'KodParlimen': 60,
        'KodKawasan': 6018,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NGA KOR MING',
        'parti': 'PKR',
    },
    786: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 61,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'EJAZI BIN YAHAYA',
        'parti': 'PKR',
    },
    787: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 61,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMED NAZRI BIN ABDUL AZIZ',
        'parti': 'BN',
    },
    788: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 61,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD AZALAN BIN MOHAMAD RADZI',
        'parti': 'PAS',
    },
    789: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6119,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUL ANUAR BIN MUSA',
        'parti': 'PKR',
    },
    790: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6119,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHAMMAD FARID FAIZI BIN AZIZAN',
        'parti': 'PAS',
    },
    791: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6119,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAINUN BIN MAT NOOR',
        'parti': 'BN',
    },
    792: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6120,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZULKARNINE BIN HASHIM',
        'parti': 'PKR',
    },
    793: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6120,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JURIJ BIN JALALUDIN',
        'parti': 'BN',
    },
    794: {
        'KodN': 6,
        'KodParlimen': 61,
        'KodKawasan': 6120,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZIZI BIN MOHAMED RIDZUWAN',
        'parti': 'PAS',
    },
    795: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 62,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'S. KESAVAN A/L SUBRAMANIAM ',
        'parti': 'PKR',
    },
    796: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 62,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DR. ISHAK BIN IBRAHIM',
        'parti': 'PAS',
    },
    797: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 62,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SRI  DEVAMANY A/L S. KRISHNASAMY",
        'parti': 'BN',
    },
    798: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 62,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'MICHAEL JEYAKUMAR DEVARAJ',
        'parti': 'PSM',
    },
    799: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 6221,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MADHI BIN HASAN',
        'parti': 'PKR',
    },
    800: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 6221,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ISRAN FAHMI BIN ISMAIL',
        'parti': 'PAS',
    },
    801: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 6221,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' HJ MOHD ZOLKAFLY BIN HJ HARUN",
        'parti': 'BN',
    },
    802: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 6222,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LOH SZE YEE',
        'parti': 'PKR',
    },
    803: {
        'KodN': 6,
        'KodParlimen': 62,
        'KodKawasan': 6222,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' TAN LIAN HOE",
        'parti': 'BN',
    },
    804: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 63,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AHMAD HUSNI BIN HANADZLAH ',
        'parti': 'BN',
    },
    805: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 63,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "AHMAD FAIZAL BIN DATO' AZUMU",
        'parti': 'PKR',
    },
    806: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 63,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'USTAZ ZULKIFLI BIN ZAKARIA ',
        'parti': 'PAS',
    },
    807: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6323,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'USTAZ HAFEZ BIN SABRI ',
        'parti': 'PAS',
    },
    808: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6323,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ASMUNI BIN AWI ',
        'parti': 'PKR',
    },
    809: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6323,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD ZIAD BIN MOHAMED ZAINAL ABIDIN ',
        'parti': 'BN',
    },
    810: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6324,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'USTAZ SALLEH BIN SAID ',
        'parti': 'PAS',
    },
    811: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6324,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AMINUDDIN BIN HAJI MD HANAFIAH ',
        'parti': 'BN',
    },
    812: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6324,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MURUGIAH A/L SUBRAMANIAM ',
        'parti': 'BEBAS',
    },
    813: {
        'KodN': 6,
        'KodParlimen': 63,
        'KodKawasan': 6324,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MUHAMMAD ARAFAT BIN VARISAI MUHAMAD ',
        'parti': 'PKR',
    },
    814: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 64,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KATHLEEN WONG MEI YIN',
        'parti': 'BN',
    },
    815: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 64,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WONG KAH WOH',
        'parti': 'PKR',
    },
    816: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6425,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JENNY CHOY TSI JEN',
        'parti': 'PKR',
    },
    817: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6425,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIEW KAR TUAN',
        'parti': 'BN',
    },
    818: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6426,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHOO BOON CHUAN',
        'parti': 'BN',
    },
    819: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6426,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL AZIZ BIN BARI',
        'parti': 'PKR',
    },
    820: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6426,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MAZLAN BIN MD ISA',
        'parti': 'PAS',
    },
    821: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6427,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE CHUAN HOW',
        'parti': 'PKR',
    },
    822: {
        'KodN': 6,
        'KodParlimen': 64,
        'KodKawasan': 6427,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NG KAI CHEONG',
        'parti': 'BN',
    },
    823: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 65,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHENG WEI YEE',
        'parti': 'BN',
    },
    824: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 65,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'M.KULASEGARAN A/L V.MURUGESON',
        'parti': 'PKR',
    },
    825: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6528,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LOW GUO NAN',
        'parti': 'BN',
    },
    826: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6528,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ONG BOON PIOW',
        'parti': 'PKR',
    },
    827: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6529,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHANG KOK AUN',
        'parti': 'BN',
    },
    828: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6529,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KO CHUNG SEN',
        'parti': 'PKR',
    },
    829: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6530,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'THANGARANI A/P THIAGARAJAN',
        'parti': 'BN',
    },
    830: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6530,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SIVASUBRAMANIAM A/L ATHINARAYANAN',
        'parti': 'PKR',
    },
    831: {
        'KodN': 6,
        'KodParlimen': 65,
        'KodKawasan': 6530,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHANARANI A/P RASIAH',
        'parti': 'PSM',
    },
    832: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 66,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LEONG CHEE WAI',
        'parti': 'BN',
    },
    833: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 66,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'V.SIVAKUMAR',
        'parti': 'PKR',
    },
    834: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 66,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SEKAR',
        'parti': 'PSM',
    },
    835: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6631,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHEAH POU HIAN ',
        'parti': 'PKR',
    },
    836: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6631,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'M.SARASWATHY',
        'parti': 'PSM',
    },
    837: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6631,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'THANKARAJ A/L KRISHNAN',
        'parti': 'BN',
    },
    838: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6632,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WONG KAM SENG',
        'parti': 'BN',
    },
    839: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6632,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHAW KAM FOON ',
        'parti': 'PKR',
    },
    840: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6632,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHIN KWAI LEONG',
        'parti': 'PSM',
    },
    841: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6633,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YONG CHOO KIONG',
        'parti': 'PKR',
    },
    842: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6633,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YUEN CHAN HOW',
        'parti': 'BN',
    },
    843: {
        'KodN': 6,
        'KodParlimen': 66,
        'KodKawasan': 6633,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHIN KWAI HENG',
        'parti': 'PSM',
    },
    844: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 67,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DRS. KHALIL IDHAM LIM',
        'parti': 'PAS',
    },
    845: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 67,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATIN MASTURA YAZID ',
        'parti': 'BN',
    },
    846: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 67,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DR AHMAD TERMIZI RAMLI',
        'parti': 'PKR',
    },
    847: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6734,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MASLIN SHAM BIN RAZMAN ',
        'parti': 'BN',
    },
    848: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6734,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LAKSAMANA PERTAMA (B) MOHAMAD IMRAN BIN ABD HAMID ',
        'parti': 'PKR',
    },
    849: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6734,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'INTAN NORHANI BINTI MOHAMAD BASIR',
        'parti': 'PAS',
    },
    850: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6735,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAMIL DZULKARNAIN',
        'parti': 'PAS',
    },
    851: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6735,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJI MOHAMAD ISA BIN JAAFAR ',
        'parti': 'PKR',
    },
    852: {
        'KodN': 6,
        'KodParlimen': 67,
        'KodKawasan': 6735,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD ZURAIMI RAZALI',
        'parti': 'BN',
    },
    853: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 68,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'PANG CHOK KING',
        'parti': 'BN',
    },
    854: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 68,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMAD NAZEER BIN M K M HAMEED',
        'parti': 'PAS',
    },
    855: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 68,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NGEH KOO HAM',
        'parti': 'PKR',
    },
    856: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6836,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAKARIA BIN HASHIM',
        'parti': 'PAS',
    },
    857: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6836,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MURAD BIN ABDULLAH',
        'parti': 'PKR',
    },
    858: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6836,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABD MANAF BIN HASHIM',
        'parti': 'BN',
    },
    859: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6837,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WONG MAY ING',
        'parti': 'PKR',
    },
    860: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6837,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HO KEAN WEI',
        'parti': 'BN',
    },
    861: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6838,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TENG KEEK SOONG',
        'parti': 'BN',
    },
    862: {
        'KodN': 6,
        'KodParlimen': 68,
        'KodKawasan': 6838,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TEOH YEE CHERN',
        'parti': 'PKR',
    },
    863: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 69,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DR. NAJIHATUSSALEHAH BT AHMAD',
        'parti': 'PAS',
    },
    864: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 69,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO MOHD NIZAR BIN ZAKARIA',
        'parti': 'BN',
    },
    865: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 69,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TARMIZI BIN MOHD JAM',
        'parti': 'PKR',
    },
    866: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6939,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUDDIN BIN ABU HANIPAH',
        'parti': 'BN',
    },
    867: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6939,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USTAZ MOHD ZAHID BIN ABU BAKAR',
        'parti': 'PAS',
    },
    868: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6939,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAJI YAHANIS BIN YAHYA',
        'parti': 'PKR',
    },
    869: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6940,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZRUL HAKKIM BIN AZHAR',
        'parti': 'PKR',
    },
    870: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6940,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USTAZ HJ MUHAMMAD ISMI BIN HJ MAT TAIB',
        'parti': 'PAS',
    },
    871: {
        'KodN': 6,
        'KodParlimen': 69,
        'KodKawasan': 6940,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KHAIRUL SHAHRIL BIN MOHAMED',
        'parti': 'BN',
    },
    872: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 70,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'YOUGAN A/L MAHALINGAM',
        'parti': 'PAS',
    },
    873: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 70,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'LEE CHEE LEONG',
        'parti': 'BN',
    },
    874: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 70,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SU KEONG SIONG',
        'parti': 'PKR',
    },
    875: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7041,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHANG GWO CHYANG',
        'parti': 'BN',
    },
    876: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7041,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEONG CHEOK KENG',
        'parti': 'PKR',
    },
    877: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7041,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'BAWANI A/P KANIAPAN',
        'parti': 'PSM',
    },
    878: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7042,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHONG ZHEMIN',
        'parti': 'PKR',
    },
    879: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7042,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DANIEL WA WAI HOW',
        'parti': 'BN',
    },
    880: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7043,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NOLEE ASHILIN BINTI MOHAMED RADZI',
        'parti': 'BN',
    },
    881: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7043,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USTAZ HAJI MOHD SOFIAN BIN HAJI REJAB',
        'parti': 'PAS',
    },
    882: {
        'KodN': 6,
        'KodParlimen': 70,
        'KodKawasan': 7043,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD AZLAN HELMI BIN HELMI',
        'parti': 'PKR',
    },
    883: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 71,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DR LEE BOON CHYE',
        'parti': 'PKR',
    },
    884: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 71,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ISMAIL BIN ARIFFIN',
        'parti': 'PAS',
    },
    885: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 71,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HENG SEAI KIE',
        'parti': 'BN',
    },
    886: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7144,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RADZI BIN ZAINON',
        'parti': 'PAS',
    },
    887: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7144,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO SERI NIZAR JAMALUDDIN',
        'parti': 'PKR',
    },
    888: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7144,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HAMZAH BIN MOHAMAD KASIM',
        'parti': 'BN',
    },
    889: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7145,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ARIF ABD LATIFF ',
        'parti': 'PAS',
    },
    890: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7145,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIEW YEE LIN',
        'parti': 'BN',
    },
    891: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7145,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN KAR HING',
        'parti': 'PKR',
    },
    892: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7146,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ALBERT CHANG CHUN CHEUN',
        'parti': 'BN',
    },
    893: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7146,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOKHTAR ABDULLAH',
        'parti': 'PAS',
    },
    894: {
        'KodN': 6,
        'KodParlimen': 71,
        'KodKawasan': 7146,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SANDREA NG SHAI CHEE',
        'parti': 'PKR',
    },
    895: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 72,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED AZNI MOHAMED ALI',
        'parti': 'PKR',
    },
    896: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 72,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': ' DATUK SERI M. SARAVANAN  ',
        'parti': 'BN',
    },
    897: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 72,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NOR AZLI MUSA',
        'parti': 'PAS',
    },
    898: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7247,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHOONG SHIN HENG',
        'parti': 'BN',
    },
    899: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7247,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD FAIZAL DATO AZUMU',
        'parti': 'PKR',
    },
    900: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7247,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NORDIN HASSAN ',
        'parti': 'PAS',
    },
    901: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7248,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SALMAH ABD LATIF',
        'parti': 'PAS',
    },
    902: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7248,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN SENG TOH',
        'parti': 'PKR',
    },
    903: {
        'KodN': 6,
        'KodParlimen': 72,
        'KodKawasan': 7248,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATO SAMSUDIN ABU HASSAN',
        'parti': 'BN',
    },
    904: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 73,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DR SALIHUDDIN',
        'parti': 'PKR',
    },
    905: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 73,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO SRI TAJUDDIN B ABDUL RAHMAN',
        'parti': 'BN',
    },
    906: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 73,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'USTAZ ZAFARULAZHAN ',
        'parti': 'PAS',
    },
    907: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7349,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUSTAFA KAMAL B MAULUT',
        'parti': 'BEBAS',
    },
    908: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7349,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAINOL FADZI B PAHARUDIN',
        'parti': 'BN',
    },
    909: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7349,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD MAHARANI B MD TASI',
        'parti': 'PKR',
    },
    910: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7349,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHAMAD YUSOFF B ABDULLAH',
        'parti': 'PAS',
    },
    911: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7350,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK DR WAN NORASHIKIN BT WAN NORDIN',
        'parti': 'BN',
    },
    912: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7350,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CIKGU ZAITON',
        'parti': 'PKR',
    },
    913: {
        'KodN': 6,
        'KodParlimen': 73,
        'KodKawasan': 7350,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'USTAZ MUSTAFA SHAARI',
        'parti': 'PAS',
    },
    914: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 74,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' SERI DIRAJA DR ZAMBRY BIN ABD KADIR",
        'parti': 'BN',
    },
    915: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 74,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMMAD ZAMRI BIN IBRAHIM',
        'parti': 'PAS',
    },
    916: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 74,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR. MOHD HATTA BIN MD RAMLI',
        'parti': 'PKR',
    },
    917: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7451,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO RASHIDI BIN IBRAHIM',
        'parti': 'BN',
    },
    918: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7451,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROHAWATI ABIDIN',
        'parti': 'PAS',
    },
    919: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7451,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YAHAYA MAT NOR',
        'parti': 'PKR',
    },
    920: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7452,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO SERI DIRAJA DR ZAMBRY BIN ABD KADIR',
        'parti': 'BN',
    },
    921: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7452,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAINAL ABIDIN BIN SAAD',
        'parti': 'PAS',
    },
    922: {
        'KodN': 6,
        'KodParlimen': 74,
        'KodKawasan': 7452,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NORDIN BIN AHMAD ISMAIL',
        'parti': 'PKR',
    },
    923: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 75,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ATA ABDUL MUNIM HASAN ADLI',
        'parti': 'PAS',
    },
    924: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 75,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': ' AHMAD ZAHID BIN HAMIDI',
        'parti': 'BN',
    },
    925: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 75,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'PAKHRURRAZI BIN HJ ARSHAD',
        'parti': 'PKR',
    },
    926: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7553,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SHAHRUL ZAMAN BIN YAHYA',
        'parti': 'BN',
    },
    927: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7553,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HATIM BIN MUSA',
        'parti': 'PKR',
    },
    928: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7553,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD MOKHERI BIN JALIL',
        'parti': 'PAS',
    },
    929: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7554,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MANNIVANAN A/L GOWINDASAMY',
        'parti': 'PKR',
    },
    930: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7554,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD MISBAHUL MUNIR BIN MASDUKI',
        'parti': 'PAS',
    },
    931: {
        'KodN': 6,
        'KodParlimen': 75,
        'KodKawasan': 7554,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KHAIRUDDIN BIN TARMIZI',
        'parti': 'BN',
    },
    932: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 76,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NGA KOR MING',
        'parti': 'PKR',
    },
    933: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 76,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DR AHMAD RAMADZAN BIN AHMAD DAUD',
        'parti': 'PAS',
    },
    934: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 76,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MAH SIEW KEONG',
        'parti': 'BN',
    },
    935: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7655,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KONG SUN CHIN',
        'parti': 'BN',
    },
    936: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7655,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TERENCE NAIDU ',
        'parti': 'PKR',
    },
    937: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7655,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'S.KUMARESAN',
        'parti': 'PAS',
    },
    938: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7656,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD AZHAR BIN JAMALUDDIN',
        'parti': 'BN',
    },
    939: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7656,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD FAIZUL BIN MOHAMED ISMAIL',
        'parti': 'PKR',
    },
    940: {
        'KodN': 6,
        'KodParlimen': 76,
        'KodKawasan': 7656,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD AZHAR BIN MOHD RAFIEI',
        'parti': 'PAS',
    },
    941: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 77,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD TARMIZI BIN ABD RAHMAN',
        'parti': 'PAS',
    },
    942: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 77,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MAH HANG SOON',
        'parti': 'BN',
    },
    943: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 77,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CHANG LIH KANG',
        'parti': 'PKR',
    },
    944: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7757,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'APPLASAMY A/L JETAKIAH',
        'parti': 'PAS',
    },
    945: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7757,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ELANGO A/L VADIL VELOO',
        'parti': 'BN',
    },
    946: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7757,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SIVANESAN A/L SUBRAMANIAM',
        'parti': 'PKR',
    },
    947: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7758,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ZULFADLI BIN ZAINAL',
        'parti': 'PAS',
    },
    948: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7758,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD KHUSAIRI BIN ABD TALIB',
        'parti': 'BN',
    },
    949: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7758,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMRAN BIN IBRAHIM',
        'parti': 'PKR',
    },
    950: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7759,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SYED ZAMZURI BIN SYED NENGAH',
        'parti': 'PAS',
    },
    951: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7759,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RUSNAH BINTI KASSIM',
        'parti': 'BN',
    },
    952: {
        'KodN': 6,
        'KodParlimen': 77,
        'KodKawasan': 7759,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMINUDDIN BIN ZULKIPLI',
        'parti': 'PKR',
    },
    953: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 78,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'MOHD TAHIR BIN HAJI KASSIM',
        'parti': 'BERJASA',
    },
    954: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 78,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MANOGARAN MARIMUTHU',
        'parti': 'PKR',
    },
    955: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 78,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WAN MAHADIR BIN WAN MAHMUD',
        'parti': 'PAS',
    },
    956: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 78,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SIVARAJ A/L CHANDRAN',
        'parti': 'BN',
    },
    957: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 78,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'SURESH KUMAR A/L BALASUBRAMANIAM',
        'parti': 'PSM',
    },
    958: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7801,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHIONG YOKE KONG',
        'parti': 'PKR',
    },
    959: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7801,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEONG TAK MAN',
        'parti': 'BN',
    },
    960: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7801,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KUMAR A/L SILAMBARAM',
        'parti': 'PAS',
    },
    961: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7802,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL RASID BIN MOHAMED ALI',
        'parti': 'PKR',
    },
    962: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7802,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL KARIM BIN NOR',
        'parti': 'PAS',
    },
    963: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7802,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MAT NOR A/L AYAT',
        'parti': 'PSM',
    },
    964: {
        'KodN': 7,
        'KodParlimen': 78,
        'KodKawasan': 7802,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'WAN ROSDY BIN WAN ISMAIL',
        'parti': 'BN',
    },
    965: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 79,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABDUL RAHMAN BIN MOHAMAD',
        'parti': 'BN',
    },
    966: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 79,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'BAHARUDIN BIN ABD RAHMAN',
        'parti': 'PKR',
    },
    967: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 79,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SOBIRIN BIN DULI',
        'parti': 'PAS',
    },
    968: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7903,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ALIAS BIN ABDUL RAHMAN',
        'parti': 'PKR',
    },
    969: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7903,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUSTAPA BIN LONG',
        'parti': 'BN',
    },
    970: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7903,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROSLAN BIN HARUN',
        'parti': 'PAS',
    },
    971: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7904,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SALUDIN BIN ENDOL',
        'parti': 'PAS',
    },
    972: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7904,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RASHID BIN MUHAMAD',
        'parti': 'PKR',
    },
    973: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7904,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEE AH WONG',
        'parti': 'BN',
    },
    974: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7905,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SOFFI BIN ABD RAZAK',
        'parti': 'BN',
    },
    975: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7905,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ANUAR BIN KASIM',
        'parti': 'PAS',
    },
    976: {
        'KodN': 7,
        'KodParlimen': 79,
        'KodKawasan': 7905,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SABARUDDIN BIN MOHD YASSIM',
        'parti': 'PKR',
    },
    977: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 80,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'TENGKU ZULPURI SHAH BIN RAJA PUJI',
        'parti': 'PKR',
    },
    978: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 80,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CHEW MEI FUN',
        'parti': 'BN',
    },
    979: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 80,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMED NILAM BIN ABDUL MANAP',
        'parti': 'PAS',
    },
    980: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8006,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD AZIZ BIN MAT KIRAM',
        'parti': 'BN',
    },
    981: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8006,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DASIMAH BINTI ZAINUDIN',
        'parti': 'PKR',
    },
    982: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8006,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "TENGKU ABDUL RAHMAN BIN TENGKU JA'AFAR",
        'parti': 'PAS',
    },
    983: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8007,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG LEAP PONG',
        'parti': 'BN',
    },
    984: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8007,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHIN CHOY HEE',
        'parti': 'PAS',
    },
    985: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8007,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHOW YU HUI',
        'parti': 'PKR',
    },
    986: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8008,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SHAHIRUDDIN BIN AB MOIN',
        'parti': 'BN',
    },
    987: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8008,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAMZAH BIN JAAFFAR',
        'parti': 'PKR',
    },
    988: {
        'KodN': 7,
        'KodParlimen': 80,
        'KodKawasan': 8008,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BEDU RAHIM BIN ISMAIL',
        'parti': 'PAS',
    },
    989: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 81,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO HAJI AHMAD NAZLAN BIN IDRIS',
        'parti': 'BN',
    },
    990: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 81,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WAN MOHD SHAHARIR BIN WAN ABD JALIL',
        'parti': 'PKR',
    },
    991: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 81,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'YOHANIS BIN AHMAD',
        'parti': 'PAS',
    },
    992: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8109,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZAKHWAN BIN BADARDDIN',
        'parti': 'PAS',
    },
    993: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8109,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN AMIZAN BIN WAN ABD RAZAK',
        'parti': 'BN',
    },
    994: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8109,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORDIN BIN SAMAT',
        'parti': 'PKR',
    },
    995: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8110,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO LIM CHONG LY',
        'parti': 'BN',
    },
    996: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8110,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WONG CHUN YUAN',
        'parti': 'PKR',
    },
    997: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8110,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZURIDAN BIN DAUD',
        'parti': 'PAS',
    },
    998: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8111,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO HAJI NAZRI BIN CHE NGAH',
        'parti': 'BN',
    },
    999: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8111,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAMALUDDIN BIN ABD RAHIM',
        'parti': 'PKR',
    },
    1000: {
        'KodN': 7,
        'KodParlimen': 81,
        'KodKawasan': 8111,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AHMAD NAAWI BIN SAMAH',
        'parti': 'PAS',
    },
    1001: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 82,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "DATO' DR JOHAN BIN MAT SAH",
        'parti': 'BN',
    },
    1002: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 82,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SAIFUDDIN BIN ABDULLAH',
        'parti': 'PKR',
    },
    1003: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 82,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NASRUDIN BIN HASSAN',
        'parti': 'PAS',
    },
    1004: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8212,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' SUHAIMI BIN JUSOH @ SULONG",
        'parti': 'BN',
    },
    1005: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8212,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ANDANSURA BIN RABU',
        'parti': 'PAS',
    },
    1006: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8212,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZULKIFLI BIN MOHAMED',
        'parti': 'PKR',
    },
    1007: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8213,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'QUEK TAI SEONG',
        'parti': 'BN',
    },
    1008: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8213,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD YUSOF BIN HASHIM',
        'parti': 'PAS',
    },
    1009: {
        'KodN': 7,
        'KodParlimen': 82,
        'KodKawasan': 8213,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE CHEAN CHUNG',
        'parti': 'PKR',
    },
    1010: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 83,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WONG KEAN HWEE',
        'parti': 'BN',
    },
    1011: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 83,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'FUZIAH BINTI SALLEH',
        'parti': 'PKR',
    },
    1012: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 83,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'SULAIMAN BIN MD DERUS',
        'parti': 'PAS',
    },
    1013: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8314,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZIZAH BINTI MOHD ALI',
        'parti': 'PAS',
    },
    1014: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8314,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TEE CHOON SER',
        'parti': 'BN',
    },
    1015: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8314,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SIM CHON SIANG',
        'parti': 'PKR',
    },
    1016: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8315,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'T. ZULKIFLI BIN T. AHMAD',
        'parti': 'BN',
    },
    1017: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8315,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SABRINA BT MD YUSOF',
        'parti': 'PKR',
    },
    1018: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8315,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROSLI BIN ABD JABBAR',
        'parti': 'PAS',
    },
    1019: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8316,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FAKHRUL ANUAR BIN ZULKAWI',
        'parti': 'PKR',
    },
    1020: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8316,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SHAFIK FAUZAN BIN SHARIF',
        'parti': 'BN',
    },
    1021: {
        'KodN': 7,
        'KodParlimen': 83,
        'KodKawasan': 8316,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'WAN MASERI BINTI WAN MOHAMAD',
        'parti': 'PAS',
    },
    1022: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 84,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD SHAHAR BIN ABDULLAH',
        'parti': 'BN',
    },
    1023: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 84,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD ASHRAF MUSTAQIM BIN BADRUL MUNIR',
        'parti': 'PKR',
    },
    1024: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 84,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD AZHAR BIN MOHAMAD NOOR ',
        'parti': 'PAS',
    },
    1025: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8417,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD. SOHAIMI BIN MOHAMAD SHAH',
        'parti': 'BN',
    },
    1026: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8417,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FAUZI BIN ABDUL RAHMAN',
        'parti': 'PKR',
    },
    1027: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8417,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAZMIN BIN DIBOK',
        'parti': 'PAS',
    },
    1028: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8418,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABD. RAHIM BIN MUDA',
        'parti': 'BN',
    },
    1029: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8418,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD NOR HISHAM BIN MUHAMMAD',
        'parti': 'PAS',
    },
    1030: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8418,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NUR ADDIN BIN IBRAHIM',
        'parti': 'PKR',
    },
    1031: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8419,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ZAILI BIN HJ. BESAR',
        'parti': 'BN',
    },
    1032: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8419,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD TARMIZI BIN YAHAYA',
        'parti': 'PAS',
    },
    1033: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8419,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KAMARZAMAN BIN MOHAMED YUNUS',
        'parti': 'PKR',
    },
    1034: {
        'KodN': 7,
        'KodParlimen': 84,
        'KodKawasan': 8419,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'BENZIN BIN DAGOK',
        'parti': 'BEBAS',
    },
    1035: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 85,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ABD KADIR BIN SAINUDDIN',
        'parti': 'BEBAS',
    },
    1036: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 85,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'AHIATUDIN BIN DAUD',
        'parti': 'PAS',
    },
    1037: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 85,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'najib razak',
        'parti': 'BN',
    },
    1038: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 85,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUHAMMAD ZAHID BIN MD ARIP',
        'parti': 'PKR',
    },
    1039: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8520,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUDDIN BIN MAHMOD',
        'parti': 'BN',
    },
    1040: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8520,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAINUDDIN BIN NOH',
        'parti': 'PAS',
    },
    1041: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8520,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABU BAKAR BIN LEBAI SUDIN',
        'parti': 'PKR',
    },
    1042: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8521,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SH MOHMED PUZI BIN SH AL',
        'parti': 'BN',
    },
    1043: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8521,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SALIM BIN ABDUL MAJID',
        'parti': 'PKR',
    },
    1044: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8521,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABU KASSIM BIN MANAF',
        'parti': 'PAS',
    },
    1045: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8522,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMMAD FAKHRUDDIN BIN MOHD ARIFF',
        'parti': 'BN',
    },
    1046: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8522,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AFIF SYAIROL BIN ABDUL RAHIM ',
        'parti': 'PKR',
    },
    1047: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8522,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD NAZHAR BIN OTHMAN',
        'parti': 'PAS',
    },
    1048: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8523,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABU BAKAR BIN HARUN ',
        'parti': 'BN',
    },
    1049: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8523,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD RAZALI BIN ITHNAIN ',
        'parti': 'PKR',
    },
    1050: {
        'KodN': 7,
        'KodParlimen': 85,
        'KodKawasan': 8523,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD FADHIL NOOR BIN ABDUL KARIM',
        'parti': 'PAS',
    },
    1051: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 86,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD FARID BIN AHMAD NORDIN',
        'parti': 'PKR',
    },
    1052: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 86,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HASENAN BIN HARUN',
        'parti': 'PAS',
    },
    1053: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 86,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' SRI DR. HJ. ISMAIL BIN ABD MUTTALIB",
        'parti': 'BN',
    },
    1054: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8624,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SOFIAN BIN ABD JALIL',
        'parti': 'PAS',
    },
    1055: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8624,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "NURHIDAYAH BINTI DATO' MOHAMAD SHAHAIMI",
        'parti': 'BN',
    },
    1056: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8624,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROSLI BIN AMIN',
        'parti': 'PKR',
    },
    1057: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8625,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BOSTAMIN BIN BAKAR',
        'parti': 'PKR',
    },
    1058: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8625,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' SRI HJH SHAHANIZA BINTI SHAMSUDIN",
        'parti': 'BN',
    },
    1059: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8625,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'FAZIL AZMI BIN NADZRI',
        'parti': 'PAS',
    },
    1060: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8626,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUJIBUR RAHMAN BIN ISHAK',
        'parti': 'PAS',
    },
    1061: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8626,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' HJ MOHAMED ARIFIN BIN AWANG ISMAIL",
        'parti': 'BN',
    },
    1062: {
        'KodN': 7,
        'KodParlimen': 86,
        'KodKawasan': 8626,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZULIANA BINTI MOHAMED',
        'parti': 'PKR',
    },
    1063: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 87,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'Kamal bin Ashaari ',
        'parti': 'PAS',
    },
    1064: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 87,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'Mohamad Rafidee bin Hassim',
        'parti': 'PKR',
    },
    1065: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 87,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "Dato' Sri Hj Ismail bin Hj Mohamed Said",
        'parti': 'BN',
    },
    1066: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8727,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "Dato' Sri Hj Mohamed bin Hj Jaafar",
        'parti': 'BN',
    },
    1067: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8727,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Abdullah bin Yusoh',
        'parti': 'PAS',
    },
    1068: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8727,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Faizah binti Baharum',
        'parti': 'PKR',
    },
    1069: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8728,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "Dato' Sri Syed Ibrahim bin Syed Ahmad",
        'parti': 'BN',
    },
    1070: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8728,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Aireroshsiri bin Roslan',
        'parti': 'PAS',
    },
    1071: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8728,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Adnan bin Abdul Manaf',
        'parti': 'PKR',
    },
    1072: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8729,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "Dato' Hj Wan Salman bin Hj Wan Ismail",
        'parti': 'BN',
    },
    1073: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8729,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'Shahril Azman bin Abd Halim',
        'parti': 'PAS',
    },
    1074: {
        'KodN': 7,
        'KodParlimen': 87,
        'KodKawasan': 8729,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'Jalani bin Ludin',
        'parti': 'PKR',
    },
    1075: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 88,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO'SRI HAJI MOHD SHARKAR BIN SHAMSUDDIN",
        'parti': 'BN',
    },
    1076: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 88,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'MOHD ANUAR BIN MOHD TAHIR',
        'parti': 'PKR',
    },
    1077: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 88,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'MOHD JUSOH BIN DARUS',
        'parti': 'PAS',
    },
    1078: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 88,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMAD FAKHRUDDIN BIN ABU HANIPAH',
        'parti': 'BEBAS',
    },
    1079: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 88,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHAIDIR BIN AHMAD',
        'parti': 'BEBAS',
    },
    1080: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8830,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' WONG TAT CHEE @ WONG TAI CHEE",
        'parti': 'BN',
    },
    1081: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8830,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'WOO CHEE-WAN',
        'parti': 'PKR',
    },
    1082: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8830,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABIRERAH BIN AWANG CHIK',
        'parti': 'PAS',
    },
    1083: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8830,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO CHUAH BOON-SEONG',
        'parti': 'BEBAS',
    },
    1084: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8831,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK SERI HAJI MOHD SHARKAR BIN SHAMSUDDIN',
        'parti': 'BN',
    },
    1085: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8831,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD KHAIDIR BIN AHMAD',
        'parti': 'BEBAS',
    },
    1086: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8831,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HASSAN BIN OMAR',
        'parti': 'PAS',
    },
    1087: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8831,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABAS BIN AWANG',
        'parti': 'PKR',
    },
    1088: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8832,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' NOR AZMI BIN MAT LUDIN",
        'parti': 'BN',
    },
    1089: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8832,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SYED HAMID BIN SYED MOHAMED',
        'parti': 'PKR',
    },
    1090: {
        'KodN': 7,
        'KodParlimen': 88,
        'KodKawasan': 8832,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HASANUDDIN BIN SALIM',
        'parti': 'PAS',
    },
    1091: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 89,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK SERI LIOW TIONG LAI',
        'parti': 'BN',
    },
    1092: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 89,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'BALASUBRAMANIAN NACHIAPAN',
        'parti': 'PAS',
    },
    1093: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 89,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WONG TACK',
        'parti': 'PKR',
    },
    1094: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8933,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE CHIN CHEN',
        'parti': 'PKR',
    },
    1095: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8933,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZAMRI BIN NONG',
        'parti': 'PAS',
    },
    1096: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8933,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'POO MUN HOONG',
        'parti': 'BN',
    },
    1097: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8934,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LAU HOI KEONG',
        'parti': 'BN',
    },
    1098: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8934,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YOUNG SYEFURA BINTI OTHMAN',
        'parti': 'PKR',
    },
    1099: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8934,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'USTAZ ROSLAN MD ESA',
        'parti': 'PAS',
    },
    1100: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8935,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' GOONASAKAREN A/L RAMAN",
        'parti': 'BN',
    },
    1101: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8935,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KAMACHE',
        'parti': 'PKR',
    },
    1102: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8935,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'T.KARUNANEETHI',
        'parti': 'BEBAS',
    },
    1103: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8935,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD KHAIRUDDIN BIN ABDULLAH',
        'parti': 'PAS',
    },
    1104: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8936,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK SERI HAJI ADNAN HAJI YAAKOB',
        'parti': 'BN',
    },
    1105: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8936,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CIKGU NOR HAIZAN @ CIKGU ENAB',
        'parti': 'PKR',
    },
    1106: {
        'KodN': 7,
        'KodParlimen': 89,
        'KodKawasan': 8936,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAHARIM BIN OSMAN',
        'parti': 'PAS',
    },
    1107: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 90,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ZAKARIA BIN ABDUL HAMID',
        'parti': 'PKR',
    },
    1108: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 90,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MUSANIFF BIN AB RAHMAN',
        'parti': 'PAS',
    },
    1109: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 90,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' SRI ISMAIL SABRI BIN YAAKOB",
        'parti': 'BN',
    },
    1110: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9037,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SHAHRUL BIN MOHAMED',
        'parti': 'PAS',
    },
    1111: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9037,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD MAJDIL FAUZI BIN ABD AZIZ',
        'parti': 'PKR',
    },
    1112: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9037,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' SRI NOROLAZALI BIN SULAIMAN",
        'parti': 'BN',
    },
    1113: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9038,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEONG YU MAN',
        'parti': 'PKR',
    },
    1114: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9038,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN TIN LOON',
        'parti': 'BN',
    },
    1115: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9039,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MANOLAN BIN MOHAMAD',
        'parti': 'PKR',
    },
    1116: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9039,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MD YUSOF BIN CHE DIN',
        'parti': 'PAS',
    },
    1117: {
        'KodN': 7,
        'KodParlimen': 90,
        'KodKawasan': 9039,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' MOHD FADIL BIN OSMAN",
        'parti': 'BN',
    },
    1118: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 91,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'M SHAHRUL NIZAM BIN ABDUL HALIFF',
        'parti': 'PAS',
    },
    1119: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 91,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SITANURISAH BINTI AB. KADIR',
        'parti': 'PKR',
    },
    1120: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 91,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HASAN BIN ARIFIN',
        'parti': 'BN',
    },
    1121: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9140,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAMSIAH BINTI ARSHAD',
        'parti': 'BN',
    },
    1122: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9140,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NAZRI BIN AHMAD',
        'parti': 'PAS',
    },
    1123: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9140,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZULKURNAIN BIN MOHAMAD RIDZUAN',
        'parti': 'PKR',
    },
    1124: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9141,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAZALI BIN KASSIM',
        'parti': 'BN',
    },
    1125: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9141,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAMLI BIN AWANG AHMAT',
        'parti': 'PAS',
    },
    1126: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9141,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'OSMAN BIN A.BAKAR',
        'parti': 'PKR',
    },
    1127: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9142,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD JOHARI BIN HUSSIN',
        'parti': 'BN',
    },
    1128: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9142,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ZOLFAKAR BIN TAIB',
        'parti': 'BEBAS',
    },
    1129: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9142,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD YUNOS BIN RAMLI',
        'parti': 'PAS',
    },
    1130: {
        'KodN': 7,
        'KodParlimen': 91,
        'KodKawasan': 9142,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AHMAD SAZILI BIN MOHD NOR',
        'parti': 'PKR',
    },
    1131: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 92,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD FASIAH BIN MOHD FAKEH',
        'parti': 'BN',
    },
    1132: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 92,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD LABIB BIN ABD JALIL',
        'parti': 'PAS',
    },
    1133: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 92,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WARNO BIN DOGOL',
        'parti': 'PKR',
    },
    1134: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9201,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RIZAM BIN ISMAIL',
        'parti': 'BN',
    },
    1135: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9201,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAMRI BIN YAHYA',
        'parti': 'PAS',
    },
    1136: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9201,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD HAMIZAR BIN SULAIMAN',
        'parti': 'PKR',
    },
    1137: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9202,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SALLEHUDDIN BIN MOHD ISKAN',
        'parti': 'BN',
    },
    1138: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9202,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHMAD MUSTAIN BIN OTHMAN',
        'parti': 'PKR',
    },
    1139: {
        'KodN': 8,
        'KodParlimen': 92,
        'KodKawasan': 9202,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SALLEHEN BIN MUKHYI',
        'parti': 'PAS',
    },
    1140: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 93,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'BUDIMAN BIN MOHD ZOHDI',
        'parti': 'BN',
    },
    1141: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 93,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MUSLIMIN BIN YAHYA',
        'parti': 'PKR',
    },
    1142: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 93,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMED SALLEH MOHD HUSIN',
        'parti': 'PAS',
    },
    1143: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9303,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO IMRAN BIN TAMRIN',
        'parti': 'BN',
    },
    1144: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9303,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MARIAM BINTI ABDUL RASHID',
        'parti': 'PKR',
    },
    1145: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9303,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD RAZALI BIN SHAARI',
        'parti': 'PAS',
    },
    1146: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9304,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LEE YEE YUAN',
        'parti': 'BN',
    },
    1147: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9304,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG SUEE LIM',
        'parti': 'PKR',
    },
    1148: {
        'KodN': 8,
        'KodParlimen': 93,
        'KodKawasan': 9304,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FADZLIN BIN TASLIMIN',
        'parti': 'PAS',
    },
    1149: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 94,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK P KAMALANATHAN A/L PANCHANATHAN',
        'parti': 'BN',
    },
    1150: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 94,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'DR WAN MAT BIN SULAIMAN',
        'parti': 'PAS',
    },
    1151: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 94,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JUNE LEOW HSIAD HUI',
        'parti': 'PKR',
    },
    1152: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 94,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KUMAR A/L S PARAMASIVAM',
        'parti': 'BEBAS',
    },
    1153: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9405,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HAJAH ROSNI BINTI SOHAR',
        'parti': 'BN',
    },
    1154: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9405,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD AMRAN BIN SAKIR',
        'parti': 'PKR',
    },
    1155: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9405,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHAMMED SALLEH BIN RI',
        'parti': 'PAS',
    },
    1156: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9406,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK WONG KOON MUN',
        'parti': 'BN',
    },
    1157: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9406,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEE KEE HIONG',
        'parti': 'PKR',
    },
    1158: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9406,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NAHARUDDIN BIN ABDUL RASHID',
        'parti': 'PAS',
    },
    1159: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9407,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK HAJI MAT NADZARI BIN AHMAD DAHLAN',
        'parti': 'BN',
    },
    1160: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9407,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HARUMAINI BIN HAJI OMAR',
        'parti': 'PKR',
    },
    1161: {
        'KodN': 8,
        'KodParlimen': 94,
        'KodKawasan': 9407,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD HASNIZAN BIN HARUN',
        'parti': 'PAS',
    },
    1162: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 95,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TS NOH BIN OMAR',
        'parti': 'BN',
    },
    1163: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 95,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NOR AZ AZLAN BIN AHMAD',
        'parti': 'PAS',
    },
    1164: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 95,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK DR ZULKAFERI HANAFI',
        'parti': 'PKR',
    },
    1165: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9508,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SAMSUDIN BIN LIAS',
        'parti': 'BN',
    },
    1166: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9508,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD ZAMRI BIN ZAINUDDIN ',
        'parti': 'PAS',
    },
    1167: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9508,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD AZMIL BIN MISMAN ',
        'parti': 'PKR',
    },
    1168: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9509,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SULAIMAN BIN ABDUL RAZAK ',
        'parti': 'BN',
    },
    1169: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9509,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROZANA ZAINAL ABIDIN ',
        'parti': 'PKR',
    },
    1170: {
        'KodN': 8,
        'KodParlimen': 95,
        'KodKawasan': 9509,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD JAFARUDDIN SYEIK DAUD ',
        'parti': 'PAS',
    },
    1171: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 96,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO SRI DR. IRMOHIZAM BIN IBRAHIM',
        'parti': 'BN',
    },
    1172: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 96,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DR DZULKEFLEY BIN  AHMAD',
        'parti': 'PKR',
    },
    1173: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 96,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'FAKARUDDIN  BIN ISMAIL',
        'parti': 'AKIM',
    },
    1174: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9610,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAKIRAN BIN JACOMAH',
        'parti': 'BN',
    },
    1175: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9610,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JUWAIRIYA BT ZULKIFLI',
        'parti': 'PKR',
    },
    1176: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9610,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD RASHID BIN MUHAMMAD KASIM',
        'parti': 'PAS',
    },
    1177: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9611,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PARTHIBAN A/L KARUPPIAH',
        'parti': 'BN',
    },
    1178: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9611,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JEFRI BIN MEJAN',
        'parti': 'PAS',
    },
    1179: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9611,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'KUMARAN A/L TAMIL DASSEN',
        'parti': 'PRM',
    },
    1180: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9611,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR IDRIS BIN AHMAD',
        'parti': 'PKR',
    },
    1181: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9612,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAHAR AZLAN BIN ARIFIN',
        'parti': 'BN',
    },
    1182: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9612,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD NOOR MOHD SHAHAR',
        'parti': 'PAS',
    },
    1183: {
        'KodN': 8,
        'KodParlimen': 96,
        'KodKawasan': 9612,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SHAHID ROSLI',
        'parti': 'PKR',
    },
    1184: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 97,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KANG MENG FUAT',
        'parti': 'BN',
    },
    1185: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 97,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'BRIG. GEN HASHIM KARIM',
        'parti': 'PAS',
    },
    1186: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 97,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'WILLIAM LEONG JEE KEEN',
        'parti': 'PKR',
    },
    1187: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9713,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SALLEH AMIRUDDIN',
        'parti': 'PKR',
    },
    1188: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9713,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL SHUKUR IDRUS',
        'parti': 'BN',
    },
    1189: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9713,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD FAUZAN MADZLAN',
        'parti': 'PAS',
    },
    1190: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9713,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD RAFIE MOHAMMAD ARIF',
        'parti': 'PRM',
    },
    1191: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9714,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHUA WEI KIAT',
        'parti': 'PKR',
    },
    1192: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9714,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'CHAN WUN HOONG',
        'parti': 'BN',
    },
    1193: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9714,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KONG TUCK WAH',
        'parti': 'PAS',
    },
    1194: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9714,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMAN MOHD NOOR',
        'parti': 'BEBAS',
    },
    1195: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9715,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAIDY ABDUL TALIB',
        'parti': 'PAS',
    },
    1196: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9715,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'IR MD NASIR IBRAHIM',
        'parti': 'BN',
    },
    1197: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9715,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KOH SWE YONG',
        'parti': 'PRM',
    },
    1198: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9715,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD SANY HAMZAN',
        'parti': 'PKR',
    },
    1199: {
        'KodN': 8,
        'KodParlimen': 97,
        'KodKawasan': 9715,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'DR. RAJANDRAN',
        'parti': 'PAP',
    },
    1200: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 98,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK ABDUL RAHIM BIN PANDAK KAMARUDIN',
        'parti': 'BN',
    },
    1201: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 98,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO SERI MOHAMED AZMIN BIN ALI',
        'parti': 'PKR',
    },
    1202: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 98,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'KHAIRIL NIZAM BIN KHIRUDIN',
        'parti': 'PAS',
    },
    1203: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9816,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAWISANDRAN A/L NARAYANAN',
        'parti': 'BN',
    },
    1204: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9816,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'AMIRUDDIN BIN SHARI',
        'parti': 'PKR',
    },
    1205: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9816,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD BIN IBRAHIM',
        'parti': 'PAS',
    },
    1206: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9816,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BADRUL HISAM BIN MD ZIN',
        'parti': 'BEBAS',
    },
    1207: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9817,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MEGAT ZULKARNAIN BIN OMARDIN',
        'parti': 'BN',
    },
    1208: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9817,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD HILMAN BIN IDHAM',
        'parti': 'PKR',
    },
    1209: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9817,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HASBULLAH BIN MOHD RIDZWAN',
        'parti': 'PAS',
    },
    1210: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9818,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ISMAIL BIN AHMAD',
        'parti': 'BN',
    },
    1211: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9818,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAARI BIN SUNGIB',
        'parti': 'PKR',
    },
    1212: {
        'KodN': 8,
        'KodParlimen': 98,
        'KodKawasan': 9818,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KAMALULHYSHAM BIN MOHD SUHUT',
        'parti': 'PAS',
    },
    1213: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 99,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO'LEONG KIM SOON",
        'parti': 'BN',
    },
    1214: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 99,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'TAN HUA MENG',
        'parti': 'PRM',
    },
    1215: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 99,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NURUL ISLAM BIN MOHAMED YUSOFF',
        'parti': 'PAS',
    },
    1216: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 99,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'ZURAIDAH BINTI KAMRUDDIN',
        'parti': 'PKR',
    },
    1217: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9919,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DR. SALWA BINTI YUNUS',
        'parti': 'BN',
    },
    1218: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9919,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SHAHRIFAH HASLIZAH BINTI SYED ARIFFIN',
        'parti': 'PAS',
    },
    1219: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9919,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHAMMED AZWAN BIN ALI',
        'parti': 'BEBAS',
    },
    1220: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9919,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'AHMAD BIN KAMARUDIN',
        'parti': 'PRM',
    },
    1221: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9919,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMED AZMIN BIN ALI',
        'parti': 'PKR',
    },
    1222: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9920,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHAMAD NIZAM BIN SHITH',
        'parti': 'BN',
    },
    1223: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9920,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NORIZUAN BIN MOHAMED ',
        'parti': 'PRM',
    },
    1224: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9920,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HANIZA BINTI MOHAMED TALHA',
        'parti': 'PKR',
    },
    1225: {
        'KodN': 8,
        'KodParlimen': 99,
        'KodKawasan': 9920,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHASIM BIN ABDUL AZIZ',
        'parti': 'PAS',
    },
    1226: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 100,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK LEONG KOK WEE',
        'parti': 'BN',
    },
    1227: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 100,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'MOHD KHAIRUL AZAM BIN ABDUL AZIZ',
        'parti': 'BEBAS',
    },
    1228: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 100,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHAMED SUKRI BIN OMAR',
        'parti': 'PAS',
    },
    1229: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 100,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATIN SRI WAN AZIZAH BINTI WAN ISMAIL',
        'parti': 'PKR',
    },
    1230: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 100,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'LEE YING HA',
        'parti': 'PRM',
    },
    1231: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10021,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HAJI MOHD HANIFF BIN HAJI KOSLAN',
        'parti': 'BN',
    },
    1232: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10021,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'IZHAM BIN HASHIM',
        'parti': 'PKR',
    },
    1233: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10021,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ISKANDAR BIN ABDUL SAMAD',
        'parti': 'PAS',
    },
    1234: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10022,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BEN LIEW POK BOON',
        'parti': 'BN',
    },
    1235: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10022,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEE YING HA',
        'parti': 'PRM',
    },
    1236: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10022,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD IRMAN BIN ABDUL WAHAB',
        'parti': 'PAS',
    },
    1237: {
        'KodN': 8,
        'KodParlimen': 100,
        'KodKawasan': 10022,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'LAI WAI CHONG',
        'parti': 'PKR',
    },
    1238: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 101,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AZMAN BIN AHMAD',
        'parti': 'BN',
    },
    1239: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 101,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DR CHE ROSLI BIN  CHE MAT',
        'parti': 'PAS',
    },
    1240: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 101,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'USTAZ HASAUDDIN BIN MOHD YUNUS',
        'parti': 'PKR',
    },
    1241: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10123,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ZIN BIN ISA',
        'parti': 'BN',
    },
    1242: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10123,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EDRY FAIZAL BIN EDDY YUSOF',
        'parti': 'PKR',
    },
    1243: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10123,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAZALY BIN HASAN',
        'parti': 'PAS',
    },
    1244: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10124,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JOHAN BIN ABD AZIZ',
        'parti': 'BN',
    },
    1245: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10124,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'BAKHTIAR BIN MOHD NOR',
        'parti': 'PKR',
    },
    1246: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10124,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ARUTCHEVAN A/L SUBRAMANIAMS',
        'parti': 'PSM',
    },
    1247: {
        'KodN': 8,
        'KodParlimen': 101,
        'KodKawasan': 10124,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJI MAD SHAHMIOUR BIN MAT SOM',
        'parti': 'PAS',
    },
    1248: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 102,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': "DATO 'LIEW  YUEN KEONG",
        'parti': 'BN',
    },
    1249: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 102,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DR ONG KIAN MIN',
        'parti': 'PKR',
    },
    1250: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 102,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD SHAFIE BIN NGAH',
        'parti': 'PAS',
    },
    1251: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 102,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DENNIS WAN JINN WOEI',
        'parti': 'PRM',
    },
    1252: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10225,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEH YEOW MENG',
        'parti': 'BN',
    },
    1253: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10225,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ZAITON BINTI AHMAD',
        'parti': 'PAS',
    },
    1254: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10225,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HEE LOY SIAN',
        'parti': 'PKR',
    },
    1255: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10225,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DENNIS WAN JINN WOEI',
        'parti': 'PRM',
    },
    1256: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10226,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD RAHIM BIN MOHD AMIN',
        'parti': 'BN',
    },
    1257: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10226,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MAZWAN BIN JOHAR',
        'parti': 'PKR',
    },
    1258: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10226,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "NUSHI BIN DATO' MAHFODZ",
        'parti': 'PAS',
    },
    1259: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10227,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LIM CHIN WAH',
        'parti': 'BN',
    },
    1260: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10227,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NG TIEN CHEE',
        'parti': 'PKR',
    },
    1261: {
        'KodN': 8,
        'KodParlimen': 102,
        'KodKawasan': 10227,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD IBRAHIM BIN GHAZALI',
        'parti': 'PAS',
    },
    1262: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 103,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ANG CHIN TATT',
        'parti': 'BN',
    },
    1263: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 103,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD ROSHARIZAN MOHD ROSLAN',
        'parti': 'PAS',
    },
    1264: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 103,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'GOBIND SINGH DEO',
        'parti': 'PKR',
    },
    1265: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 10328,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHANG TOONG WOH',
        'parti': 'BN',
    },
    1266: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 10328,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EAN YONG HIAN WAH',
        'parti': 'PKR',
    },
    1267: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 10329,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD SATIM BIN DIMAN',
        'parti': 'BN',
    },
    1268: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 10329,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NOOR HANIM ISMAIL',
        'parti': 'PAS',
    },
    1269: {
        'KodN': 8,
        'KodParlimen': 103,
        'KodKawasan': 10329,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR SITI MARIAH MAHMUD',
        'parti': 'PKR',
    },
    1270: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 104,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TAN SEONG LIM',
        'parti': 'BN',
    },
    1271: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 104,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'WONG CHEN',
        'parti': 'PKR',
    },
    1272: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 104,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMAD SHAHIR BIN MOHD ADNAN',
        'parti': 'PAS',
    },
    1273: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 104,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'TOH SIN WAH ',
        'parti': 'BEBAS',
    },
    1274: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10430,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHIEW KAI HENG',
        'parti': 'BN',
    },
    1275: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10430,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG SZE HAN',
        'parti': 'PKR',
    },
    1276: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10430,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JONATHAN LIM YING RAN',
        'parti': 'PAS',
    },
    1277: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10431,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHONG AH WATT',
        'parti': 'BN',
    },
    1278: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10431,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MICHELLE NG MEI SZE',
        'parti': 'PKR',
    },
    1279: {
        'KodN': 8,
        'KodParlimen': 104,
        'KodKawasan': 10431,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TOH SIN WAH',
        'parti': 'BEBAS',
    },
    1280: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 105,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MARIA CHIN BINTI ABDULLAH',
        'parti': 'PKR',
    },
    1281: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 105,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CHEW HIAN TAT',
        'parti': 'BN',
    },
    1282: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 105,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NORAINI BINTI HUSSIN',
        'parti': 'PAS',
    },
    1283: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10532,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GHAZALI BIN DAUD',
        'parti': 'PAS',
    },
    1284: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10532,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR. SHAHARUDDIN BIN BADARUDDIN',
        'parti': 'PKR',
    },
    1285: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10532,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YUSOFF BIN HM. HANIFF',
        'parti': 'BN',
    },
    1286: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10532,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'VIGWESWARAN A/L T.SUBRAMANIAM',
        'parti': 'BEBAS',
    },
    1287: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10533,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SYAMSUL FIRDAUS BIN MOHAMED SUPRI',
        'parti': 'PKR',
    },
    1288: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10533,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ARIFFIN BIN MAHAIYUDDIN',
        'parti': 'PAS',
    },
    1289: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10533,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL MUTALIF BIN ABDUL RAHIM',
        'parti': 'BN',
    },
    1290: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10534,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAJIV A/L RISHYAKARAN',
        'parti': 'PKR',
    },
    1291: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10534,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DAVID SAU KAH HENG',
        'parti': 'PAS',
    },
    1292: {
        'KodN': 8,
        'KodParlimen': 105,
        'KodKawasan': 10534,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHAI KOH TING',
        'parti': 'BN',
    },
    1293: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 106,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HO KWOK XHENG',
        'parti': 'BN',
    },
    1294: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 106,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'PUA KHAM WEE',
        'parti': 'PKR',
    },
    1295: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 106,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' WONG MUN KHEONG",
        'parti': 'PRM',
    },
    1296: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10635,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN GIM TUAN',
        'parti': 'BN',
    },
    1297: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10635,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIM YI WEI',
        'parti': 'PKR',
    },
    1298: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10636,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "CH'NG SOO CHAU",
        'parti': 'BN',
    },
    1299: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10636,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHONG FOOK MENG',
        'parti': 'BEBAS',
    },
    1300: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10636,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAMALIAH BINTI JAMALUDDIN',
        'parti': 'PKR',
    },
    1301: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10637,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SYED ABDUL RAZAK BIN SYED LONG ALSAGOFF',
        'parti': 'BN',
    },
    1302: {
        'KodN': 8,
        'KodParlimen': 106,
        'KodKawasan': 10637,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WONG KEAT PING',
        'parti': 'PKR',
    },
    1303: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 107,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'A. PRAKASH RAO A/L APPLANAIDOO',
        'parti': 'BN',
    },
    1304: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 107,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NURIDAH BINTI MOHD SALLEH',
        'parti': 'PAS',
    },
    1305: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 107,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ZAINURIZZAMAN BIN MOHARAM',
        'parti': 'PSM',
    },
    1306: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 107,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'SIVARASA RASIAH',
        'parti': 'PKR',
    },
    1307: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10738,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZEIN ISMA BIN ISMAIL',
        'parti': 'BN',
    },
    1308: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10738,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KHAIRUDIN BIN OTHMAN',
        'parti': 'PKR',
    },
    1309: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10738,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HANAFI BIN ZULKAPLI',
        'parti': 'PAS',
    },
    1310: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10739,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HALIMATON SAADIAH BT BOHAN',
        'parti': 'BN',
    },
    1311: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10739,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SHATIRI BIN MANSOR',
        'parti': 'PKR',
    },
    1312: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10739,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SITI ROHAYA BINTI AHAD ',
        'parti': 'PAS',
    },
    1313: {
        'KodN': 8,
        'KodParlimen': 107,
        'KodKawasan': 10739,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SIVARAJAN A/L ARUMUGAM',
        'parti': 'PSM',
    },
    1314: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 108,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AZHARI BIN SHAARI',
        'parti': 'BN',
    },
    1315: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 108,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD ZUHDI BIN MARSUKI',
        'parti': 'PAS',
    },
    1316: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 108,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'KHALID BIN ABDUL SAMAD',
        'parti': 'PKR',
    },
    1317: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10840,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD NAJWAN BIN HALIMI',
        'parti': 'PKR',
    },
    1318: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10840,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JUMAEAH BINTI MASDI',
        'parti': 'BN',
    },
    1319: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10840,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD DUSUKI BIN ABD RANI',
        'parti': 'PAS',
    },
    1320: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10841,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL HALIM BIN OMAR',
        'parti': 'PAS',
    },
    1321: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10841,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "AHMAD MUA'ADZAM SHAH BIN YA'AKOP",
        'parti': 'BN',
    },
    1322: {
        'KodN': 8,
        'KodParlimen': 108,
        'KodKawasan': 10841,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RODZIAH BINTI ISMAIL',
        'parti': 'PKR',
    },
    1323: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 109,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': "DATO' MOHANA MUNIANDY ",
        'parti': 'BN',
    },
    1324: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 109,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATO ABDULLAH SANI',
        'parti': 'PKR',
    },
    1325: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 109,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR ABD RANI OSMAN',
        'parti': 'PAS',
    },
    1326: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 109,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MANIKAVASAGAM A/L SUNDRAM',
        'parti': 'PRM',
    },
    1327: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10942,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUL ANUAR BIN SAIMUN',
        'parti': 'BN',
    },
    1328: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10942,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MANIKAVASAGAM',
        'parti': 'PRM',
    },
    1329: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10942,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NURNAJHAN SALLEH',
        'parti': 'PAS',
    },
    1330: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10942,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SHEE CHEE WENG',
        'parti': 'BEBAS',
    },
    1331: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10942,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'MOHD FAKHRUL RAZI',
        'parti': 'PKR',
    },
    1332: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10943,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DAROYAH ALWI',
        'parti': 'PKR',
    },
    1333: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10943,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATOK SARONI BIN JUDI',
        'parti': 'BN',
    },
    1334: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10943,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'GANTHI A/P NAGAMUTHU',
        'parti': 'PRM',
    },
    1335: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10943,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'WAN ASRINA WAN HASSAN',
        'parti': 'PAS',
    },
    1336: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10944,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RASHID ASARI',
        'parti': 'PKR',
    },
    1337: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10944,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ KHAIRI HUSSIN',
        'parti': 'BN',
    },
    1338: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10944,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JEICHANDRAN',
        'parti': 'PRM',
    },
    1339: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10944,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HALIMAH ALI',
        'parti': 'PAS',
    },
    1340: {
        'KodN': 8,
        'KodParlimen': 109,
        'KodKawasan': 10944,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ZAINAL AZWAR',
        'parti': 'BEBAS',
    },
    1341: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 110,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUL SHAH BIN ABDULLAH',
        'parti': 'PAS',
    },
    1342: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 110,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CHING EU BOON',
        'parti': 'BN',
    },
    1343: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 110,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CHARLES ANTHONY A/L R.SANTIAGO',
        'parti': 'PKR',
    },
    1344: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 110,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'PUVANANDERAN A/L GANASAMOORTHY',
        'parti': 'BEBAS',
    },
    1345: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11045,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TEOH KAH YEONG',
        'parti': 'BN',
    },
    1346: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11045,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TENG CHANG KHIM',
        'parti': 'PKR',
    },
    1347: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11046,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SEIKH RAJESH BIN SEIKH AHMAD',
        'parti': 'BN',
    },
    1348: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11046,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMIZAM BIN ZAMAN HURI',
        'parti': 'PKR',
    },
    1349: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11046,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SHANMUGASUNDRAM A/L VEERAPPAN',
        'parti': 'PSM',
    },
    1350: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11046,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'KHALID BIN NAYAN',
        'parti': 'PAS',
    },
    1351: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11047,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SANTOKH SINGH A/L GURDEV SINGH',
        'parti': 'PAS',
    },
    1352: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11047,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEONG TUCK CHEE',
        'parti': 'PKR',
    },
    1353: {
        'KodN': 8,
        'KodParlimen': 110,
        'KodKawasan': 11047,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEE HOOI LING',
        'parti': 'BN',
    },
    1354: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 111,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'V.GUNALAN A/L VELU',
        'parti': 'BN',
    },
    1355: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 111,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMAD BIN SABU',
        'parti': 'PKR',
    },
    1356: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 111,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HJ MOHAMED DIAH BIN BAHARUDIN',
        'parti': 'PAS',
    },
    1357: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11148,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SUBRAMANIAM A/L RETNAM',
        'parti': 'BN',
    },
    1358: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11148,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GUNARAJ R. GEORGE',
        'parti': 'PKR',
    },
    1359: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11148,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAJAN A/L MANIKESAVAN ',
        'parti': 'PAS',
    },
    1360: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11149,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KAMARUZZAMAN BIN JOHARI',
        'parti': 'BN',
    },
    1361: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11149,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ MOHD YUSUF BIN ABDULLAH',
        'parti': 'PAS',
    },
    1362: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11149,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HANAFIAH BIN HUSIN ',
        'parti': 'PRM',
    },
    1363: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11149,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MAT SHUHAIMI BIN SHAFIEI',
        'parti': 'PKR',
    },
    1364: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11150,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TIEW HOCK HUAT',
        'parti': 'BN',
    },
    1365: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11150,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GANABATIRAU A/L VERAMAN',
        'parti': 'PKR',
    },
    1366: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11150,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ BURHAN BIN ADNAN',
        'parti': 'PAS',
    },
    1367: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11150,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ABDUL RAZAK BIN ISMAIL',
        'parti': 'BEBAS',
    },
    1368: {
        'KodN': 8,
        'KodParlimen': 111,
        'KodKawasan': 11150,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'RAJASEKARAN A/L SUNDARAPANDY',
        'parti': 'BEBAS',
    },
    1369: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 112,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'XAVIER JAYAKUMAR A/L ARULANANDAM',
        'parti': 'PKR',
    },
    1370: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 112,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SHAHRIL SUFIAN BIN HAMDAN',
        'parti': 'BN',
    },
    1371: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 112,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK DR YAHYA BIN BABA',
        'parti': 'PAS',
    },
    1372: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11251,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD HAMIDI BIN ABU BAKAR',
        'parti': 'PKR',
    },
    1373: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11251,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO SULAIMAN BIN MOHD KARLI',
        'parti': 'BN',
    },
    1374: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11251,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATO DR AHMAD YUNUS BIN HAIRI',
        'parti': 'PAS',
    },
    1375: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11252,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG SIOK HWA',
        'parti': 'BN',
    },
    1376: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11252,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LAU WENG SAN',
        'parti': 'PKR',
    },
    1377: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11252,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN CHOON SWEE @ PHILIP TAN',
        'parti': 'PRM',
    },
    1378: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11253,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DR MOHD SALEHUDDIN BIN HAFIZ',
        'parti': 'PAS',
    },
    1379: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11253,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROZANA BINTI KAMARULZAMAN',
        'parti': 'BN',
    },
    1380: {
        'KodN': 8,
        'KodParlimen': 112,
        'KodKawasan': 11253,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HASNUL BIN BAHARUDDIN',
        'parti': 'PKR',
    },
    1381: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 113,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HAJI SABIRIN BIN MARSONO',
        'parti': 'PAS',
    },
    1382: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 113,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO HAJI MARSUM BIN PAING',
        'parti': 'BN',
    },
    1383: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 113,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMED HANIPA BIN MAIDIN',
        'parti': 'PKR',
    },
    1384: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11354,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' DR HAJI KARIM BIN MANSOR",
        'parti': 'BN',
    },
    1385: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11354,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'IR MOHD HASLIN BIN HASSAN',
        'parti': 'PAS',
    },
    1386: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11354,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJI BORHAN BIN AMAN SHAH',
        'parti': 'PKR',
    },
    1387: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11355,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "SHAHRUM BIN DATO' HAJI MOHD SHARIF",
        'parti': 'BN',
    },
    1388: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11355,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YUSMI HANIFF BIN ARIFFIN',
        'parti': 'PAS',
    },
    1389: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11355,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ADHIF SYAN BIN ABDULLAH',
        'parti': 'PKR',
    },
    1390: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11356,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' NG CHOK SIN",
        'parti': 'BN',
    },
    1391: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11356,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "ROHAYA BINTI DATO' MOHD SHAHIR",
        'parti': 'PAS',
    },
    1392: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11356,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RONNIE LIU TIAN KHIEW',
        'parti': 'PKR',
    },
    1393: {
        'KodN': 8,
        'KodParlimen': 113,
        'KodKawasan': 11356,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HARRY ARUL RAJ A/L KRISHNAN',
        'parti': 'PAP',
    },
    1394: {
        'KodN': 9,
        'KodParlimen': 114,
        'KodKawasan': 114,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ONG SIANG LIANG',
        'parti': 'BN',
    },
    1395: {
        'KodN': 9,
        'KodParlimen': 114,
        'KodKawasan': 114,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LIM LIP ENG ',
        'parti': 'PKR',
    },
    1396: {
        'KodN': 9,
        'KodParlimen': 115,
        'KodKawasan': 115,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK DR. DOMINIC LAU HOE CHAI',
        'parti': 'BN',
    },
    1397: {
        'KodN': 9,
        'KodParlimen': 115,
        'KodKawasan': 115,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'AZHAR BIN YAHYA',
        'parti': 'PAS',
    },
    1398: {
        'KodN': 9,
        'KodParlimen': 115,
        'KodKawasan': 115,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'VM PANJAMOTHY A/L MUTHUSAMY',
        'parti': 'BEBAS',
    },
    1399: {
        'KodN': 9,
        'KodParlimen': 115,
        'KodKawasan': 115,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'PRABAKARAN A/L PARAMESWARAN',
        'parti': 'BEBAS',
    },
    1400: {
        'KodN': 9,
        'KodParlimen': 116,
        'KodKawasan': 116,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'Yew Teong Look @ Philip Yew',
        'parti': 'BN',
    },
    1401: {
        'KodN': 9,
        'KodParlimen': 116,
        'KodKawasan': 116,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'Tan Yew Kew',
        'parti': 'PKR',
    },
    1402: {
        'KodN': 9,
        'KodParlimen': 116,
        'KodKawasan': 116,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'Razali bin Tumirin',
        'parti': 'PAS',
    },
    1403: {
        'KodN': 9,
        'KodParlimen': 117,
        'KodKawasan': 117,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATO DR LOGA BALA A/L JAGANATHAN',
        'parti': 'BN',
    },
    1404: {
        'KodN': 9,
        'KodParlimen': 117,
        'KodKawasan': 117,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'USTAZ MOHAMAD SOLLEH BIN ABD RAZAK',
        'parti': 'PAS',
    },
    1405: {
        'KodN': 9,
        'KodParlimen': 117,
        'KodKawasan': 117,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HANNAH YEOH',
        'parti': 'PKR',
    },
    1406: {
        'KodN': 9,
        'KodParlimen': 118,
        'KodKawasan': 118,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ZULHASNAN BIN RAFIQUE',
        'parti': 'BN',
    },
    1407: {
        'KodN': 9,
        'KodParlimen': 118,
        'KodKawasan': 118,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NIK NAZMI BIN NIK AHMAD',
        'parti': 'PKR',
    },
    1408: {
        'KodN': 9,
        'KodParlimen': 118,
        'KodKawasan': 118,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'UBAID BIN ABD AKLA',
        'parti': 'PAS',
    },
    1409: {
        'KodN': 9,
        'KodParlimen': 119,
        'KodKawasan': 119,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'JOHARI BIN ABDUL GHANI',
        'parti': 'BN',
    },
    1410: {
        'KodN': 9,
        'KodParlimen': 120,
        'KodKawasan': 120,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ANN TAN EAN EAN',
        'parti': 'BN',
    },
    1411: {
        'KodN': 9,
        'KodParlimen': 120,
        'KodKawasan': 120,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'FONG KUI LUN',
        'parti': 'PKR',
    },
    1412: {
        'KodN': 9,
        'KodParlimen': 120,
        'KodKawasan': 120,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'KHAIRUL HUSNI OTHMAN',
        'parti': 'PFP',
    },
    1413: {
        'KodN': 9,
        'KodParlimen': 121,
        'KodKawasan': 121,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RAJA NONG CHIK BIN RAJA ZAINAL ABIDIN',
        'parti': 'BN',
    },
    1414: {
        'KodN': 9,
        'KodParlimen': 121,
        'KodKawasan': 121,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'FAUZI BIN ABU BAKAR',
        'parti': 'PAS',
    },
    1415: {
        'KodN': 9,
        'KodParlimen': 121,
        'KodKawasan': 121,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD FAHMI BIN MOHAMED FADZIL',
        'parti': 'PKR',
    },
    1416: {
        'KodN': 9,
        'KodParlimen': 122,
        'KodKawasan': 122,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TERESA KOK SUH SIM',
        'parti': 'PKR',
    },
    1417: {
        'KodN': 9,
        'KodParlimen': 122,
        'KodKawasan': 122,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHAN QUIN ER',
        'parti': 'BN',
    },
    1418: {
        'KodN': 9,
        'KodParlimen': 123,
        'KodKawasan': 123,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HENG SINN YEE',
        'parti': 'BN',
    },
    1419: {
        'KodN': 9,
        'KodParlimen': 123,
        'KodKawasan': 123,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TAN KOK WAI',
        'parti': 'PKR',
    },
    1420: {
        'KodN': 9,
        'KodParlimen': 124,
        'KodKawasan': 124,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KAMARUDIN BIN JAFFAR',
        'parti': 'PKR',
    },
    1421: {
        'KodN': 9,
        'KodParlimen': 124,
        'KodKawasan': 124,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ROSNI BINTI ADAM',
        'parti': 'PAS',
    },
    1422: {
        'KodN': 9,
        'KodParlimen': 124,
        'KodKawasan': 124,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ADNAN BIN SEMAN @ ABDULLAH',
        'parti': 'BN',
    },
    1423: {
        'KodN': 9,
        'KodParlimen': 125,
        'KodKawasan': 125,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI UTAMA TENGKU ADNAN BIN TENGKU MANSOR',
        'parti': 'BN',
    },
    1424: {
        'KodN': 9,
        'KodParlimen': 125,
        'KodKawasan': 125,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "PROF DATO' DR. HAJI ZAINAL ABIDIN BIN KIDAM",
        'parti': 'PAS',
    },
    1425: {
        'KodN': 9,
        'KodParlimen': 125,
        'KodKawasan': 125,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "PROF DATO' DR. HAJI SAMSU ADABI BIN MAMAT",
        'parti': 'PKR',
    },
    1426: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 126,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUSTAFAR BIN AB KADIR',
        'parti': 'PKR',
    },
    1427: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 126,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JALALUDDIN BIN ALIAS',
        'parti': 'BN',
    },
    1428: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 126,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NORMAN BIN IPIN ',
        'parti': 'PAS',
    },
    1429: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12601,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SEET TEE GEE',
        'parti': 'BN',
    },
    1430: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12601,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LOKE SIEW FOOK',
        'parti': 'PKR',
    },
    1431: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12601,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JAMALUS BIN MANSOR',
        'parti': 'PAS',
    },
    1432: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12602,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NOOR AZMI BIN YUSOF',
        'parti': 'BN',
    },
    1433: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12602,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAMRAN BIN ABU HASSAN',
        'parti': 'PAS',
    },
    1434: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12602,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'OSMAN BIN DUSA',
        'parti': 'PKR',
    },
    1435: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12603,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL KARIM SHAHIMI BIN ABDUL RAZAK',
        'parti': 'PAS',
    },
    1436: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12603,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD RAZI BIN MODH ALI',
        'parti': 'BN',
    },
    1437: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12603,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAINAL FIKRI BIN ABD KADIR',
        'parti': 'PKR',
    },
    1438: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12604,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BAKRI BIN SAWIR',
        'parti': 'PKR',
    },
    1439: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12604,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MAZLY BIN YASIN',
        'parti': 'PAS',
    },
    1440: {
        'KodN': 11,
        'KodParlimen': 126,
        'KodKawasan': 12604,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BAHARUDIN BIN JALI',
        'parti': 'BN',
    },
    1441: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 127,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KAMARULZAMAN BIN KAMDIAS',
        'parti': 'PKR',
    },
    1442: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 127,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MUSTAFFA BIN DAHARUN',
        'parti': 'PAS',
    },
    1443: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 127,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': "DATO' HJ. MOHD SALIM BIN SHARIF",
        'parti': 'BN',
    },
    1444: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12705,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABD RAHMAN BIN RAMLI',
        'parti': 'PKR',
    },
    1445: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12705,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' HJ. SHAMSHULKAHAR BIN HJ. MOHD DELI",
        'parti': 'BN',
    },
    1446: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12705,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD AL-ZUKRI BIN MUHAMAT YASSIN',
        'parti': 'PAS',
    },
    1447: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12706,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MASDI BIN MUSA',
        'parti': 'PAS',
    },
    1448: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12706,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUSTAPHA BIN NAGOOR',
        'parti': 'BN',
    },
    1449: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12706,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': "DATO' ABDUL RAHMAN BIN JAAFAR",
        'parti': 'PKR',
    },
    1450: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12707,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' MANICKAM A/L LETCHUMAN",
        'parti': 'BN',
    },
    1451: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12707,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD FAIRUZ BIN ISA',
        'parti': 'PAS',
    },
    1452: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12707,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'S. MULIA DI BIN SABTU',
        'parti': 'PKR',
    },
    1453: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12707,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': "DATO' DR. SURESH A/L SREENIVASAN",
        'parti': 'BEBAS',
    },
    1454: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12708,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUSTAFAR BAKRI BIN ABDUL AZIZ',
        'parti': 'PAS',
    },
    1455: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12708,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TEO KOK SIONG',
        'parti': 'PKR',
    },
    1456: {
        'KodN': 11,
        'KodParlimen': 127,
        'KodKawasan': 12708,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHONG WAN YU',
        'parti': 'BN',
    },
    1457: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 128,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'LOKE SIEW FOOK',
        'parti': 'PKR',
    },
    1458: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 128,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHONG SIN WOON',
        'parti': 'BN',
    },
    1459: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 128,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SHARIFFUDDIN BIN AHMAD',
        'parti': 'PAS',
    },
    1460: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12809,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMMAD GHAZALI BIN ABU BAKAR',
        'parti': 'PAS',
    },
    1461: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12809,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': ' SUHAIMI BIN KASSIM',
        'parti': 'PKR',
    },
    1462: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12809,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MAZALAN BIN MAAROP ',
        'parti': 'BN',
    },
    1463: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12810,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ARUL KUMAR A/L JAMBUNATHAN ',
        'parti': 'PKR',
    },
    1464: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12810,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ABU ZARIM  BIN ABDUL RAHMAN ',
        'parti': 'PAS',
    },
    1465: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12810,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEAW KOK CHAN',
        'parti': 'BN',
    },
    1466: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12811,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BALAMURUGAN AL SANMUGAM',
        'parti': 'PAP',
    },
    1467: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12811,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LIM KOK KIAN',
        'parti': 'BN',
    },
    1468: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12811,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHEW SEH YONG',
        'parti': 'PKR',
    },
    1469: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12812,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'YAU CON SENG ',
        'parti': 'PAS',
    },
    1470: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12812,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NG CHIN TSAI ',
        'parti': 'PKR',
    },
    1471: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12812,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SIOW KOI VOON ',
        'parti': 'BN',
    },
    1472: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12813,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAHIM BIN YUSOF ',
        'parti': 'PAS',
    },
    1473: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12813,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMINUDDIN BIN HARUN ',
        'parti': 'PKR',
    },
    1474: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12813,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SYAMSUL AMRI BIN ISMAIL',
        'parti': 'BN',
    },
    1475: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12813,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'BUJANG BIN ABU',
        'parti': 'BEBAS',
    },
    1476: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12814,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD RAFIE BIN AB MALEK',
        'parti': 'PKR',
    },
    1477: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12814,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUSTAFFA BIN DAHARUN',
        'parti': 'PAS',
    },
    1478: {
        'KodN': 11,
        'KodParlimen': 128,
        'KodKawasan': 12814,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABU UBAIDAH BIN HJ REDZA',
        'parti': 'BN',
    },
    1479: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 129,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'RAFIEI BIN MUSTPHA',
        'parti': 'PAS',
    },
    1480: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 129,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'EDDIN SYAZLEE BIN SHITH',
        'parti': 'PKR',
    },
    1481: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 129,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HASAN BIN MALEK',
        'parti': 'BN',
    },
    1482: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12915,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATO HJ ISMAIL B LASIM',
        'parti': 'BN',
    },
    1483: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12915,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROSLI BIN OMAR',
        'parti': 'PKR',
    },
    1484: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12915,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HASSAN BIN MOHAMED',
        'parti': 'PAS',
    },
    1485: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12916,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO ABDUL SAMAD BIN IBRAHIM',
        'parti': 'BN',
    },
    1486: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12916,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAFIEI BIN MUSTPHA',
        'parti': 'PAS',
    },
    1487: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12916,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JAMALI BIN SALAM',
        'parti': 'PKR',
    },
    1488: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12917,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO HJ ADNAN BIN ABU HASSAN',
        'parti': 'BN',
    },
    1489: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12917,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'FAZILAH BINTI ABU SAMAH',
        'parti': 'PAS',
    },
    1490: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12917,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD RAIS BIN MOHAMAD@BASIRON',
        'parti': 'PKR',
    },
    1491: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12918,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO NORHAYATI BINTI OMAR',
        'parti': 'BN',
    },
    1492: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12918,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD NAZARUDIN BIN SABTU',
        'parti': 'PKR',
    },
    1493: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12918,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AHMAD FADZIL BIN OTHMAN',
        'parti': 'PAS',
    },
    1494: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12919,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAIFUL YAZAN B SULAIMAN',
        'parti': 'BN',
    },
    1495: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12919,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZULKEFLY MOHAMAD BIN OMAR',
        'parti': 'PKR',
    },
    1496: {
        'KodN': 11,
        'KodParlimen': 129,
        'KodKawasan': 12919,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KAMARUDIN BIN MD.TAHIR',
        'parti': 'PAS',
    },
    1497: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 130,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NG KIAN NAM',
        'parti': 'BN',
    },
    1498: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 130,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHAIRIL ANUAR BIN MOHD WAFA',
        'parti': 'PAS',
    },
    1499: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 130,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DAVID DASS A/L ASEERPATHAM',
        'parti': 'PAP',
    },
    1500: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 130,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'CHA KEE CHIN',
        'parti': 'PKR',
    },
    1501: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13020,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ISMAIL BIN AHMAD',
        'parti': 'PKR',
    },
    1502: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13020,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD KHAIRIL ANUAR BIN MOHD WAFA',
        'parti': 'PAS',
    },
    1503: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13020,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HASIM BIN RUSDI',
        'parti': 'BN',
    },
    1504: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13020,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DAVID DASS A/L ASEERPATHAM',
        'parti': 'PAP',
    },
    1505: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13021,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MAK KAH KEONG',
        'parti': 'BN',
    },
    1506: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13021,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN LEE KOON',
        'parti': 'PKR',
    },
    1507: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13022,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YAP SIOK MOY',
        'parti': 'BN',
    },
    1508: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13022,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SARASWATHY A/P PARAGAZUM',
        'parti': 'PAP',
    },
    1509: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13022,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MARY JOSEPHINE PRITTAM SINGH',
        'parti': 'PKR',
    },
    1510: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13023,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PARIMALA DEVI A/P THEYAGASON',
        'parti': 'PAP',
    },
    1511: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13023,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HO CHOY SHIN',
        'parti': 'BN',
    },
    1512: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13023,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YAP YEW WENG',
        'parti': 'PKR',
    },
    1513: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13024,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHOONG VEE HING',
        'parti': 'BN',
    },
    1514: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13024,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GUNASEKAREN A/L PALASAMY',
        'parti': 'PKR',
    },
    1515: {
        'KodN': 11,
        'KodParlimen': 130,
        'KodKawasan': 13024,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAGAYA RAJAN A/L XAVIER',
        'parti': 'PAP',
    },
    1516: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 131,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KHAIRY JAMALUDDIN ABU BAKAR ',
        'parti': 'BN',
    },
    1517: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 131,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUSTAFA BIN DOLAH ',
        'parti': 'PAS',
    },
    1518: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 131,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'KOLONEL (B) ROSELI BIN ABDUL GANI',
        'parti': 'PKR',
    },
    1519: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13125,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MASITA BINTI MOHAMED ALI',
        'parti': 'PAS',
    },
    1520: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13125,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD GHAZALI BIN ABD WAHID',
        'parti': 'BN',
    },
    1521: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13125,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD TAUFEK BIN ABDUL GHANI ',
        'parti': 'PKR',
    },
    1522: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13126,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROSMIN BIN ADAM ',
        'parti': 'PAS',
    },
    1523: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13126,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAIFULBAHRI BIN IDRIS ',
        'parti': 'BN',
    },
    1524: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13126,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZIZAN BIN MARZUKI ',
        'parti': 'PKR',
    },
    1525: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13127,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHAMAD BIN HAJI HASAN ',
        'parti': 'BN',
    },
    1526: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13128,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ISHAK BIN OMAR ',
        'parti': 'PAS',
    },
    1527: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13128,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AWALUDIN BIN SAID ',
        'parti': 'BN',
    },
    1528: {
        'KodN': 11,
        'KodParlimen': 131,
        'KodKawasan': 13128,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAHRIZAL BIN MASRUDIN ',
        'parti': 'PKR',
    },
    1529: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 132,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MAHFUZ BIN ROSLAN',
        'parti': 'PAS',
    },
    1530: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 132,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DANYAL BALAGOPAL ABDULLAH',
        'parti': 'PKR',
    },
    1531: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 132,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOGAN A/L VELAVATHAM',
        'parti': 'BN',
    },
    1532: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13229,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LIM CHIN FUI',
        'parti': 'BN',
    },
    1533: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13229,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YEK DIEW CHING',
        'parti': 'PKR',
    },
    1534: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13230,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YEONG KUN YOU',
        'parti': 'BN',
    },
    1535: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13230,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHOO KEN HWA',
        'parti': 'PKR',
    },
    1536: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13231,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TUN HAIRUDIN BIN ABU BAKAR',
        'parti': 'BN',
    },
    1537: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13231,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD IBRAHIM KHAN BIN AMANULLA KHAN',
        'parti': 'PKR',
    },
    1538: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13232,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL RAHMAN BIN MOHD REDZA',
        'parti': 'BN',
    },
    1539: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13232,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NOOR MOHAMMAD RIZAL BIN ISHAK',
        'parti': 'PAS',
    },
    1540: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13232,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RUSLI BIN ABDULLAH',
        'parti': 'PKR',
    },
    1541: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13233,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'THINALAN A/L T. RAJAGOPALU',
        'parti': 'BN',
    },
    1542: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13233,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAVI A/L MUNUSAMY',
        'parti': 'PKR',
    },
    1543: {
        'KodN': 11,
        'KodParlimen': 132,
        'KodKawasan': 13233,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KAMAROL RIDZUAN BIN MOHD ZAIN',
        'parti': 'PAS',
    },
    1544: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 133,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ABD HALIM B ABU BAKAR',
        'parti': 'PAS',
    },
    1545: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 133,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SHAZIMAN BIN ABU MANSOR',
        'parti': 'BN',
    },
    1546: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 133,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HASAN BIN BAHAROM',
        'parti': 'PKR',
    },
    1547: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13334,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABD HALIM BIN ABU BAKAR',
        'parti': 'PAS',
    },
    1548: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13334,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'BAHARUDDIN ARIF BIN SIRI',
        'parti': 'PKR',
    },
    1549: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13334,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABD RAZAK BIN AB SAID',
        'parti': 'BN',
    },
    1550: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13335,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ISHAK BIN MAASIN',
        'parti': 'PAS',
    },
    1551: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13335,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ISAM BIN MOHD ISA',
        'parti': 'BN',
    },
    1552: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13335,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAIFUL ADLY BIN ABD WAHAB',
        'parti': 'PKR',
    },
    1553: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13336,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABD RAZAKEK BIN ABD RAHIM',
        'parti': 'PAS',
    },
    1554: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13336,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'VEERAPAN A/L SUPERAMANIAM',
        'parti': 'PKR',
    },
    1555: {
        'KodN': 11,
        'KodParlimen': 133,
        'KodKawasan': 13336,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KOH KIM SWEE',
        'parti': 'BN',
    },
    1556: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 134,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD NASIR BIN OTHMAN',
        'parti': 'PAS',
    },
    1557: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 134,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'SABIRIN BIN JAAFAR',
        'parti': 'PKR',
    },
    1558: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 134,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MAS ERMIEYATI BINTI SAMSUDIN',
        'parti': 'BN',
    },
    1559: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13401,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ISMAIL BIN OTHMAN',
        'parti': 'BN',
    },
    1560: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13401,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HASMORNI BINTI TAMBY',
        'parti': 'PKR',
    },
    1561: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13401,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZMI BIN SAMBUL',
        'parti': 'PAS',
    },
    1562: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13402,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD RAWI BIN MAHMUD',
        'parti': 'BN',
    },
    1563: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13402,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HALIM BIN BACHIK',
        'parti': 'PKR',
    },
    1564: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13402,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'IMRAN BIN ABDUL RAHMAN',
        'parti': 'PAS',
    },
    1565: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13403,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AMIRUDIN BIN YUSOF',
        'parti': 'BN',
    },
    1566: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13403,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAMARUDIN BIN AHMAD',
        'parti': 'PAS',
    },
    1567: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13403,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RUSLIN BIN HASAN',
        'parti': 'PKR',
    },
    1568: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13404,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RIDHUAN AFFANDI BIN ABU BAKAR',
        'parti': 'PKR',
    },
    1569: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13404,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ARSHAD BIN MOHAMAD SOM',
        'parti': 'PAS',
    },
    1570: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13404,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SULAIMAN BIN MD ALI',
        'parti': 'BN',
    },
    1571: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13405,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ASRI BIN SHAIK ABDUL AZIZ',
        'parti': 'PAS',
    },
    1572: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13405,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAIRI BIN SUBOH',
        'parti': 'PKR',
    },
    1573: {
        'KodN': 12,
        'KodParlimen': 134,
        'KodKawasan': 13405,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LATIPAH BINTI OMAR',
        'parti': 'BN',
    },
    1574: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 135,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK WONG NAI CHEE',
        'parti': 'BN',
    },
    1575: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 135,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MOHD NAZREE BIN MOHD ARIS',
        'parti': 'PAS',
    },
    1576: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 135,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD REDZUAN BIN MD. YUSOF',
        'parti': 'PKR',
    },
    1577: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13506,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK WIRA HAJAH NORPIPAH BTE ABDOL',
        'parti': 'BN',
    },
    1578: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13506,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUHAMMAD JAILANI BIN KHAMIS',
        'parti': 'PKR',
    },
    1579: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13506,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD RASHIDI BIN ABD RAZAK',
        'parti': 'PAS',
    },
    1580: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13507,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK PANIRCHELVAM A/L PICHAMUTHU',
        'parti': 'BN',
    },
    1581: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13507,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAMINATHAN A/L GANESAN',
        'parti': 'PKR',
    },
    1582: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13507,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EMRANSYAH BIN ISMAIL',
        'parti': 'PAS',
    },
    1583: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13508,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': ' DATUK WIRA KOH NAI KWONG',
        'parti': 'BN',
    },
    1584: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13508,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GINNIE LIM SIEW LIN',
        'parti': 'PKR',
    },
    1585: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13508,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'WAN ZAHIDI BIN WAN ISMAIL',
        'parti': 'PAS',
    },
    1586: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13509,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK WIRA HJ AB WAHAB BIN HJ AB LATIP',
        'parti': 'BN',
    },
    1587: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13509,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD SOFI BIN ABD WAHAB',
        'parti': 'PKR',
    },
    1588: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13509,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHSIN BIN IBRAHIM',
        'parti': 'PAS',
    },
    1589: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13510,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI HJ ABDUL GHAFFAR BIN ATAN',
        'parti': 'BN',
    },
    1590: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13510,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZAMZURI BIN ARIFIN',
        'parti': 'PKR',
    },
    1591: {
        'KodN': 12,
        'KodParlimen': 135,
        'KodKawasan': 13510,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AZLAN BIN MADDIN',
        'parti': 'PAS',
    },
    1592: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 136,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ZALI BIN MAT YASIN',
        'parti': 'BN',
    },
    1593: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 136,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'RUSNAH BINTI ALUAI',
        'parti': 'PKR',
    },
    1594: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 136,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ZULKIFLI BIN ISMAIL',
        'parti': 'PAS',
    },
    1595: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13611,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'IDRIS BIN HARON',
        'parti': 'BN',
    },
    1596: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13611,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD LOKMAN BIN ABDUL GANI',
        'parti': 'PKR',
    },
    1597: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13612,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NORAZMAN BIN HASSAN',
        'parti': 'BN',
    },
    1598: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13612,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL HALIM BIN MAIDIN',
        'parti': 'PAS',
    },
    1599: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13612,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JUHARI BIN OSMAN',
        'parti': 'PKR',
    },
    1600: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13613,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABU BAKAR BIN MOHD DIAH',
        'parti': 'BN',
    },
    1601: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13613,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAFIE BIN AHMAD',
        'parti': 'PAS',
    },
    1602: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13613,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD RAFIQ BIN NAIZAMOHIDEEN',
        'parti': 'PKR',
    },
    1603: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13614,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GUE TECK',
        'parti': 'PKR',
    },
    1604: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13614,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SHAFIQ BIN ISMAIL',
        'parti': 'PAS',
    },
    1605: {
        'KodN': 12,
        'KodParlimen': 136,
        'KodKawasan': 13614,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LIM BAN HONG',
        'parti': 'BN',
    },
    1606: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 137,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TAN SRI HJ MOHD ALI BIN MOHD RUSTAM',
        'parti': 'BN',
    },
    1607: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 137,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR MD. KHALID BIN KASSIM',
        'parti': 'PAS',
    },
    1608: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 137,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'SHAMSUL ISKANDAR BIN MD AKIN',
        'parti': 'PKR',
    },
    1609: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13715,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK CHUA LIAN CHYE',
        'parti': 'BN',
    },
    1610: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13715,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAMLI BIN DALIP',
        'parti': 'PAS',
    },
    1611: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13715,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HORHIZAM BIN HASSAN BAKTEE',
        'parti': 'PKR',
    },
    1612: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13716,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK CHUA KHENG HWA',
        'parti': 'BN',
    },
    1613: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13716,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ SEPRI BIN RAHMAN',
        'parti': 'PAS',
    },
    1614: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13716,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KERK CHEE YEE',
        'parti': 'PKR',
    },
    1615: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13717,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK HJ YUNUS BIN HITAM',
        'parti': 'BN',
    },
    1616: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13717,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ADLY BIN ZAHARI',
        'parti': 'PKR',
    },
    1617: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13717,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMAT PUHAT BIN BEDOL',
        'parti': 'PAS',
    },
    1618: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13718,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAHMAD BIN MARIMAN',
        'parti': 'BN',
    },
    1619: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13718,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FARHAN BIN IBRAHIM @ ALIAS',
        'parti': 'PKR',
    },
    1620: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13718,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JANTAN BIN ABDULLAH',
        'parti': 'PAS',
    },
    1621: {
        'KodN': 12,
        'KodParlimen': 137,
        'KodKawasan': 13718,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'PROF. MADYA DR KAMAROLZAMAN BIN HJ MOHD JIDI',
        'parti': 'BEBAS',
    },
    1622: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 138,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHOO WEI SERN',
        'parti': 'BN',
    },
    1623: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 138,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KHOO POAY TIONG',
        'parti': 'PKR',
    },
    1624: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 138,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'GOH LEONG SAN',
        'parti': 'BEBAS',
    },
    1625: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13819,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NG CHOON KOON',
        'parti': 'BN',
    },
    1626: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13819,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SEAH SHOO CHIN',
        'parti': 'PKR',
    },
    1627: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13819,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GOH LEONG SAN',
        'parti': 'BEBAS',
    },
    1628: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13820,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MELVIN CHUA KEW WEI',
        'parti': 'BN',
    },
    1629: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13820,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LOW CHEE LEONG',
        'parti': 'PKR',
    },
    1630: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13820,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SIM TONG HIM',
        'parti': 'BEBAS',
    },
    1631: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13821,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KAMARUDIN BIN SEDIK',
        'parti': 'PAS',
    },
    1632: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13821,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE KIAT LEE',
        'parti': 'BN',
    },
    1633: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13821,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DAMIEN YEO SHEN LI',
        'parti': 'PKR',
    },
    1634: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13821,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIM JAK WONG',
        'parti': 'BEBAS',
    },
    1635: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13822,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LEE CHONG LENG',
        'parti': 'BN',
    },
    1636: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13822,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEY KOK KIEW',
        'parti': 'PKR',
    },
    1637: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13822,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHIN CHOONG SENG',
        'parti': 'BEBAS',
    },
    1638: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13823,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL RAZAK BIN ABDUL RAHMAN',
        'parti': 'BN',
    },
    1639: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13823,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NOOR EFFANDI BIN AHMAD',
        'parti': 'PKR',
    },
    1640: {
        'KodN': 12,
        'KodParlimen': 138,
        'KodKawasan': 13823,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROSAZALI BIN MD YASSIN',
        'parti': 'PAS',
    },
    1641: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 139,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK PADUKA KHAIRUDDIN BIN ABU HASAN',
        'parti': 'PKR',
    },
    1642: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 139,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HAJI ABDUL ALIM BIN SHAPIE',
        'parti': 'PAS',
    },
    1643: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 139,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK SERI WIRA HJ AHMAD BIN HAMZAH',
        'parti': 'BN',
    },
    1644: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13924,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK KOH CHIN HAN',
        'parti': 'BN',
    },
    1645: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13924,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ SUHAIMI BIN HARUN',
        'parti': 'PAS',
    },
    1646: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13924,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR WONG FORT-PIN',
        'parti': 'PKR',
    },
    1647: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13925,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAJAH KINTAN BTE MAN',
        'parti': 'PAS',
    },
    1648: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13925,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK WIRA HJ GHAZALE BIN MUHAMAD',
        'parti': 'BN',
    },
    1649: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13925,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SHAMSUL ISKANDAR @ YUSRIE MOHD AKIN',
        'parti': 'PKR',
    },
    1650: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13926,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD BILAL BIN RAHUDIN',
        'parti': 'PAS',
    },
    1651: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13926,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK ZAIDI BIN ATTAN',
        'parti': 'BN',
    },
    1652: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13926,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NOR KHAIRI BIN YUSOF',
        'parti': 'PKR',
    },
    1653: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13927,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ROSLAN BIN AHMAD',
        'parti': 'BN',
    },
    1654: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13927,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HAJI YUHAIZAD BIN ABDULLAH',
        'parti': 'PKR',
    },
    1655: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13927,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAJI ABDUL MALEK BIN YUSOF',
        'parti': 'PAS',
    },
    1656: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13928,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZALINA BIN ABDUL RAHMAN',
        'parti': 'PKR',
    },
    1657: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13928,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK HASAN BIN ABD RAHMAN',
        'parti': 'BN',
    },
    1658: {
        'KodN': 12,
        'KodParlimen': 139,
        'KodKawasan': 13928,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAJI ZAKARIYA BIN KASNIN',
        'parti': 'PAS',
    },
    1659: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 140,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI S SUBRAMANIAM',
        'parti': 'BN',
    },
    1660: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 140,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'R SANHTARA KUMAR',
        'parti': 'PKR',
    },
    1661: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 140,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KHAIRUL FAIZI AHMAD KAMIL',
        'parti': 'PAS',
    },
    1662: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 14001,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ZAHARI BIN SARIP',
        'parti': 'BN',
    },
    1663: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 14001,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORSAMSU BIN MOHD YUSOF',
        'parti': 'PKR',
    },
    1664: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 14002,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHIAM YOK MENG',
        'parti': 'BN',
    },
    1665: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 14002,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN CHENG CHOON',
        'parti': 'PKR',
    },
    1666: {
        'KodN': 13,
        'KodParlimen': 140,
        'KodKawasan': 14002,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'KHAIRUL FAIZI AHMAD KAMIL',
        'parti': 'PAS',
    },
    1667: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 141,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK HJ. AYUB BIN RAHMAT',
        'parti': 'BN',
    },
    1668: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 141,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HJH NATRAH BINTI ISMAIL',
        'parti': 'PKR',
    },
    1669: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 14103,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHOO SHIAW LEE',
        'parti': 'BN',
    },
    1670: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 14103,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORMALA BT SUDIRMAN',
        'parti': 'PAS',
    },
    1671: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 14103,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. CHONG FAT FULL',
        'parti': 'PKR',
    },
    1672: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 14104,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ANUAR BIN ABD MANAP',
        'parti': 'BN',
    },
    1673: {
        'KodN': 13,
        'KodParlimen': 141,
        'KodKawasan': 14104,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DR. SULAIMAN BIN MOHD NOR',
        'parti': 'PKR',
    },
    1674: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 142,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK SARCHU BIN SAWAL',
        'parti': 'PAS',
    },
    1675: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 142,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'PANG HOCK LIONG',
        'parti': 'PKR',
    },
    1676: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 142,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK CHUA TEE YONG',
        'parti': 'BN',
    },
    1677: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 14205,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NASHARUDIN BIN AWANG',
        'parti': 'PAS',
    },
    1678: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 14205,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD SOLIHAN BIN BADRI',
        'parti': 'PKR',
    },
    1679: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 14205,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD AZAHAR BINIBRAHIM',
        'parti': 'BN',
    },
    1680: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 14206,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN CHONG',
        'parti': 'BN',
    },
    1681: {
        'KodN': 13,
        'KodParlimen': 142,
        'KodKawasan': 14206,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAMAKRISHNAN A/L SUPPIAH',
        'parti': 'PKR',
    },
    1682: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 143,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HAJI ISMAIL BIN MOHAMED',
        'parti': 'BN',
    },
    1683: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 143,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'TAN SRI MAHIADDIN BIN MD YASIN',
        'parti': 'PKR',
    },
    1684: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 143,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD NAWFAL BIN MAHFODZ',
        'parti': 'PAS',
    },
    1685: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 14307,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAHRUDDIN BIN JAMAL',
        'parti': 'PKR',
    },
    1686: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 14307,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD NOOR BIN TAIB',
        'parti': 'BN',
    },
    1687: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 14307,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMAD NUR IQBAL BIN ABD RAZAK',
        'parti': 'PAS',
    },
    1688: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 14308,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NAJIB BIN LEP',
        'parti': 'PAS',
    },
    1689: {
        'KodN': 13,
        'KodParlimen': 143,
        'KodKawasan': 14308,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK NORIAH BTE MAHAT',
        'parti': 'BN',
    },
    1690: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 144,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK IR. DR. HJ HAMIM BIN SAMURI',
        'parti': 'BN',
    },
    1691: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 144,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SYED IBRAHIM BIN SYED NUH',
        'parti': 'PKR',
    },
    1692: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 144,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'RUSMAN BIN KEMIN',
        'parti': 'PAS',
    },
    1693: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14409,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK M ASOJAN A/L MUNIYANDY',
        'parti': 'BN',
    },
    1694: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14409,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TAN SRI DATO’ HJ. MUHYIDDIN BIN HJ MOHD YASSIN',
        'parti': 'PKR',
    },
    1695: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14409,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK DR. MAHFODZ BIN MOHAMED',
        'parti': 'PAS',
    },
    1696: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14410,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK GOH TEE TEE',
        'parti': 'BN',
    },
    1697: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14410,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'EE CHIN LI',
        'parti': 'PKR',
    },
    1698: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14411,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK HJ ABDULL RAHIM BIN HJ TALIB',
        'parti': 'BN',
    },
    1699: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14411,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. FAIZUL AMRI BIN ADNAN',
        'parti': 'PKR',
    },
    1700: {
        'KodN': 13,
        'KodParlimen': 144,
        'KodKawasan': 14411,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ MUSTAFFA BIN SALLEH',
        'parti': 'PAS',
    },
    1701: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 145,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KOH CHON CHAI ',
        'parti': 'BN',
    },
    1702: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 145,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'YEO BEE YIN ',
        'parti': 'PKR',
    },
    1703: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 145,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ZARUL @ MOHD ZAHRUL BIN SALLEH ',
        'parti': 'PAS',
    },
    1704: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14512,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LEE KIM HENG ',
        'parti': 'BN',
    },
    1705: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14512,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NG YAK HOWE ',
        'parti': 'PKR',
    },
    1706: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14513,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD RADZI BIN AMIN ',
        'parti': 'BN',
    },
    1707: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14513,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD BIN HASHIM ',
        'parti': 'BEBAS',
    },
    1708: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14513,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SALAHUDDIN BIN AYUB ',
        'parti': 'PKR',
    },
    1709: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14513,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD MAZRI BIN YAHYA ',
        'parti': 'PAS',
    },
    1710: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14514,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HASSAN BIN JOHARI ',
        'parti': 'BN',
    },
    1711: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14514,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'S.JEGANATHAN A/L SUBTAMANIAM ',
        'parti': 'BEBAS',
    },
    1712: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14514,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMAN BIN IBRAHIM ',
        'parti': 'PAS',
    },
    1713: {
        'KodN': 13,
        'KodParlimen': 145,
        'KodKawasan': 14514,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MD YSAHRUDIN BIN KUSNI ',
        'parti': 'PKR',
    },
    1714: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 146,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI RAZALI BIN IBRAHIM',
        'parti': 'BN',
    },
    1715: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 146,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SYED SADDIQ BIN SYED ABDUL RAHMAN',
        'parti': 'PKR',
    },
    1716: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 146,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ABDUL AZIZ BIN TALIB ',
        'parti': 'PAS',
    },
    1717: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14615,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' ASHARI BIN MD SARIP",
        'parti': 'BN',
    },
    1718: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14615,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORHAYATI BINTI BACHOK ',
        'parti': 'PKR',
    },
    1719: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14615,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DR. MOHAMAD BIN TASLIM ',
        'parti': 'PAS',
    },
    1720: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14616,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAITON BINTI ISMAIL',
        'parti': 'BN',
    },
    1721: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14616,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NAIM BIN JUSRI',
        'parti': 'PKR',
    },
    1722: {
        'KodN': 13,
        'KodParlimen': 146,
        'KodKawasan': 14616,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ CHEMAN BIN YUSOH',
        'parti': 'PAS',
    },
    1723: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 147,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NORAINI BINTI AHMAD',
        'parti': 'BN',
    },
    1724: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 147,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ANIS AFIDA BINTI MOHD AZLI',
        'parti': 'PKR',
    },
    1725: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 147,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD ROSDI BIN BAHARI',
        'parti': 'PAS',
    },
    1726: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14717,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ADNAN BIN OTHMAN',
        'parti': 'PAS',
    },
    1727: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14717,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ISMAIL BIN ROSLAN',
        'parti': 'BN',
    },
    1728: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14717,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD KHUZZAN BIN ABU BAKAR',
        'parti': 'PKR',
    },
    1729: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14718,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZULKURNAIN BIN KAMISAN',
        'parti': 'BN',
    },
    1730: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14718,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD AJIB BIN OMAR',
        'parti': 'PKR',
    },
    1731: {
        'KodN': 13,
        'KodParlimen': 147,
        'KodKawasan': 14718,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SALEHUDIN AB RASHID',
        'parti': 'PAS',
    },
    1732: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 148,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MARDI BIN MARWAN',
        'parti': 'PAS',
    },
    1733: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 148,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK DR. IR. WEE KA SIONG',
        'parti': 'BN',
    },
    1734: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 148,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'LIEW CHIN TONG',
        'parti': 'PKR',
    },
    1735: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14819,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHEW PECK CHOO',
        'parti': 'PKR',
    },
    1736: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14819,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'LING TIAN SOON',
        'parti': 'BN',
    },
    1737: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14819,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMMAD BIN ABDULLAH',
        'parti': 'PAS',
    },
    1738: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14820,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK SAMSOLBARI BIN JAMALI',
        'parti': 'BN',
    },
    1739: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14820,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD BAKRI BIN SAMIAN',
        'parti': 'PAS',
    },
    1740: {
        'KodN': 13,
        'KodParlimen': 148,
        'KodKawasan': 14820,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAIS BIN MOHD AKIL',
        'parti': 'PKR',
    },
    1741: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 149,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK DR SHAHRUDDIN SALLEH',
        'parti': 'PKR',
    },
    1742: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 149,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LT KOL HJ M ASHARI SIDON',
        'parti': 'PAS',
    },
    1743: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 149,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK AZIZ KAPRAWI',
        'parti': 'BN',
    },
    1744: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14921,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SOH LIP YAN',
        'parti': 'BN',
    },
    1745: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14921,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CIKGU HAJI NASIR',
        'parti': 'PAS',
    },
    1746: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14921,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CIKGU AMINOLHUDA',
        'parti': 'PKR',
    },
    1747: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14922,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CIKGU ABDUL HADI BIN HARUN',
        'parti': 'PAS',
    },
    1748: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14922,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FERDAUS BIN KAYAU',
        'parti': 'PKR',
    },
    1749: {
        'KodN': 13,
        'KodParlimen': 149,
        'KodKawasan': 14922,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RASHIDAH RAMLI',
        'parti': 'BN',
    },
    1750: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 150,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HALIZA BINTI ABDULLAH',
        'parti': 'BN',
    },
    1751: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 150,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD RASHID BIN HASNON',
        'parti': 'PKR',
    },
    1752: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 150,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MAHFODZ BIN MOHAMED',
        'parti': 'PAS',
    },
    1753: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15023,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GAN PECK CHENG ',
        'parti': 'PKR',
    },
    1754: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15023,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KANG BENG KUAN ',
        'parti': 'BN',
    },
    1755: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15023,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MISRAN BIN SAMIAN ',
        'parti': 'PAS',
    },
    1756: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15024,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAIDI BIN JAPAR',
        'parti': 'BN',
    },
    1757: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15024,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KHAIRUDDIN BIN A RAHIM',
        'parti': 'PKR',
    },
    1758: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15024,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD RAMLI BIN MD KARI',
        'parti': 'PAS',
    },
    1759: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15025,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD TUKIRAN @ MOHD TUMIRAN BIN AHMAD',
        'parti': 'PAS',
    },
    1760: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15025,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MALIK FAISHAL BIN AHMAD ',
        'parti': 'PKR',
    },
    1761: {
        'KodN': 13,
        'KodParlimen': 150,
        'KodKawasan': 15025,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AYUB BIN JAMIL',
        'parti': 'BN',
    },
    1762: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 151,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'R. MASZLEE BIN MALIK',
        'parti': 'PKR',
    },
    1763: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 151,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK LIANG TECK MENG',
        'parti': 'BN',
    },
    1764: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 151,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHD JUBRI BIN SELAMAT',
        'parti': 'PAS',
    },
    1765: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15126,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJ AHMAD BIN AHEM',
        'parti': 'PKR',
    },
    1766: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15126,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZLISHAM BIN AZAHAR',
        'parti': 'PAS',
    },
    1767: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15126,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HJ ABD TAIB BIN ABU BAKAR',
        'parti': 'BN',
    },
    1768: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15127,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MURUGAN A/L MUTHUSAMY@RONY MURUGAN',
        'parti': 'PKR',
    },
    1769: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15127,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK ONN HAFIZ BIN GHAZI',
        'parti': 'BN',
    },
    1770: {
        'KodN': 13,
        'KodParlimen': 151,
        'KodKawasan': 15127,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD JUBRI BIN SELAMAT ',
        'parti': 'PAS',
    },
    1771: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 152,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUHAMMAD HASBULLAH BIN MD NAJIB',
        'parti': 'PAS',
    },
    1772: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 152,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'GAN PING SIEU',
        'parti': 'BN',
    },
    1773: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 152,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WONG SHU QI',
        'parti': 'PKR',
    },
    1774: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 15228,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHIN SIM LAI',
        'parti': 'BN',
    },
    1775: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 15228,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHEW CHONG SIN',
        'parti': 'PKR',
    },
    1776: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 15229,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MD JAIS BIN SARDAY',
        'parti': 'BN',
    },
    1777: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 15229,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MUHAMMAD HASBULLAH BIN MD NAJIB',
        'parti': 'PAS',
    },
    1778: {
        'KodN': 13,
        'KodParlimen': 152,
        'KodKawasan': 15229,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUHAMAD SAID BIN JONET',
        'parti': 'PKR',
    },
    1779: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 153,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'HISHAMMUDDIN TUN HUSSEIN',
        'parti': 'BN',
    },
    1780: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 153,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ONN ABU BAKAR',
        'parti': 'PKR',
    },
    1781: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 15330,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TEOH YAP KUN',
        'parti': 'BN',
    },
    1782: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 15330,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SHEIKH OMAR ALI',
        'parti': 'PKR',
    },
    1783: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 15330,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SHAMUGAM A/L MUNISAMY',
        'parti': 'BEBAS',
    },
    1784: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 15331,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'VIDYANANTHAN A/L RAMANADHAN',
        'parti': 'BN',
    },
    1785: {
        'KodN': 13,
        'KodParlimen': 153,
        'KodKawasan': 15331,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NOORLIHAN BINTI ARIFFIN',
        'parti': 'PKR',
    },
    1786: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 154,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ABD LATIFF BIN AHMAD',
        'parti': 'BN',
    },
    1787: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 154,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'A. RAHMAN BIN A HAMID',
        'parti': 'PAS',
    },
    1788: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 154,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MD NASIR BIN HASHIM',
        'parti': 'PKR',
    },
    1789: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15432,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ALWIYAH BINTI TALIB',
        'parti': 'BN',
    },
    1790: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15432,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROSLAN BIN NIKMAT',
        'parti': 'PAS',
    },
    1791: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15432,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NORUL HASZARUL BIN ABU SAMAH',
        'parti': 'PKR',
    },
    1792: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15433,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAVEN KUMAR A/L KRISHNASAMY',
        'parti': 'BN',
    },
    1793: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15433,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'A. RAHMAN BIN A HAMID',
        'parti': 'PAS',
    },
    1794: {
        'KodN': 13,
        'KodParlimen': 154,
        'KodKawasan': 15433,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAHAMIZON BINTI ABDUL GHANI',
        'parti': 'PKR',
    },
    1795: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 155,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ADHAM BIN BABA',
        'parti': 'BN',
    },
    1796: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 155,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NORJEPRI BIN MOHD JELANI',
        'parti': 'PKR',
    },
    1797: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 155,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'YUHANITA BINTI YUNAN',
        'parti': 'PAS',
    },
    1798: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15534,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAWAHIR BINTI HUSEIN',
        'parti': 'PKR',
    },
    1799: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15534,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HAHASRIN BIN HASHIM',
        'parti': 'BN',
    },
    1800: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15534,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD NAZARI BIN MOKHTAR',
        'parti': 'PAS',
    },
    1801: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15535,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RASHIDAH BINTI ISMAIL',
        'parti': 'BN',
    },
    1802: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15535,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABRARY BIN RAMLY',
        'parti': 'PKR',
    },
    1803: {
        'KodN': 13,
        'KodParlimen': 155,
        'KodKawasan': 15535,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BAHRIN BIN ALIAS',
        'parti': 'PAS',
    },
    1804: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 156,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HALIMAH BINTI MOHD SADIQUE',
        'parti': 'BN',
    },
    1805: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 156,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AZLINDA BINTI ABDUL LATIF',
        'parti': 'PKR',
    },
    1806: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 15636,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABD RAZAK BIN ISA',
        'parti': 'PKR',
    },
    1807: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 15636,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RASMAN BIN ITHNAIN',
        'parti': 'BN',
    },
    1808: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 15637,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NOR ASIDAH BINTI IBRAHIM',
        'parti': 'PKR',
    },
    1809: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 15637,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROSLELI BIN JAHARI',
        'parti': 'BN',
    },
    1810: {
        'KodN': 13,
        'KodParlimen': 156,
        'KodKawasan': 15637,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SITI ZAHARAH BINTI OTHMAN',
        'parti': 'PAS',
    },
    1811: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 157,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': "DATO' SRI AZALINA BINTI DATO' OTHMAN SAID",
        'parti': 'BN',
    },
    1812: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 157,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NORLIZA BINTI NGADIRAN',
        'parti': 'PKR',
    },
    1813: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 15738,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO 'SHARIFAH AZIZAH BINTI  DATO' SYED ZAIN",
        'parti': 'BN',
    },
    1814: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 15738,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD KAMAH BIN NOR',
        'parti': 'PKR',
    },
    1815: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 15739,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "DATO' IR  SYED SIS BIN A.RAHMAN",
        'parti': 'BN',
    },
    1816: {
        'KodN': 13,
        'KodParlimen': 157,
        'KodKawasan': 15739,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ZAMIL NAJWAH BIN ARBAAIN',
        'parti': 'PKR',
    },
    1817: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 158,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'CHOONG SHIAU YOON',
        'parti': 'PKR',
    },
    1818: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 158,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'HOU KOK CHUNG',
        'parti': 'BN',
    },
    1819: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 158,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ABDULLAH BIN HUSSIN',
        'parti': 'PAS',
    },
    1820: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15840,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GOPALAKRISHNAN A/L SUBRAMANIAM',
        'parti': 'PKR',
    },
    1821: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15840,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AZMAN BIN ATMIN',
        'parti': 'PAS',
    },
    1822: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15840,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MAULIZAN BIN BUJANG',
        'parti': 'BN',
    },
    1823: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15841,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL AZIZ BIN TOHAK',
        'parti': 'BN',
    },
    1824: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15841,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MAZLAN BIN BUJANG',
        'parti': 'BERSATU',
    },
    1825: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15841,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LIM YAK HONG',
        'parti': 'BEBAS',
    },
    1826: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15841,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ABDULLAH BIN HUSSIN',
        'parti': 'PAS',
    },
    1827: {
        'KodN': 13,
        'KodParlimen': 158,
        'KodKawasan': 15841,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'TING CHOON CHAI',
        'parti': 'BEBAS',
    },
    1828: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 159,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'AB. AZIZ BIN ABDULLAH',
        'parti': 'PAS',
    },
    1829: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 159,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMED KHALED NORDIN',
        'parti': 'BN',
    },
    1830: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 159,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CHEE JOCK',
        'parti': 'BEBAS',
    },
    1831: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 159,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'HASSAN BIN ABDUL KARIM',
        'parti': 'PKR',
    },
    1832: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15942,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN CHER PUK',
        'parti': 'BN',
    },
    1833: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15942,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KUMUTHA A/P RAHMAN',
        'parti': 'PAS',
    },
    1834: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15942,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIOW CAI TUNG',
        'parti': 'DAP',
    },
    1835: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15943,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMED KHALED NORDIN',
        'parti': 'BN',
    },
    1836: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15943,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AB. AZIZ BIN ABDULLAH',
        'parti': 'PAS',
    },
    1837: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15943,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ROHANI BINTI YAACOB',
        'parti': 'BEBAS',
    },
    1838: {
        'KodN': 13,
        'KodParlimen': 159,
        'KodKawasan': 15943,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'CHE ZAKARIA BIN MOHD SALLEH',
        'parti': 'BERSATU',
    },
    1839: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 160,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'SHAHRIR BIN ABDUL SAMAD',
        'parti': 'BN',
    },
    1840: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 160,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AKMAL NASIR',
        'parti': 'PKR',
    },
    1841: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 16044,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YAHYA BIN JAAFAR',
        'parti': 'BN',
    },
    1842: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 16044,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD IZHAR BIN AHMAD',
        'parti': 'PKR',
    },
    1843: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 16044,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ZAKIAH BINTI TUKIRIN',
        'parti': 'PAS',
    },
    1844: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 16045,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ANG BOON HENG',
        'parti': 'BN',
    },
    1845: {
        'KodN': 13,
        'KodParlimen': 160,
        'KodKawasan': 16045,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ANDREW CHEN KAH ENG',
        'parti': 'PKR',
    },
    1846: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 161,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SALAHUDDIN BIN AYUB',
        'parti': 'PKR',
    },
    1847: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 161,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NUR JAZLAN BIN TAN SRI MOHAMED',
        'parti': 'BN',
    },
    1848: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 161,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'MOHD MAZRI BIN YAHYA',
        'parti': 'PAS',
    },
    1849: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 161,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'YAP KENG TAK',
        'parti': 'BEBAS',
    },
    1850: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16146,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WONG YOU FONG',
        'parti': 'BN',
    },
    1851: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16146,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHEO YEE HOW',
        'parti': 'PKR',
    },
    1852: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16146,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD NAZRIN BIN IHSAN',
        'parti': 'PAS',
    },
    1853: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16147,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RAMLEE BIN BOHANI',
        'parti': 'BN',
    },
    1854: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16147,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'OSMAN BIN SAPIAN',
        'parti': 'PKR',
    },
    1855: {
        'KodN': 13,
        'KodParlimen': 161,
        'KodKawasan': 16147,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DZULKIFLI BIN SULAIMAN',
        'parti': 'PAS',
    },
    1856: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 162,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'JASON TEOH SEW HOCK',
        'parti': 'BN',
    },
    1857: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 162,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'LIM KIT SIANG',
        'parti': 'PKR',
    },
    1858: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 16248,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'S KANAN',
        'parti': 'BN',
    },
    1859: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 16248,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN HONG PIN',
        'parti': 'PKR',
    },
    1860: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 16249,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD KHAIRI BIN A.MALIK',
        'parti': 'BN',
    },
    1861: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 16249,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DZULKEFLY AHMAD',
        'parti': 'PKR',
    },
    1862: {
        'KodN': 13,
        'KodParlimen': 162,
        'KodKawasan': 16249,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ SALLEHUDDIN BIN MOHD DAHIRAN',
        'parti': 'PAS',
    },
    1863: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 163,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'TANG NAI SOON',
        'parti': 'BN',
    },
    1864: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 163,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JUWAHIR BIN AMIN',
        'parti': 'PAS',
    },
    1865: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 163,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TEO NIE CHING',
        'parti': 'PKR',
    },
    1866: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16350,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': "ABD AZIZ BIN JA'AFAR",
        'parti': 'PAS',
    },
    1867: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16350,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ALI MAZAT BIN SALLEH',
        'parti': 'BN',
    },
    1868: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16350,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TOSRIN BIN JARVANTHI',
        'parti': 'PKR',
    },
    1869: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16351,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JIMMY PUAH WEE TSE',
        'parti': 'PKR',
    },
    1870: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16351,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEO LEE HO',
        'parti': 'BN',
    },
    1871: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16351,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JUWAHIR BIN AMIN',
        'parti': 'PAS',
    },
    1872: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16352,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SHEN POH KUAN',
        'parti': 'BN',
    },
    1873: {
        'KodN': 13,
        'KodParlimen': 163,
        'KodKawasan': 16352,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TEE BOON TSONG',
        'parti': 'PKR',
    },
    1874: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 164,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'AHMAD BIN MASLAN',
        'parti': 'BN',
    },
    1875: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 164,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'KARMAIN BIN SARDINI',
        'parti': 'BERSEKUTU',
    },
    1876: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 164,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'BAHAROM BIN MOHAMAD',
        'parti': 'PAS',
    },
    1877: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16453,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HASNI BIN MOHAMMAD',
        'parti': 'BN',
    },
    1878: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16453,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ZULKIFLI BIN TASREP',
        'parti': 'PKR',
    },
    1879: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16453,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHD FIRDAUS BIN JAFFAR',
        'parti': 'PAS',
    },
    1880: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16454,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TEE SIEW KIONG',
        'parti': 'BN',
    },
    1881: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16454,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'BAHAROM BIN MOHAMAD',
        'parti': 'PAS',
    },
    1882: {
        'KodN': 13,
        'KodParlimen': 164,
        'KodKawasan': 16454,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAQIUDDIN BIN CHE MAN',
        'parti': 'PKR',
    },
    1883: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 165,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WEE JECK SENG',
        'parti': 'BN',
    },
    1884: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 165,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'NORDIN BIN OTHMAN',
        'parti': 'PAS',
    },
    1885: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 165,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DR MD FARID BIN MD RAFIQ',
        'parti': 'PKR',
    },
    1886: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 16555,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'TAN ENG MENG',
        'parti': 'BN',
    },
    1887: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 16555,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YEO TUNG SIONG',
        'parti': 'PKR',
    },
    1888: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 16556,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SUHAIZAN BIN KAYAT',
        'parti': 'PKR',
    },
    1889: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 16556,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MD OTHMAN BIN YUSOF',
        'parti': 'BN',
    },
    1890: {
        'KodN': 13,
        'KodParlimen': 165,
        'KodKawasan': 16556,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KARIM BIN DERAMAN ',
        'parti': 'PAS',
    },
    1891: {
        'KodN': 9,
        'KodParlimen': 166,
        'KodKawasan': 166,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ROZMAN BIN ISLI',
        'parti': 'BN',
    },
    1892: {
        'KodN': 9,
        'KodParlimen': 166,
        'KodKawasan': 166,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SITI ZALEHA S.W. IBRAHIM',
        'parti': 'PHRS',
    },
    1893: {
        'KodN': 9,
        'KodParlimen': 166,
        'KodKawasan': 166,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'AHMAD JUNID @ JUNIT BIN MOHD ALING @ ALING',
        'parti': 'PAS',
    },
    1894: {
        'KodN': 9,
        'KodParlimen': 166,
        'KodKawasan': 166,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'NOOR HALIM BIN ZAINI',
        'parti': 'WARISAN',
    },
    1895: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 167,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK ABDUL RAHIM BAKRI',
        'parti': 'BN',
    },
    1896: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 167,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHD ASHRAF CHIN ABDULLAH',
        'parti': 'PCS',
    },
    1897: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 167,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SH AZMAN BIN SH ALONG',
        'parti': 'WARISAN',
    },
    1898: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ABDUL MIJUL BIN UNAINI',
        'parti': 'BN',
    },
    1899: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABIDULA BIN AMSANA',
        'parti': 'PHRS',
    },
    1900: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOHAMMAD MOHARMIN',
        'parti': 'WARISAN',
    },
    1901: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'NORLAJI BIN AMIR HASSAN',
        'parti': 'STAR',
    },
    1902: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ABDUL NASIR BIN JAMALUDDIN',
        'parti': 'PKS',
    },
    1903: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16701,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'KUSUGAN BIN ALI ( PPRS )',
        'parti': 'BEBAS',
    },
    1904: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16702,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI PANGLIMA TEO CHEE KANG',
        'parti': 'BN',
    },
    1905: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16702,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'TSEN CHOU YIN@THOMAS TSEN CHAU YIN',
        'parti': 'PCS',
    },
    1906: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16702,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHONG CHEN BIN',
        'parti': 'WARISAN',
    },
    1907: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16702,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ALIASGAR BIN OMOLONG',
        'parti': 'PAS',
    },
    1908: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16702,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ALLAIDLY BINTI POYON (PPRS)',
        'parti': 'BEBAS',
    },
    1909: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DAUSIEH BINTI QUECK @ PARAMAN',
        'parti': 'PAS',
    },
    1910: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK BOLKIAH BIN ISMAIL',
        'parti': 'BN',
    },
    1911: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PRANSOL TIYING ( ANAK NEGERI )',
        'parti': 'BEBAS',
    },
    1912: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 7,
        'NamaCalon': 'BAKIR BIN MANCAING',
        'parti': 'BEBAS',
    },
    1913: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'RAMLAH BINTI NASIR',
        'parti': 'PKS',
    },
    1914: {
        'KodN': 15,
        'KodParlimen': 167,
        'KodKawasan': 16703,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'MAKLIN BIN MASIAU',
        'parti': 'WARISAN',
    },
    1915: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 168,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DSP DR MAXIMUS J.ONGKILI',
        'parti': 'BN',
    },
    1916: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 168,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'DR PAUL PORODONG',
        'parti': 'PCS',
    },
    1917: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 168,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK MAIJOL MAHAP',
        'parti': 'PKR',
    },
    1918: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 168,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'BARLUS MANGABIS',
        'parti': 'WARISAN',
    },
    1919: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16804,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JULITA MOJUNGKI',
        'parti': 'BN',
    },
    1920: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16804,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JORNAH MOZIHIM',
        'parti': 'PCS',
    },
    1921: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16804,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'SAZALYE DONOL ABDULLAH',
        'parti': 'PKR',
    },
    1922: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16804,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MARUNSAI DAWAI',
        'parti': 'STAR',
    },
    1923: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16804,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'RAHIM MADHAKONG',
        'parti': 'PKS',
    },
    1924: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16805,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ANITA BARANTING',
        'parti': 'BN',
    },
    1925: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16805,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATO BAINTIN ADUN',
        'parti': 'WARISAN',
    },
    1926: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16805,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JOEL MASILUNG',
        'parti': 'STAR',
    },
    1927: {
        'KodN': 15,
        'KodParlimen': 168,
        'KodKawasan': 16805,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JOHNSON GABAN',
        'parti': 'PCS',
    },
    1928: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 169,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LAIMAN BIN IKIN @ AG LAIMAN B. KAKIMIN',
        'parti': 'PAS',
    },
    1929: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 169,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK SERI PANGLIMA MD SALLEH TUN SAID',
        'parti': 'BN',
    },
    1930: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 169,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MIASIN @ AIMADUDDIN BIN MION',
        'parti': 'PHRS',
    },
    1931: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 169,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'ISNARAISAH MUNIRAH BINTI MAJILIS @ FAKHARUDY',
        'parti': 'WARISAN',
    },
    1932: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16906,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SUWAH BIN BULLEH',
        'parti': 'STAR',
    },
    1933: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16906,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MUSTAQIM BIN ALING',
        'parti': 'PAS',
    },
    1934: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16906,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HJ. MUSBAH BIN HJ. JAMLI',
        'parti': 'BN',
    },
    1935: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16906,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MUSTAPHA @ MOHD YUNUS BIN SAKMUD',
        'parti': 'PKR',
    },
    1936: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16907,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MAIL BIN BALINU',
        'parti': 'PCS',
    },
    1937: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16907,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RUBIN GURIBAH',
        'parti': 'STAR',
    },
    1938: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16907,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LUKIAH BINTI INDAN',
        'parti': 'PKR',
    },
    1939: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16907,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SATAIL BIN MAJUNGKAT',
        'parti': 'PAS',
    },
    1940: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16907,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'EWON BENEDICK',
        'parti': 'BN',
    },
    1941: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16908,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'AMSOR BIN TUAH',
        'parti': 'BEBAS',
    },
    1942: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16908,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK JAPLIN BIN AKIM @ ABD HAMID',
        'parti': 'BN',
    },
    1943: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16908,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD BATHRIN @ ABD BAHKRIN BIN MOHD YUSOF',
        'parti': 'WARISAN',
    },
    1944: {
        'KodN': 15,
        'KodParlimen': 169,
        'KodKawasan': 16908,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ADZMIN BIN AWANG',
        'parti': 'PAS',
    },
    1945: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 170,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MADIUS BIN TANGAU',
        'parti': 'BN',
    },
    1946: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 170,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CHRISNADIA BINTI SINAM',
        'parti': 'PKR',
    },
    1947: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 170,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'SYRA PETER @ P GOM',
        'parti': 'PHRS',
    },
    1948: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 170,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'KALAKAU @ KALAKAN BIN UNTOL @ ENTOL',
        'parti': 'PCS',
    },
    1949: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 170,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'PAUMIN @ MOHD AMINUDDIN BIN ALING',
        'parti': 'PAS',
    },
    1950: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17009,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'SAMIN @ JASMIN BIN DULIN',
        'parti': 'STAR',
    },
    1951: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17009,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAHID @ NOORDIN BIN JAHIM',
        'parti': 'BN',
    },
    1952: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17009,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DAUSIL BIN KUNDAYONG',
        'parti': 'PKR',
    },
    1953: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17009,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MOJILIP BIN BUMBURING @ WILFRED',
        'parti': 'PCS',
    },
    1954: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17010,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'HAJIJI BIN HAJI NOOR',
        'parti': 'BN',
    },
    1955: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17010,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDULLAH SANI BIN DAUD',
        'parti': 'WARISAN',
    },
    1956: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17010,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ARIFIN BIN HARITH',
        'parti': 'PHRS',
    },
    1957: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17011,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JONISTON BIN LUMAI @ BANGKUAI',
        'parti': 'BN',
    },
    1958: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17011,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JO-ANNA SUE HENLEY RAMPAS',
        'parti': 'WARISAN',
    },
    1959: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17011,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GAIBIN BIN RANSOI',
        'parti': 'PCS',
    },
    1960: {
        'KodN': 15,
        'KodParlimen': 170,
        'KodKawasan': 17011,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TERENCE SINTI',
        'parti': 'STAR',
    },
    1961: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 171,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'JEFFRY KUMIN',
        'parti': 'SAPP',
    },
    1962: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 171,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ROBERT SOPINING',
        'parti': 'PCS',
    },
    1963: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 171,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ABDUL RAHMAN BIN DAHLAN',
        'parti': 'BN',
    },
    1964: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 171,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'AZIS JAMMAN',
        'parti': 'WARISAN',
    },
    1965: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17112,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AZHAR MATUSSIN',
        'parti': 'WARISAN',
    },
    1966: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17112,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JAINAB DSP  AHMAD  AYID',
        'parti': 'BN',
    },
    1967: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17112,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ASPAR BIN OYET @ AKBAR',
        'parti': 'PAS',
    },
    1968: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17112,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ASHIM JAMAT',
        'parti': 'SAPP',
    },
    1969: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAKARIAH JANIT',
        'parti': 'PKS',
    },
    1970: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JOHNNY GOH CHIN LOK',
        'parti': 'BN',
    },
    1971: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SITUL MINTOW',
        'parti': 'BEBAS',
    },
    1972: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'TERENCE TSEN KIM FATT',
        'parti': 'PKAN',
    },
    1973: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'KENNY CHUA TECK HO',
        'parti': 'PKR',
    },
    1974: {
        'KodN': 15,
        'KodParlimen': 171,
        'KodKawasan': 17113,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'JOHN STEPHEN DIONYSIUS',
        'parti': 'SAPP',
    },
    1975: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 172,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LEE HAN KYUN @ JOSEPH LEE',
        'parti': 'BN',
    },
    1976: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 172,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'YONG TECK LEE',
        'parti': 'SAPP',
    },
    1977: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 172,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CHAN FOONG HIN',
        'parti': 'DAP',
    },
    1978: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17214,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHIN SHU YING',
        'parti': 'BN',
    },
    1979: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17214,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YONG WE KONG',
        'parti': 'SAPP',
    },
    1980: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17214,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAN LEE FATT',
        'parti': 'DAP',
    },
    1981: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17215,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YEE MOH CHAI',
        'parti': 'BN',
    },
    1982: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17215,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHAN CHEE CHING',
        'parti': 'BEBAS',
    },
    1983: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17215,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LEN LIP FONG @ LAND LIP FONG',
        'parti': 'PKAN',
    },
    1984: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17215,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'LIEW CHIN JIN',
        'parti': 'PKR',
    },
    1985: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17215,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'LIM KAT CHUNG',
        'parti': 'SAPP',
    },
    1986: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17216,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'PAMELA YONG',
        'parti': 'BN',
    },
    1987: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17216,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'GEE TIEN SIONG',
        'parti': 'SAPP',
    },
    1988: {
        'KodN': 15,
        'KodParlimen': 172,
        'KodKawasan': 17216,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PHOONG JIN ZHE',
        'parti': 'DAP',
    },
    1989: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 173,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'marcus m mojigoh',
        'parti': 'BN',
    },
    1990: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 173,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'awang husaini bin sahari',
        'parti': 'PKR',
    },
    1991: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 173,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'mil kusin bin abdillah',
        'parti': 'PKAN',
    },
    1992: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 173,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'jivol@edmund bin poupolin',
        'parti': 'PHRS',
    },
    1993: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 173,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'zulzaim hilmee bin abidin',
        'parti': 'PAS',
    },
    1994: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17317,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'edward yong oui fah',
        'parti': 'BN',
    },
    1995: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17317,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'chong wei leung',
        'parti': 'PKAN',
    },
    1996: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17317,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'noraiza binti hj mohammad noor',
        'parti': 'PHRS',
    },
    1997: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17317,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'hamid bin ismail',
        'parti': 'PAS',
    },
    1998: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17317,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'wong hong junz',
        'parti': 'WARISAN',
    },
    1999: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17318,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'yahya hussin',
        'parti': 'BN',
    },
    2000: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17318,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ester otion',
        'parti': 'PHRS',
    },
    2001: {
        'KodN': 15,
        'KodParlimen': 173,
        'KodKawasan': 17318,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'uda bin sulai',
        'parti': 'WARISAN',
    },
    2002: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 174,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'CEASER MANDELA MALAKUN',
        'parti': 'BN',
    },
    2003: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 174,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'EDWIN @ JACK BOSI',
        'parti': 'PKAN',
    },
    2004: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 174,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'CLEFTUS STEPHEN SPINE',
        'parti': 'STAR',
    },
    2005: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 174,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'IGNATIUS DARELL LEIKING',
        'parti': 'WARISAN',
    },
    2006: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17419,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'GOH FAH SHUN',
        'parti': 'BN',
    },
    2007: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17419,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CHONG PIT FAH',
        'parti': 'STAR',
    },
    2008: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17419,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JANNIE LASIMBANG',
        'parti': 'DAP',
    },
    2009: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17420,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BANDASAN @ DIONISIUS DENNIS J TUNDING',
        'parti': 'PCS',
    },
    2010: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17420,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DONALD PETER MAJUNTIN',
        'parti': 'BN',
    },
    2011: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17420,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JENIFER LASIMBANG',
        'parti': 'WARISAN',
    },
    2012: {
        'KodN': 15,
        'KodParlimen': 174,
        'KodKawasan': 17420,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DANIM @ ALOYSIUS SIAP',
        'parti': 'STAR',
    },
    2013: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 175,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DATUK ROSNAH BINTI HJ ABD RASHID SHIRLIN',
        'parti': 'BN',
    },
    2014: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 175,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'AHMAD BIN HASSAN',
        'parti': 'WARISAN',
    },
    2015: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 175,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'JAMIL BIN WILLIAM CORE',
        'parti': 'STAR',
    },
    2016: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 175,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ELBEAT BIN SIKUIL',
        'parti': 'PCS',
    },
    2017: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17521,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MATLIN BIN JILON',
        'parti': 'PKS',
    },
    2018: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17521,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK GHULAMHAIDAR@YUSOF BIN KHAN',
        'parti': 'BN',
    },
    2019: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17521,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': ' SALLEH IDRIS',
        'parti': 'WARISAN',
    },
    2020: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17521,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'WAHID @HARITH BIN ISMAIL',
        'parti': 'PKAN',
    },
    2021: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17522,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK SERI PANGLIMA HJ ABDUL RAHIM ISMAIL',
        'parti': 'BN',
    },
    2022: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17522,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'DATUK HAIDI BIN MOKTHAR',
        'parti': 'WARISAN',
    },
    2023: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17522,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAWASING BIN MAINUS@HERMAN I MIANAS',
        'parti': 'PCS',
    },
    2024: {
        'KodN': 15,
        'KodParlimen': 175,
        'KodKawasan': 17522,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK JAMES @ EBI GHANI',
        'parti': 'PKS',
    },
    2025: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 176,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ANIFAH AMAN',
        'parti': 'BN',
    },
    2026: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 176,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'JAAFAR BIN ISMAIL',
        'parti': 'PHRS',
    },
    2027: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 176,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'KARIM BIN BUJANG',
        'parti': 'WARISAN',
    },
    2028: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17623,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK MOHAMAD BIN ALAMIN',
        'parti': 'BN',
    },
    2029: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17623,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DAUD BIN YUSOF',
        'parti': 'WARISAN',
    },
    2030: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17623,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JAAFAR BIN ISMAIL',
        'parti': 'PHRS',
    },
    2031: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17624,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROSJELEN BINTI SALIMAT',
        'parti': 'PCS',
    },
    2032: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17624,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MOHD ARIFIN BIN MOHD ARIF',
        'parti': 'BN',
    },
    2033: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17624,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ALI OMAR BIN MOHD IDRIS',
        'parti': 'PHRS',
    },
    2034: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17624,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HAJI YAHYA BIN AHMAD',
        'parti': 'BEBAS',
    },
    2035: {
        'KodN': 15,
        'KodParlimen': 176,
        'KodKawasan': 17624,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ABD SANI BIN MARIP @ MARIF',
        'parti': 'WARISAN',
    },
    2036: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 177,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK HJH AZIZAH DSP MOHD DUN',
        'parti': 'BN',
    },
    2037: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 177,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK JOHN GHANI',
        'parti': 'PKR',
    },
    2038: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 177,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'DSP HJ LAJIM UKIN',
        'parti': 'PHRS',
    },
    2039: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17725,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK ISNIN BIN ALIASNIH ',
        'parti': 'BN',
    },
    2040: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17725,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HJH JOHAIR MATLANI',
        'parti': 'WARISAN',
    },
    2041: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17725,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DSP HJ LAJIM BIN UKIN',
        'parti': 'PHRS',
    },
    2042: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17726,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'LIMUS BIN JURI',
        'parti': 'BN',
    },
    2043: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17726,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'EN JONAS SUNGGIM',
        'parti': 'PHRS',
    },
    2044: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17726,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EN DIKIN HJ MUSAH',
        'parti': 'PKR',
    },
    2045: {
        'KodN': 15,
        'KodParlimen': 177,
        'KodKawasan': 17726,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK HERMAN TIONGSUH',
        'parti': 'PCS',
    },
    2046: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 178,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'YAMANI HAFEZ BIN MUSA',
        'parti': 'BN',
    },
    2047: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 178,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NOOR HAYATY BINTI MUSTAPHA',
        'parti': 'BEBAS',
    },
    2048: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 178,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DAYANG AEZZY BINTI LIMAN',
        'parti': 'BEBAS',
    },
    2049: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17827,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MATBALI BIN MUSAH',
        'parti': 'BN',
    },
    2050: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17827,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MD SAMLIH BIN JUAISIN',
        'parti': 'WARISAN',
    },
    2051: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17827,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ASMAT BIN JAPAR',
        'parti': 'PHRS',
    },
    2052: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17828,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAPAWI BIN AMAT WASLI@AHMAD',
        'parti': 'BN',
    },
    2053: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17828,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'YUSOF@JOSREE BIN YACOB',
        'parti': 'BEBAS',
    },
    2054: {
        'KodN': 15,
        'KodParlimen': 178,
        'KodKawasan': 17828,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PATRICK SADOM',
        'parti': 'BEBAS',
    },
    2055: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 179,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'EWON BIN EBIN',
        'parti': 'BN',
    },
    2056: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 179,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'JONATHAN YASIN',
        'parti': 'PKR',
    },
    2057: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 179,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ANDAU BIN YASUN @ BRUNO',
        'parti': 'PCS',
    },
    2058: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17929,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JOACHIM GUNSALAM',
        'parti': 'BN',
    },
    2059: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17929,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'JAPIRIL SUHAIMIN',
        'parti': 'STAR',
    },
    2060: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17929,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JINUS SODIONG',
        'parti': 'PKS',
    },
    2061: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17929,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HENRYNUS AMIN',
        'parti': 'PKAN',
    },
    2062: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17930,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AMAN @ AZMAN MANAF',
        'parti': 'STAR',
    },
    2063: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17930,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MASIDI MANJUN @ MASDI',
        'parti': 'BN',
    },
    2064: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17930,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'CHONG PECK HING@CHONG POH SING',
        'parti': 'PKR',
    },
    2065: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17930,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JUHAILI SIDEK',
        'parti': 'PKAN',
    },
    2066: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17931,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABIDIN MADINGKIR',
        'parti': 'BN',
    },
    2067: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17931,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'PEDDRIN @ FEDDRIN TUUANG @ TULING',
        'parti': 'STAR',
    },
    2068: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17931,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JULIAN @ PAUL SIDIN',
        'parti': 'WARISAN',
    },
    2069: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17931,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MAT JAILI BIN SAMAT',
        'parti': 'PRS',
    },
    2070: {
        'KodN': 15,
        'KodParlimen': 179,
        'KodKawasan': 17931,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'SATIOL BIN INDONG',
        'parti': 'PCS',
    },
    2071: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 180,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'JIUS BIN AWANG',
        'parti': 'PCS',
    },
    2072: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 180,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MAIMIN BIN RIJAN@JEFFRUS RIJAN',
        'parti': 'BEBAS',
    },
    2073: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 180,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'DATUK DANIEL KINSIK',
        'parti': 'BN',
    },
    2074: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 180,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'DATUK JUSTIN GUKA',
        'parti': 'BEBAS',
    },
    2075: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 180,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'JAKE NOINTIN',
        'parti': 'WARISAN',
    },
    2076: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18032,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JUSTIN BIN ALIP',
        'parti': 'WARISAN',
    },
    2077: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18032,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK DR JEFFREY KITINGAN',
        'parti': 'STAR',
    },
    2078: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18032,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NESTOR BIN JOANNES',
        'parti': 'PCS',
    },
    2079: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18032,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JOSEPH PAIRIN KITINGAN',
        'parti': 'BN',
    },
    2080: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'PETER JINO ALLION',
        'parti': 'BN',
    },
    2081: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK JUSTIN GUKA',
        'parti': 'BEBAS',
    },
    2082: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ROBERT TAWIK',
        'parti': 'STAR',
    },
    2083: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'PETER SAILT',
        'parti': 'DAP',
    },
    2084: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'THOMAS ANGGAN',
        'parti': 'PKS',
    },
    2085: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18033,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'DR AISAT ELLIK BIN IGAU@OSWOLD IGGAN',
        'parti': 'PKAN',
    },
    2086: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18034,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'RASININ BIN KOUTIS@KAUTIS',
        'parti': 'WARISAN',
    },
    2087: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18034,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK SAPIN@SAIRIN BIN KARANO@KARNO',
        'parti': 'BN',
    },
    2088: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18034,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'KONG FUI SENG',
        'parti': 'STAR',
    },
    2089: {
        'KodN': 15,
        'KodParlimen': 180,
        'KodKawasan': 18034,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HUSSEIN@JAIMIS BIN KASSIM@MADATIN',
        'parti': 'PCS',
    },
    2090: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 181,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'RUBIN BIN BALANG',
        'parti': 'BN',
    },
    2091: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 181,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'NOORITA SUAL',
        'parti': 'DAP',
    },
    2092: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 181,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'LAIMOI YUSLINAH BIN LAIKIM',
        'parti': 'PHRS',
    },
    2093: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18135,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JAINEH BIN JUAYA@JIMMY JAWATAH',
        'parti': 'STAR',
    },
    2094: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18135,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'RADIN MALLEH',
        'parti': 'BN',
    },
    2095: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18135,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'PETER ANTHONY',
        'parti': 'WARISAN',
    },
    2096: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18135,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'CHINLY BIN MONIU@MAH TSEN LI',
        'parti': 'PCS',
    },
    2097: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18135,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'LIDOS RABIH@GEORGE REJOS',
        'parti': 'PKS',
    },
    2098: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18136,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YAHIA@YAHYA BIN RAIMAH',
        'parti': 'PHRS',
    },
    2099: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18136,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HARRIS BOLOS',
        'parti': 'WARISAN',
    },
    2100: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18136,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'TAY JIN KIONG @ ALFRED',
        'parti': 'PCS',
    },
    2101: {
        'KodN': 15,
        'KodParlimen': 181,
        'KodKawasan': 18136,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JAMAWI BIN JAAFAR',
        'parti': 'BN',
    },
    2102: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 182,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'JOH JIMMY @ RICHARD JOE',
        'parti': 'STAR',
    },
    2103: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 182,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ARTHUR JOSEPH KURUP',
        'parti': 'BN',
    },
    2104: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 182,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'RAYMOND AHUAR',
        'parti': 'PKR',
    },
    2105: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 182,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MAIDIN ATAK',
        'parti': 'PCS',
    },
    2106: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 182,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'ENGAH SINTAN',
        'parti': 'BEBAS',
    },
    2107: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18237,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ELLRON ANGIN',
        'parti': 'BN',
    },
    2108: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18237,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MARTIN TOMMY',
        'parti': 'WARISAN',
    },
    2109: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18237,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'BARITUS GUNGKIT',
        'parti': 'STAR',
    },
    2110: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18237,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'PETER BEATY',
        'parti': 'PKAN',
    },
    2111: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18238,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BOBBEY AH FANG SUAN',
        'parti': 'BN',
    },
    2112: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18238,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ANGIN@NASARUDIN LAMBAHAN',
        'parti': 'PCS',
    },
    2113: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18238,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AHUAR RASAM',
        'parti': 'WARISAN',
    },
    2114: {
        'KodN': 15,
        'KodParlimen': 182,
        'KodKawasan': 18238,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'APANDY@LUKAN AGINDI',
        'parti': 'PHRS',
    },
    2115: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK RONALD KIANDEE',
        'parti': 'BN',
    },
    2116: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'SALIMAH BINTI OYONG',
        'parti': 'BEBAS',
    },
    2117: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'TOIDY LUIT',
        'parti': 'PCS',
    },
    2118: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'SIPIN BIN KADANDI',
        'parti': 'PHRS',
    },
    2119: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 5,
        'NamaCalon': 'JAPAR BIN ZAIRUN',
        'parti': 'WARISAN',
    },
    2120: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 183,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 6,
        'NamaCalon': 'LEM @ SALIM BIN MATIN',
        'parti': 'PPRS',
    },
    2121: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18339,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK JAMES RATIB',
        'parti': 'BN',
    },
    2122: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18339,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ASPAH ABDULLAH SANI',
        'parti': 'WARISAN',
    },
    2123: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18339,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ARSHAD BIN ABDUL',
        'parti': 'PPRS',
    },
    2124: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18339,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'AG OSMAN ASIBIH',
        'parti': 'PKS',
    },
    2125: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18340,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL RAHMAN BIN KONGKAWANG',
        'parti': 'BN',
    },
    2126: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18340,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ALBERT THOMAS ENTI',
        'parti': 'PKS',
    },
    2127: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18340,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'RAMSAH TASIM',
        'parti': 'WARISAN',
    },
    2128: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18340,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JAMES MIKI',
        'parti': 'PCS',
    },
    2129: {
        'KodN': 15,
        'KodParlimen': 183,
        'KodKawasan': 18340,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'RAINUS AWANG',
        'parti': 'STAR',
    },
    2130: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 184,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'ZAKARIA HJ MOHD EDRIS',
        'parti': 'BN',
    },
    2131: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 184,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ALFIAN BIN MANSYUR ',
        'parti': 'PHRS',
    },
    2132: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 184,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'IRWANSHAH BIN MUSTAFA',
        'parti': 'WARISAN',
    },
    2133: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18441,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'JUSLIEE BIN AJIROL',
        'parti': 'BN',
    },
    2134: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18441,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JOILIN @ CHIRISTIN BTE BUGUNG',
        'parti': 'PKS',
    },
    2135: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18441,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ARUNARNSIN BIN TAIB',
        'parti': 'WARISAN',
    },
    2136: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18441,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JAMALUDDIN BIN LAMBA',
        'parti': 'PKAN',
    },
    2137: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18441,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'DAHIL MASDIK',
        'parti': 'PHRS',
    },
    2138: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18442,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUSA HJ AMAN',
        'parti': 'BN',
    },
    2139: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18442,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'HJ ASMARA BIN ABD RAHMAN',
        'parti': 'WARISAN',
    },
    2140: {
        'KodN': 15,
        'KodParlimen': 184,
        'KodKawasan': 18442,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'OSMAN BIN ENTING',
        'parti': 'PKS',
    },
    2141: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 185,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LINDA TSEN THAU LIN',
        'parti': 'BN',
    },
    2142: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 185,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'NORSAH BINTI BUNGSO',
        'parti': 'PAS',
    },
    2143: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 185,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'LIEW VUI KEONG',
        'parti': 'WARISAN',
    },
    2144: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 185,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'HAMZAH ABDULLAH',
        'parti': 'AMANAH',
    },
    2145: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAMSUDIN  YAHYA',
        'parti': 'BN',
    },
    2146: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ABDUL RASHID BIN ABDUL RAHMAN',
        'parti': 'STAR',
    },
    2147: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ARIFFIN BIN ASGALI',
        'parti': 'WARISAN',
    },
    2148: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'SAHAR ABDUL MAJID',
        'parti': 'PAS',
    },
    2149: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ALIAS RAHMAD BIN BENJAMIN',
        'parti': 'PKS',
    },
    2150: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18543,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'DATU MOHD FAIZAL DATU BACHTIAL',
        'parti': 'BEBAS',
    },
    2151: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18544,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'LIM KAI MIN',
        'parti': 'BN',
    },
    2152: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18544,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NORSAH BINTI BUNGSO',
        'parti': 'PAS',
    },
    2153: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18544,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'BESARUN BIN KECHA',
        'parti': 'STAR',
    },
    2154: {
        'KodN': 15,
        'KodParlimen': 185,
        'KodKawasan': 18544,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'HIEW VUN ZIN',
        'parti': 'WARISAN',
    },
    2155: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 186,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'LIM MING HOO',
        'parti': 'BN',
    },
    2156: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 186,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'WONG CHEN FATT',
        'parti': 'DAP',
    },
    2157: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 18645,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'CHAN TZUN HEI',
        'parti': 'BN',
    },
    2158: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 18645,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'CALVIN CHONG',
        'parti': 'DAP',
    },
    2159: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 18646,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'JUFAZLI SH AHMAD ',
        'parti': 'BEBAS',
    },
    2160: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 18646,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAYMON TAN',
        'parti': 'BN',
    },
    2161: {
        'KodN': 15,
        'KodParlimen': 186,
        'KodKawasan': 18646,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'FRANKIE POON MING FUNG',
        'parti': 'DAP',
    },
    2162: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 187,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MUSTAPA BIN DATU TAMBUYONG',
        'parti': 'PHRS',
    },
    2163: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 187,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOKTAR BIN RADIN',
        'parti': 'BN',
    },
    2164: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 187,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'M.A GHAZALI BIN ABDUL GHANI',
        'parti': 'WARISAN',
    },
    2165: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18747,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MASIUNG BANAH',
        'parti': 'BN',
    },
    2166: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18747,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'EDWARD PODOK ',
        'parti': 'PCS',
    },
    2167: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18747,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'NURFAEZAH CHUA@ KIAT KANG',
        'parti': 'WARISAN',
    },
    2168: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18747,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'JUMAIDIN BIN LAKALIA',
        'parti': 'PAS',
    },
    2169: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18747,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'JAMES BIN AIT',
        'parti': 'STAR',
    },
    2170: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18748,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'MUARIFFIDDIN BIN ABDUL MALEK',
        'parti': 'PHRS',
    },
    2171: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18748,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'MOHD ISMAIL BIN AYOB',
        'parti': 'WARISAN',
    },
    2172: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18748,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SADDI BIN ABDUL RAHMAN',
        'parti': 'BN',
    },
    2173: {
        'KodN': 15,
        'KodParlimen': 187,
        'KodKawasan': 18748,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ABDUL GHANI KUSOI',
        'parti': 'PPRS',
    },
    2174: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 188,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATU NASRUN BIN DATU MANSUR',
        'parti': 'BN',
    },
    2175: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 188,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'MOHAMMADIN BIN KETAPI',
        'parti': 'WARISAN',
    },
    2176: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 188,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'RAMLI BIN PATARUDDIN',
        'parti': 'PAS',
    },
    2177: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 188,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'SITI SHAZIANTI BINTI AJAK',
        'parti': 'PHRS',
    },
    2178: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18849,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'BULANGAN PANASI',
        'parti': 'PHRS',
    },
    2179: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18849,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABD RAHMAN BIN TAGGOH',
        'parti': 'PKS',
    },
    2180: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18849,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'MIZMA BINTI APPEHDULLAH',
        'parti': 'BN',
    },
    2181: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18849,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ASSAFFAL P.ALIAN',
        'parti': 'WARISAN',
    },
    2182: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18850,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': "DATO' HJ MOHAMMAD YUSOF HJ APDAL",
        'parti': 'BN',
    },
    2183: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18850,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DUMI BIN PG MASDAL',
        'parti': 'WARISAN',
    },
    2184: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18850,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'WONG YU CHIN',
        'parti': 'PHRS',
    },
    2185: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18851,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'NILWAN BIN KABANG',
        'parti': 'BN',
    },
    2186: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18851,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SAHING BIN TAKING',
        'parti': 'PHRS',
    },
    2187: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18851,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'NORAZLINAH BINTI ARIF',
        'parti': 'WARISAN',
    },
    2188: {
        'KodN': 15,
        'KodParlimen': 188,
        'KodKawasan': 18851,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'KASMAN BIN KARATE',
        'parti': 'PAS',
    },
    2189: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 189,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'ASMARA BIN AHMAD',
        'parti': 'PRM',
    },
    2190: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 189,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ABDUL NASIR BIN RAUF',
        'parti': 'PAS',
    },
    2191: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 189,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'DATUK RAMLEE BIN MARHABAN',
        'parti': 'BN',
    },
    2192: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 189,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'DATUK SERI SHAFIE BIN APDAL',
        'parti': 'WARISAN',
    },
    2193: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18952,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK HERMAN BIN MOHAMMAD',
        'parti': 'BN',
    },
    2194: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18952,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ABDUL NASIR BIN RAUF',
        'parti': 'PAS',
    },
    2195: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18952,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK JAUJAN BIN SAMBAKONG',
        'parti': 'WARISAN',
    },
    2196: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18952,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'UTUNG BIN TANJONG BARU',
        'parti': 'BEBAS',
    },
    2197: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18953,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK SERI NASIR BIN TUN SAKARAN',
        'parti': 'BN',
    },
    2198: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18953,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'DATUK SERI SHAFIE BIN APDAL',
        'parti': 'WARISAN',
    },
    2199: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK RAZAK BIN TUN SAKARAN',
        'parti': 'BN',
    },
    2200: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ABDUL MUKSIN BIN MOHAMMAD HASSAN',
        'parti': 'BEBAS',
    },
    2201: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'HJH MANIS MUKA BINTI HJ MOHD DARA',
        'parti': 'WARISAN',
    },
    2202: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'MOHAMAD BIN SARAHIL',
        'parti': 'PAS',
    },
    2203: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'KULI BIN MARALAM',
        'parti': 'PKS',
    },
    2204: {
        'KodN': 15,
        'KodParlimen': 189,
        'KodKawasan': 18954,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'MOHD SAID BIN TIBLAN',
        'parti': 'PHRS',
    },
    2205: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 190,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': 'MARY YAP KAIN CHING',
        'parti': 'BN',
    },
    2206: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 190,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'ALIZAMAN BIN JIJURAHMAN',
        'parti': 'PHRS',
    },
    2207: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 190,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'MOHAMAD BIN HUSAIN',
        'parti': 'PAS',
    },
    2208: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 190,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'CHRISTINA LIEW',
        'parti': 'PKR',
    },
    2209: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19055,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'RAZALI BIN HAMZAH',
        'parti': 'PHRS',
    },
    2210: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19055,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'AMBOASE BIN RAMANO',
        'parti': 'PAS',
    },
    2211: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19055,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HAJI ALIPA JACKERY',
        'parti': 'BEBAS',
    },
    2212: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19055,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK OSMAN BIN JAMAL',
        'parti': 'BN',
    },
    2213: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19055,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'ANDI RUS DIANA BT ANDI PALADJARENG',
        'parti': 'WARISAN',
    },
    2214: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19056,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'ABDUL SALIP BIN EJAL',
        'parti': 'WARISAN',
    },
    2215: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19056,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ALIZAMAN BIN JIJURAHMAN',
        'parti': 'PHRS',
    },
    2216: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19056,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DAUD BIN JALALUDDIN',
        'parti': 'PAS',
    },
    2217: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19056,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'NIZAM BIN DATUK ABU BAKAR TITINGAN',
        'parti': 'BN',
    },
    2218: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19057,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'PANG THOU CHUNG',
        'parti': 'PHRS',
    },
    2219: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19057,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'WONG SZE PHIN @ JIMMY',
        'parti': 'DAP',
    },
    2220: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19057,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LO SU FUI',
        'parti': 'BN',
    },
    2221: {
        'KodN': 15,
        'KodParlimen': 190,
        'KodKawasan': 19057,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'LEONG YUN FUI',
        'parti': 'PKS',
    },
    2222: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 191,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 2,
        'NamaCalon': 'YB DSP HJ ABDUL GHAPUR BIN HJ SALLEH',
        'parti': 'BN',
    },
    2223: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 191,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 4,
        'NamaCalon': 'AHMAD BIN LAHAMA',
        'parti': 'PHRS',
    },
    2224: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 191,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 3,
        'NamaCalon': 'NORBIN BIN ALOH',
        'parti': 'PAS',
    },
    2225: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 191,
        'JenisKawasan': 'PARLIMEN',
        'susunan': 1,
        'NamaCalon': "MA'MUN BIN SULAIMAN",
        'parti': 'WARISAN',
    },
    2226: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'AHMAD BIN DULLAH',
        'parti': 'PAS',
    },
    2227: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 6,
        'NamaCalon': 'AZIZUL BIN TANDEK',
        'parti': 'PKS',
    },
    2228: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'SHARATHA MASYAROH BINTI JOHN RIDWAN LINCON',
        'parti': 'PHRS',
    },
    2229: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'LIM TING KHAI',
        'parti': 'BN',
    },
    2230: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'ARMANI BIN AKUM',
        'parti': 'AMANAH',
    },
    2231: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19158,
        'JenisKawasan': 'DUN',
        'susunan': 5,
        'NamaCalon': 'SARIFUDDIN BIN HATA',
        'parti': 'WARISAN',
    },
    2232: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19159,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'USMAN BIN MADEAMING',
        'parti': 'PAS',
    },
    2233: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19159,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'ARDI BIN ARSAH @ SAMSI',
        'parti': 'PHRS',
    },
    2234: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19159,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'DATUK HAMISA BINTI SAMAT',
        'parti': 'BN',
    },
    2235: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19160,
        'JenisKawasan': 'DUN',
        'susunan': 2,
        'NamaCalon': 'ROSLAN BIN RAMLI',
        'parti': 'PAS',
    },
    2236: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19160,
        'JenisKawasan': 'DUN',
        'susunan': 1,
        'NamaCalon': 'YUSRI BIN YUNUS',
        'parti': 'PHRS',
    },
    2237: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19160,
        'JenisKawasan': 'DUN',
        'susunan': 3,
        'NamaCalon': 'DATUK ABD MUIS BIN PICHO',
        'parti': 'BN',
    },
    2238: {
        'KodN': 15,
        'KodParlimen': 191,
        'KodKawasan': 19160,
        'JenisKawasan': 'DUN',
        'susunan': 4,
        'NamaCalon': 'HASSAN A. GANI PG AMIR',
        'parti': 'WARISAN',
    },
}
